#
# spec file for package gnome-control-center
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Allow to enable/disable ibus, as GNOME is rather strict on new versions.
%bcond_without  ibus
# Wacom input support
%ifarch s390 s390x
%bcond_with     wacom
%else
%bcond_without  wacom
%endif

Name:           gnome-control-center
Version:        47.2
Release:        1.1
Summary:        The GNOME Control Center
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://apps.gnome.org/app/org.gnome.Settings
Source0:        %{name}-%{version}.tar.zst
Source99:       %{name}-rpmlintrc

# PATCH-NEEDS-REBASE Patch1
# PATCH-FIX-OPENSUSE gnome-control-center-disable-error-message-for-NM.patch bsc#989801 sckang@suse.com -- network: Improve the check for whether NM or wicked is running
Patch1:         gnome-control-center-disable-error-message-for-NM.patch
# PATCH-FIX-UPSTREAM gnome-control-center-users-page-Don-t-show-the-system-accounts.patch bsc#1224199 glgo#GNOME/Settings#3066 xwang@suse.com -- not show system account in Users panel
Patch2:         gnome-control-center-users-page-Don-t-show-the-system-accounts.patch

### patches for Leap >= 15 plus SLE >= 15, but not TW
# PATCH-FEATURE-SLE gnome-control-center-system-never-use-gnome-software.patch bsc#999336 fezhang@suse.com -- info: Never search for gnome-software as an option when checking for updates on SLE and Leap 42.2, because we use gpk-update-viewer.
Patch1001:      gnome-control-center-system-never-use-gnome-software.patch
# PATCH-FEATURE-SLE gnome-control-center-more-power-button-actions.patch bsc#993381 fezhang@suse.com -- power: Bring back the "shutdown" and "interactive" power button actions.
Patch1002:      gnome-control-center-more-power-button-actions.patch
# PATCH-FEATURE-SLE gnome-control-center-bring-back-firewall-zone.patch fate#316719 sckang@suse.com -- network: Bring back the firewall zone combo box to select proper firewall zone for each connection.
Patch1003:      gnome-control-center-bring-back-firewall-zone.patch
# PATCH-NEEDS-REBASE gnome-control-center-info-fix-distro-logo.patch boo#1200581 milachew@mail.lv -- Fix the size of logo icon in About system
Patch1004:      gnome-control-center-info-fix-distro-logo.patch

BuildRequires:  /usr/bin/Xvfb
BuildRequires:  cups-devel >= 1.4
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  krb5-devel
BuildRequires:  meson >= 0.58.0
BuildRequires:  pkgconfig
BuildRequires:  python3-dbusmock
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(accountsservice) >= 0.6.39
BuildRequires:  pkgconfig(cairo-gobject)
BuildRequires:  pkgconfig(colord) >= 0.1.34
BuildRequires:  pkgconfig(colord-gtk4)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gcr-4) >= 4.1.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.23.0
BuildRequires:  pkgconfig(gdk-wayland-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0) >= 2.76.6
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gnome-bluetooth-3.0)
BuildRequires:  pkgconfig(gnome-desktop-4)
BuildRequires:  pkgconfig(gnome-settings-daemon) >= 41
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(goa-1.0) >= 3.51.0
BuildRequires:  pkgconfig(goa-backend-1.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 47.0
BuildRequires:  pkgconfig(gsound)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk4) >= 4.15.2
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.6.beta
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libnm) >= 1.24.0
BuildRequires:  pkgconfig(libnma-gtk4)
BuildRequires:  pkgconfig(libpulse) >= 2.0
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(malcontent-0) => 0.7.0
BuildRequires:  pkgconfig(mm-glib) >= 0.7
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.103
BuildRequires:  pkgconfig(pwquality) >= 1.2.2
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(tecla)
BuildRequires:  pkgconfig(udisks2) >= 2.8.2
BuildRequires:  pkgconfig(upower-glib) >= 0.99.8
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xi) >= 1.2
## CONDITIONAL BUILD REQUIREMENTS
%if %{with wacom}
BuildRequires:  pkgconfig(libwacom) >= 1.4
%endif
%if %{with ibus}
BuildRequires:  pkgconfig(ibus-1.0) >= 1.5.2
%endif
##
Requires:       gnome-settings-daemon >= 41
# needed for universal access panel
Requires:       gnome-themes-accessibility
Requires:       gnome-version
Requires:       iso-codes
# Needed for showing keyboard layout
Requires:       tecla-keyboard-layout-viewer
# For the thunderbolt panel
Recommends:     bolt
Recommends:     %{name}-user-faces
# cups-pk-helper should only be recommended, rather than a hard Requires, see boo#904047
Recommends:     cups-pk-helper
Recommends:     dbus(com.intel.dleyna-server)
# the printers panel can use the dbus service
Recommends:     system-config-printer-dbus-service
# For the power panel
Recommends:     power-profiles-daemon

%description
The control center is GNOME's main interface for configuration of
various aspects of your desktop.

%package user-faces
Summary:        Login manager user avatars
Group:          System/GUI/GNOME
BuildArch:      noarch

%description user-faces
This package provides user avatars to be used by display managers

%package devel
Summary:        Header files for the GNOME Control Center
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}
BuildArch:      noarch

%description devel
The control center is GNOME's main interface for configuration of
various aspects of your desktop.

%package color
Summary:        Configuration panel for color management
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
# The color panel requires colord to be present for the glib schema
Requires:       colord
# The color panel interacts with binaries from gnome-color-manager
Requires:       gnome-color-manager
Supplements:    %{name}
BuildArch:      noarch

%description color
This package provides the color management configuration panel for
GNOME control center.

%package goa
Summary:        Configuration panel for online accounts
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
# The online accounts panel interacts with binaries and icons from gnome-online-accounts
Requires:       gnome-online-accounts
Supplements:    (%{name} and gnome-online-accounts)
BuildArch:      noarch

%description goa
This package provides the online accounts onfiguration panel for
GNOME control center.

%package users
Summary:        Configuration panel for User accounts
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
Supplements:    %{name}
BuildArch:      noarch

%description users
This package provides the online accounts onfiguration panel for
GNOME control center.

%lang_package

%prep
%setup -q
%patch -P 1 -p1
%patch -P 2 -p1

# patches for Leap >= 15 plus SLE >= 15, but not TW
%if 0%{?sle_version} >= 150000
%patch -P 1001 -p1
%patch -P 1002 -p1
%patch -P 1003 -p1
# patch needs rebase
# %patch -P 1004 -p1
%endif

%build
%meson \
	-Ddocumentation=true \
	%{!?with_ibus: -Dibus=false} \
	-Dmalcontent=true \
	-Dtests=false \
	-Dsnap=false \
	-Dlocation-services=enabled \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}-2.0 %{?no_lang_C}
%find_lang %{name}-2.0-timezones %{name}-2.0.lang
%fdupes %{buildroot}%{_prefix}

# We do not package gnome-control-center.rules (bnc#804966)
rm %{buildroot}%{_datadir}/polkit-1/rules.d/gnome-control-center.rules

%check
%meson_test

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/*
%{_datadir}/metainfo/org.gnome.Settings.appdata.xml
%exclude %{_datadir}/applications/gnome-color-panel.desktop
%exclude %{_datadir}/applications/gnome-online-accounts-panel.desktop
%exclude %{_datadir}/applications/gnome-users-panel.desktop
%{_datadir}/applications/*.desktop
%{_datadir}/bash-completion/completions/gnome-control-center
%{_datadir}/dbus-1/services/org.gnome.Settings.service
%{_datadir}/dbus-1/services/org.gnome.Settings.SearchProvider.service
%{_datadir}/glib-2.0/schemas/org.gnome.Settings.gschema.xml
%{_datadir}/gnome-control-center/
%dir %{_datadir}/gnome-shell/
%dir %{_datadir}/gnome-shell/search-providers/
%{_datadir}/gnome-shell/search-providers/org.gnome.Settings.search-provider.ini
%{_datadir}/icons/hicolor/*/*/*.svg
%{_datadir}/icons/gnome-logo-text-dark.svg
%{_datadir}/icons/gnome-logo-text.svg
%{_datadir}/locale/en/
%{_datadir}/polkit-1/actions/org.gnome.controlcenter.remote-login-helper.policy
%{_datadir}/polkit-1/actions/org.gnome.controlcenter.remote-session-helper.policy
%{_datadir}/polkit-1/actions/org.gnome.controlcenter.system.policy
%{_datadir}/polkit-1/actions/org.gnome.controlcenter.user-accounts.policy
# We do not package gnome-control-center.rules
#{_datadir}/polkit-1/rules.d/gnome-control-center.rules
%dir %{_datadir}/sounds/gnome
%dir %{_datadir}/sounds/gnome/default
%dir %{_datadir}/sounds/gnome/default/alerts
%{_datadir}/sounds/gnome/default/alerts/*.ogg
%{_libexecdir}/gnome-control-center-print-renderer
%{_libexecdir}/gnome-control-center-search-provider
%{_mandir}/man1/gnome-control-center.1%{?ext_man}

%files user-faces
%{_datadir}/pixmaps/faces/

%files color
%{_datadir}/applications/gnome-color-panel.desktop

%files goa
%{_datadir}/applications/gnome-online-accounts-panel.desktop

%files users
%{_datadir}/applications/gnome-users-panel.desktop

%files devel
%doc gnome-control-center.doap
%{_datadir}/pkgconfig/gnome-keybindings.pc
%{_datadir}/gettext/its/gnome-keybindings.its
%{_datadir}/gettext/its/gnome-keybindings.loc
%{_datadir}/gettext/its/sounds.its
%{_datadir}/gettext/its/sounds.loc

%files lang -f %{name}-2.0.lang
# english locale should be in the main package
%exclude %{_datadir}/locale/en

%changelog
* Mon Nov 25 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Accessibility: Remove "screen" labels that take too much space
  + Appearance: Fix accidental reset of accent colors config
  + Apps: Fix some memory leaks
  + Color: Ensure profiles are connected before operating on them
  + Mobile Networks: Fix alignment of status pages
  + Mouse:
  - Fix illustration assets requiring gstreamer-plugins-bad
  - Update illustration assets
  + Printers: Remove wrong tooltip in the "Add Printer" button
  + Updated translations.
* Tue Oct 29 2024 bjorn.lie@gmail.com
- Update to version 47.1.1+9:
  * wwan: Fix status pages
  * default-apps-row:
  - Fix auto_ptr usage causing leaks
  - Fix auto_ptr use-after-free
  * Updated translations.
* Tue Oct 22 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1.1:
  + Fix crash on display scales > 1 due to conflicting type
    registration.
* Mon Oct 21 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + About: Allow FQDN hostnames
  + Appearance: Fix thumbnailing of backgrounds causing OOM kills
  + Date and Time: Fix resize issue in the time format row when
    shown in small window sizes
  + Online Accounts: Fix untranslated account provider info string
  + Region and Language: Update language row after closing language
    selector
  + Remote Desktop: Hide "Remote Desktop" row when
    gnome-remote-desktop is not available
  + Wacom:
  - Don't crash when handling an unknown stylus ID
  - Don't show Map Buttons for fallback devices
  - Handle all external remotes like an external TV remote-like
    device
  - Make assets recolaborable, supporting dark-style,
    high-contrast, and accent colors
  - Support HDPI for tablet/stylus illustration images
  + Updated translations.
* Fri Sep 27 2024 bjorn.lie@gmail.com
- Update to version 47.0.1+8:
  * online-accounts: Fix gettext use for row
  * online-accounts: fix gettext calls to static strings
  * Updated translations.
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0.1:
  + Fix invalid appstream release notes syntax.
- Changes from version 47.0:
  + Appearance: Fix accessibility regression on background names.
  + Apps: Handle opening details of Epiphany webapps.
  + Color:
  - Fix visibility of control buttons when expanding rows.
  - Fix "Show details" link on profile warning.
  + Sharing: Make "Media Sharing" dialog use GtkFileDialog for
    adding new folders.
  + Updated translations.
* Tue Sep 10 2024 Michael Gorse <mgorse@suse.com>
- Rebase gnome-control-center-more-power-button-actions.patch.
- Update some version requirements.
* Tue Sep  3 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Various ports from deprecated GTK and Libadwaita APIs
  + Appearance: Improve performance when loading wallpapers
  + Apps: Fix crash when handling invalid app permissions
  + Date and Time: Fix "Auto Timezone" setting visibility when
    Location Services are unavailable
  + Online Accounts: Update description of MS365 online account
    provider
  + Sharing: Fix adding "Shared Media" folders
  + Users:
  - Update feedback icons for validating username and passwords
  - Use a dialog to confirm removable of user fingerprints
  + WiFi: Fix crash when unplugging removable WiFi adapters
  + Updated translations.
* Thu Aug 29 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + Various CI fixes
  + Various ports to modern libadwaita widgets
  + Various mnemonics additions
  + Use GtkWindow.set_default_icon_name for legacy sessions
  + Accessibility: Rename "Reduce Animation" setting to "Animation
    Effects"
  + Apps:
  - Rename "File and Link Associations" page to "Files and Links"
  - Show status page when Parental Controls aren't available
  - Don't show "App is not sandboxed" banner for system
    components
  + Display:
  - Adapt rotation labels to the screen ratio
  - Don't set automatic Night Light when Location Services are
    unavailable
  + Keyboard
  - Load input choice locales asynchronously
  - Fix "Move" buttons in input rows
  + Location: Remove reference to now retired Mozilla Location
    Services
  + Mouse:
  - Use monochrome assets to support different accent colors
  - Separate "Touchpad" row into its own preferences row group
  + Network: Don't set empty ignored hosts
  + Notifications: Turn "App Notifications" dialog into a subpage
  + Online Accounts: Add a toast overlay for panel
    notifications/error messages
  + Users:
  - Modernize the "Add User" dialog
  - Respect password "enforcing" based on
    /etc/security/pwquality.conf
  - Avoid user names with underscores being interpreted as
    mnemonics
  - Show correctly the remaining list of fingerprints to enroll
  - Reverse sorting of finger names list to prioritize most used
    ones
  + Printers:
  - Various tweaks for the PPD Selection dialog
  - Add button instead of link to open printer cups web page
  + Privacy:
  - Don't leak Bolt and Location subpages
  - Fix visibility of Bolt settings when Bolt isn't available
  + Remote Desktop:
  - Fix loop resetting credentials
  - Use new gnome-remote-desktop server configuration DBUs
    interface
  + Sound: Add an empty state page for when no sound device is
    available
  + Wacom: Set up Wacom stylus keyboard shortcuts and switch
    monitor
  + WWAN: Fix crash preventing the load of the SIM Unlock dialog
  + Updated translations.
- Rebase patch, and disable patch 1, needs manual rebase.
* Sun Aug 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.4:
  + Accessibility: Fix enum value for follow centered
  + Apps: Fix memory leak for MMManager object in default apps page
  + Network: Don't set empty ignored hosts
  + Privacy: Fix visibility issue of Bolt settings when Bolt isn't
    available
  + Users:
  - Avoid accidental mnemonics for user name rows
  - Show correctly the remaining list of fingerprints to enroll
  + WWAN: Fix crash on Unlock SIM dialog
* Tue Jul 30 2024 Michael Gorse <mgorse@suse.com>
- Rebase gnome-control-center-info-never-use-gnome-software.patch
  and rename to
  gnome-control-center-system-never-use-gnome-software.patch
- Rebase gnome-control-center-bring-back-firewall-zone.patch.
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.3:
  + CI fixes
  + Mouse: Make Mouse test click indicator not respond for middle
    clicks
  + Network: Reference icon-name proper for wifi panel
  + Tests: Don't require Xvfb or setxkbmap for tests
  + Sharing: Make Orca read the "Add Folder" row in Media Sharing
    settings
  + Update translations.
- Refresh patches with quilt.
* Tue Jun  4 2024 Alynx Zhou <alynx.zhou@suse.com>
- Update gnome-control-center-disable-error-message-for-NM.patch:
  Add info page to toolbar view instead of navigation page to
  prevent hiding close button (bsc#1222099).
* Mon Jun  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Enable the "Location" settings panel by default.
  + Improve accessibility of some secondary-labels in settings
    rows.
  + Increase default log verbosity level.
  + Accessibility:
  - Fix icon name of accessibility panel desktop file.
  - Fix flash area settings selection shown incorrectly.
  + Display: Fix crash when closing laptop lid.
  + Keyboard: Fix keyboard navigation of keyboard shortcuts dialog
    categories.
  + Mouse and Touchpad: Remove unnecessary a11y label.
  + Network:
  - Fix crash when removing bluetooth network adapter row.
  - Sort VPN connections list alphabetically.
  - Remove incorrect assertion that breaks proxy settings page.
  + Sound:
  - Make sliders more accessible by keyboard.
  - Remove need for translating speaker test button tooltip.
  + System:
  - Improve accessibility of "Copy" buttons in Remote Desktop.
  - Fix crash in Date And Time settings closing before async
    calls finish.
  - Fix reuse of remote-desktop verify encryption fingerprint
    dialog.
  + Users: Fix visibility issue in parental controls row.
  + Updated translations.
* Fri May 24 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-control-center-users-page-Don-t-show-the-system-accounts.patch:
  not show system account in Users panel
  (bsc#1224199 glgo#GNOME/Settings#3066).
* Mon May 13 2024 Richard Rahl <rrahl0@disroot.org>
- Re-Enable location-services support:
  + Pass -Dlocation-services=enabled to meson.
  * * Support had been disabled by upstream as the mozilla location
    service will shut down. which in turn means location service
    will not be very accurate anymore.
* Thu May  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Accessibility: Improve accessibility of "Typing" settings
    sliders.
  + Display: Fix crash when pressing Escape in the display
    settings.
  + Network: Add stable-ssid support for cloned-mac.
  + Privacy:
  - Add build option to enable Location services
  - Fix opening of Help pages while viewing Privacy settings
  + Sharing: Auto hide Sharing panel when Rygel AND
    gnome-user-share are not available.
  + System:
  - Don't show auto-timezone setting when Location services
    unavailable.
  - Avoid unnecessary time-change requests.
  - Fix issue with sensitivity of "Add" and "Enroll" Enterprise
    Login buttons.
  - Improve generated passwords capacity in Remote Desktop
    settings.
  + Wacom: Check for the right output connector name.
- Drop upstream merged
  gnome-control-center-datetime-Avoid-emitting-the-time-changed-signal.patch.
* Mon Apr  8 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-control-center-datetime-Avoid-emitting-the-time-changed-signal.patch:
  Avoid emitting the time-changed signal
  (bsc#1222149, bsc#1221799, glgo#GNOME/gnome-control-center#2943).
* Wed Mar 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0.1:
  + Handle legacy panel arguments
  + Accessibility: Allow launching subpages directly.
  + Privacy: Fix Thunderbolt panel not launching.
  + System:
  - Avoid setting auto time sync when it isn't needed.
  - Improve startup time by loading subpages on demand.
  + Updated translations.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Split out users panel: it shall not be installed by default on
  Aeon.
* Mon Mar 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Update links in appdata file
  + Improve sidebar search results
  + Appearance: Add a transition to the selected background check.
  + Color: Fix visibility of calibration button.
  + Online Accounts: Reorder online account providers list.
  + Privacy & Security: Allow launching subpages of the privacy
    panel directly.
  + Wacom:
  - Bump libwacom dependency requirement to >= 1.4.
  - Add AES styli as separate stylus SVG.
  - Accept eraser types of button when matching stylus IDs.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc+75:
  + Allow launching some subpages from the command line.
  + Various ports of custom widgets to libadwaita widgets.
  + Appearance: Track current active background better.
  + Display:
  - Add support for Variable Refresh Rate (VRR) modes.
  - Show the full VRR range for a monitor when possible.
  + System:
  - Introduce the "Remote Login" settings.
  - Rename the old "Remote Desktop" settings to "Desktop
    Sharing".
  - Reintroduce some of "System" pages as search results.
  + Users:
  - Fix issue with newly created user page showing other user's
    info.
  - Introduce a new "Add Enterprise User" dialog.
* Tue Feb 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta.2:
  + Exceptional release to fix translations.
* Tue Feb 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta.1:
  + Exceptional release to include gnome-online-accounts changes.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Drop pkexec dependency.
  + Bump gcr dependency to gcr4.
  + Reorder sidebar/panel list.
  + Use g_clear_handle_id with g_source_remove to remove GSources.
  + Add CcHostname as a wrapper to interact with system-hostnamed.
  + Remove periods in subtitles/descriptions/labels according to
    the HIG.
  + Various string/sentence rewording (for clarity).
  + Various style changes in symbolic icons.
  + Various ports of custom widgets to modern libadwaita
    alternatives.
  + Various new mnemonics added.
  + Accessibility:
  - Expose new "show-status-shapes" setting.
  - Rephrase overamplification string in the "Hearing" settings.
  - Stop tracking old GTK theme.
  - Stop forcing HighContrast icon theme (The theme is considered
    deprecated).
  + Apps:
  - Tweak headings & descriptions from Default Apps sections.
  - Tweak the autorun-never option design (inverting the
    autorun-never option logic).
  - Use modern libadwaita widgets in the Removable Media
    settings.
  + Keyboard: Use AdwActionRow to show the key modifier options.
  + Network: Fix missing VPN entries.
  + Mouse:
  - Add "Test Settings" button to the body of the panel.
  - Modernize mouse test dialog (adds secondary-click test).
  + Printers:
  - Add padding to the sidebar items from "Printer Options".
  - Add .suggested-action style class to "Test Page" button.
  + Privacy:
  - Hide non-functional microphone panel.
  + Search:
  - Add commandline parameter for opening the Search Locations
    dialog directly.
  - Stop removing non-existent folders from tracker.
  - Expose single directory setting.
  - Add placeholder for custom locations.
  - Set title for non-existent bookmarks.
  - Always show switch for default/bookmarks.
  - Handle unset XDG dirs.
  - Tweak search locations labels.
  + Sharing:
  - Fix alignment of networks section in the File/Media sharing
    dialogs.
  - Use edit-delete-symbolic in networks list rather than
    window-close-symbolic.
  - Move main switches from dialog headerbars into the dialog's
    content area.
  + Sound:
  - Show radio buttons as prefix for the Alert Sound rows.
  - Add tooltips to all speaker test buttons.
  + System:
  - Move "Remote Login" from sharing panel to System (now named
    "Secure Shell").
  - Use polkit to request permissions to enable/disable sshd.
  - Create CcSystemDetailsWindow upon opening (speed up System
    panel startup time).
  - Fix crash in About page after dark mode switch.
  - Don't show Remote Desktop settings when backend is not
    available.
  - Show gnome-control-center version on the "GNOME Version" row
    in the About page.
  - Fix language chooser dialog not closing in Users page.
  + Wi-Fi:
  - Show password when sharing QR Code.
  - Fix crash with toast notifications in the Saved Networks
    dialog.
  + Updated translations.
- Drop gnome-control-center-add-user-button.patch: no longer
  applicable.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45.3:
  + Datetime: Fix build with -Wincompatible-pointer-types.
  + Region: Prevent preview crash from accessing invalid pointer.
  + Wifi: Fix build with -Wincompatible-pointer-types.
- Drop gnome-control-center-fix-region-preview-crash.patch: fixed
  upstream.
* Thu Jan  4 2024 Alynx Zhou <alynx.zhou@suse.com>
- Add gnome-control-center-fix-region-preview-crash.patch:
  nl_langinfo's returned pointer could be invalid after switching
  locale, so we have to save the result before switch locale to
  prevent the crash (bsc#1218528,
  glgo#GNOME/gnome-control-center!2122).
* Thu Dec  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.2:
  + Apps:
  - Fix status page glitch on initialization
  - Fix "File and Link Association" interface not reflecting
    changes
  + Background: Improve background preview and chooser performance
  + Default Apps: Fix undesired resetting of default apps during
    startup
  + Mouse: Fix interference issue with scroll event in Mouse Test
    window
  + Network:
  - Close network editor when using non-native
    nm-connection-editor
  - Show decoration buttons on empty-state (no network device
    found page)
  - Share WPA3 (SAE) networks with QR Code
  - Hide QR Code icon when connection is not successful
  - Remove deprecated 'wpa-none'
  - Fix route label alignments
  + Privacy:
  - Fix crash from free bug in the Camera page
  - Fix potential crash on Bolt page visibility
  + Region: Show preview measurement format in current locale
  + Sound: Update mute state when setting mixer control for a
    stream
  + Users: Show tooltip information for the Avatar widget
- Drop gnome-control-center-network-fix-nmce-popup.patch: Fixed
  upstream.
* Wed Dec  6 2023 Yifan Jiang <yfjiang@suse.com>
- Mark gnome-control-center-info-fix-distro-logo.patch as rebase
  needed. The patch needs a deeper review because its base is too
  old and SLE/Leap specific.
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Sun Nov 26 2023 bjorn.lie@gmail.com
- Update to version 45.1+22:
  + apps: Fix status page glitch on initialization
  + po: Fix missing closing tag in pt_BR locale
  + background: Improve preview performance
  + applications: Fix File & Link Associations UI
  + Updated translations.
* Mon Nov 13 2023 bjorn.lie@gmail.com
- Update to version 45.1+14:
  + user-accounts: Sync lock tooltip for the Avatar
  + privacy: Fix crash from free bug in cc-camera-page
  + default-apps: Workaround AdwComboRow item selection at startup
  + network-connection-editor: Align Routes labels
  + Updated translations.
* Fri Oct 27 2023 Jonathan Kang <sckang@suse.com>
- Rebase gnome-control-center-disable-error-message-for-NM.patch,
  gnome-control-center-info-never-use-gnome-software.patch,
  gnome-control-center-more-power-button-actions.patch and
  gnome-control-center-bring-back-firewall-zone.patch(bsc#1216601).
* Mon Oct 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + About: Add more types of processor support
  + Accessibility: Make Cursor Size dialog close on Escape key
  + Keyboard: Allow closing Shortcuts dialog with Escape key
  + Mouse:
  - Fix linked style of primary mouse button in RTL languages
  - Avoid making videos blurry
  + Network:
  - Fix editing connections without a device
  - Revert "Disable DNS entry if automatic DNS option is enabled"
* Thu Oct 12 2023 Jonathan Kang <songchuan.kang@suse.com>
- Add gnome-control-center-network-fix-nmce-popup.patch:
  network-connection-editor: Close the editor when nm-connection-editor
  exits(bsc#1208193 glgo#GNOME/gnome-control-center!1956).
* Tue Oct  3 2023 bjorn.lie@gmail.com
- Update to version 45.0+34:
  + network: fix editing connections without a device (boo#1215651)
  + mouse: Fix linked style of primary mouse button in RTL
  + privacy: Fix crash in the firmware security page
  + data:
  - Fix label string
  - Add missing wireguard-peer.ui to POTFILES.in
  - Mark translatable strings yes
  + info-overview: Add more types of processor support
  + Updated translations.
- Switch to git checkout from stable branch, use explicit commit.
* Fri Sep 22 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-control-center-add-user-button.patch:
  Show add user button when user is a normal user
  (bsc#1215556 glgo#GNOME/Settings!1927).
* Fri Sep 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Fix panel list (sidebar) issues with panel centering
  + Use g_printeer to message when running in non-supported
    environments
  + About:
  - Fix issue with system details label having the "selected"
    state
  - Allow system details labels to span multiple lines
  + Accessibility: Fix issue when icon theme changes to
    HighContrast can't be reverted
  + Keyboard: Fallback to subproject when keyboard previewer
    (tecla) is not available
  + Network:
  - Fix criticals when updating connection
  - Don't try to update device if it doesn't exist
  - Don't show QR Code button for wifi connections using
    unsupported security methods
  + Online Accounts: Add line-breaks to log messages
  + Search: Fix crash when selecting folder in "Other Search"
    locations
  + Users: Allow new password insert if the old one is right
- Add explicit pkgconfig(tecla) BuildRequires: New dependency.
- Switch service and tarball produced to zst compression.
* Fri Aug 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.rc:
  + About:
  - Port to AdwToolbarView
  - Make System Details window more compact
  - Port System Details window to AdwBreakpoint
  - Port System Details window to AdwToolbarView
  + Accessibility: Port to AdwToolbarView
  + Applications:
  - Make panel fit on narrow widths
  - Port deprecated GtkDialogs to AdwWindow
  + Background: Port to AdwToolbarView
  + Bluetooth: Port to AdwToolbarView
  + Color: Port to AdwToolbarView
  + Date and Time:
  - Port to AdwToolbarView
  - Port dialog to AdwWindow
  + Default Apps: Port to AdwToolbarView
  + Display:
  - Port to AdwNavigationView and AdwtoolbarView
  - Reduce the size of the preview width
  + Keyboard:
  - Port to AdwToolbarView
  - Port keyboard shortcuts dialog to AdwNavigationView
  - Fix criticals when inpuit chooser is destroyed
  - Write to mru-sources setting if it has never been set before
  + Mouse:
  - Make adaptative
  - Port to AdwToolbarView
  - Port the test dialog to AdwToolbarView
  - Stop leaking the test window
  + Multitasking: Port to AdwToolbarView
  + Network:
  - Port to AdwNavigationView and AdwToolbarView
  - Port the Wi-Fi panel to AdwToolbarView
  - Stop leaking the hotspot dialog
  + Notifications:
  - Port to AdwToolbarView
  - Port dialog to AdwWindow and AdwToolbarView
  + Online Accounts: Port to AdwToolbarView
  + Power:
  - Port to AdwToolbarView
  - Port the suspend dialog to AdwWindow and AdwToolbarView
  + Printers:
  - Port to AdwToolbarView
  - Make the panel adaptative
  - Move search bar above the banner
  - Port dialogs to AdwWindow and AdwToolbarView
  - Fix size calculation for normalized printer name
  + Removable Media:
  - Port the dialog to AdwWindow
  - Port to AdwToolbarView
  + Region: Port to AdwToolbarView
  + Search: Port to AdwToolbarView
  + Sharing:
  - Port to AdwToolbarView
  - Port dialogs to AdwWindow and AdwToolbarView
  - Port Remote Login row to AdwSwitchRow
  + Sound:
  - Port to AdwToolbarView
  - Port dialogs to AdwWindow and AdwToolbarView
  + User Accounts:
  - Fix account type row sensitivity
  - Port to AdwToolbarView
  - Port Add User dialog from deprecated GtkDialog to AdwWindow
  - Update status page text when no accountsservice is available
  - Show label when another user is logged in
  - Port error message dialogs to AdwToasts
  - Port deprecated GtkMessageDialogs to AdwMessageDialog
  - Add "loading" page at startup
  + Wacom: Port to AdwToolbarView
  + WWAN: Port to AdwToolbarView
- Pass tests=false to meson, we are not running tests, so lets not
  build them either (avoids a dependency on setxkbmap).
* Mon Aug  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Prevent loading last-panel unconditionally on startup
  + Multiple settings rows got ported to use the AdwSwitchRow
    widget
  + Various accessibility label fixes
  + Various memory leak fixes
  + About: New About panel displaying system information in a more
    compact way
  + Applications: Fix crash when opening the Apps panel as the
    last-opened panel
  + Datetime: Add description explaining the "Clock & Calendar"
    settings
  + Displays: Replace deprecated GtkComboBox with AdwComboRow
  + Keyboard:
  - Fix "Move up/down" movement options in the input list
  - Spawn "tecla" app to display the keyboard map (replaces
    gkbd-keyboard-display)
  - Fix alignment of the "Set Shorcut..." button
  + Network: Use an AdwSwitchRow widget to enable/disable Wi-Fi
  + Online Accounts:
  - Improve "offiline" message text
  - Use banner to indicate when the system is offline
  - Add panel description text and section titles
  + Sound:
  - Make output test whell smaller
  - Ellipsize long device name label
  + Printers: Use the "card" style for printer entries
  + Privacy: New Privacy panel containing all the panels under the
    Privacy category
  + Region: Fix preview buttoins in the format chooser
  + Search: Fix "Move up/down" movement options in the app search
    list
  + Users:
  - Show "Other Users" section only when there are users to show
  - Make entire panel insensitive when the user has no permission
    to make changes
  - Fix focus issues when selecting avatar image from a file
  - Fix g_critical errors when loading file metadata for avatars
- Replace gnomekbd-tools Requires with tecla-keyboard-layout-viewer
  Requires following upstream changes.
* Fri Jul 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Add placeholder text to various search entries
  + Set a minimum size for various dialogs
  + Make dialogs close when pressing the Escape key
  + Replace deprecated GTK4 methods with new replacements
  + Depend on snapd-glib-2 (soup3 version)
  + Accessibility improvements
  + Common:
  - Fix time entry for RTL languages
  - Use ToastOverlay
  - Show start title buttons in header bar
  - Allow more theming of rows
  - Only return to last panel if it didn't crash
  - Improvements to panel activation
  - Improvements to panel searching
  + About:
  - Show only the GNOME major version
  - Update hostname only after apply is clicked
  + Accessibility: Present the checked state on the list row itself
  + Appearance: Clear out dconf if user picks defaults
  + Applications:
  - Always use bold for app name in dialogs
  - Use header capitalization in the "No apps" AdwStatusPage
  + Color:
  - Do not try to access to null pointer in destruction
  - Dim information text & fix "Learn more" link alignment
  + Date and Time:
  - Fix NTP switch getting out of sync
  - Add top bar clock and calendar switches
  - Move "Time Format" row out of "Clock" section
  - Merge "Clock" and "Calendar" sections
  + Default Apps: Don't crash when there are no apps for a mimetype
  + Device Security:
  - Skip security attributes that have been obsoleted by others
  - Ddon't translate technical report
  + Display:
  - Allow configuring all monitors and apply settings at once
  - Try snapping all the displays after a config change
  - Don't leak config manager proxy
  - Use AdwPreferencesPage
  - Fix display enabled toggle visibility
  - Fix gaps when numbering unusable displays
  - Fix stuck window subtitle
  - Fix invalid panel state after canceling changes
  - Check best_mode exist before adding flag
  + Info: Show each GPU in it's own line
  + Mouse:
  - Prevent infinite loop on settings changes
  - Do not bind sensitivity to touchpad settings
  - Simplify binding of touchpad sensitive widgets
  - Hide entire "Touchpad" row when touchpad cannot be disabled
  + Keyboard:
  - Fix cancel button issue
  - Add "Compose" and "Character" keywords
  - Add ellipsis to the "Add Shortcut" button label
  - Fix "Add Custom Shortcut" in others sections
  - Drop "Left Alt" as compose key option
  + Network:
  - Validate max length of hotspot SSID
  - Keep current mode when enabling proxy
  - Increase maximum MTU value from 10000 to 65536
  - Fix incorrect styling in WiFi list
  - Make the security status and signal strength read by screen
    readers
  - Add a confirmation dialog when forgetting a connection
  - Center panel title when subtitle isn't visible
  - Rename "Other Devices" to "Bluetooth"
  - Fix crash when importing wrong vpn file
  - Drop legacy vpn_export function
  - Close Connection Editor dialog when clicking Apply button
  - Add delete icon in saved WiFi connections list
  - Move WiFi controls out of headerbar
  + Notifications: Replace "Applications" with "App Notifications"
  + Power:
  - Label the main "battery" as UPS if that's what it is
  - Hide automatic suspend row in VM
  + Region: Fix label of formats for the login screen
  + Sharing:
  - Disable AdwActionRow markup for networks
  - Fix network row visible name bug
  - Remove global master switch
  - Fix visual bug for active indicators
  - Add icons next to each row
  - Add subtitle to each panel row
  + Sound:
  - Make bass audible on low quality hardware
  - Prevent duplicate sound device entries
  + Thunderbolt:
  - Update page to be more similar to other pages
  - Modernize Device Dialog UI
  + Usage: Fix confirmation dialog when clearing history
  + Users:
  - Remove account activity window
  - Set language-chooser to hide on close
  - Add popover explaining about the "Administrator" option
  - Add a popover describing the autologin functionality
  - Move "Add User" button out of the user listbox
  - Improve avatar crop mechanics
  - Improve rounding of avatar crop edges
  - Draw avatar crop corners to inside of crop
  + Wacom: Rename "Test Your Settings" button to "Test Settings"
  + Updated translations.
- Rebase patch with quilt, but still disable it, breaks build in
  current form, so needs reworking or possibly dropping.
* Fri Jun 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.3:
  + Updated translations.
* Fri May 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Various small accessibility fixes.
  + Fixes in Gtk template usage that causes crashes on some
    systems.
  + Appearance: Clear dconf when resetting to defaults.
  + Mouse: Hide entire "Touchpad" row when touchpad cannot be
    disabled.
  + Network: Fix racy radio buttons in connection editor.
  + Users: Remove autologin row tooltip when unlocked.
  + Updated translations.
* Fri Apr 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Common:
  - Update hostname only after apply is clicked.
  - Add widget name and css class to CcIllustratedRow and
    CcSplitRow.
  + Color: Do not try to access to null pointer in destruction.
  + Date & Time: Fix NTP switch getting out of sync.
  + Display:
  - Allow configuring all monitors and apply settings at once.
  - Disconnect config manager changed handler.
  - Don't leak config manager proxy.
  + Network: Fix crash when removing a connection.
  + Region: Fix label of formats for the login screen.
  + Sharing: Fix network row visible name bug.
  + Shell: Add workaround to make disabled pictures are painted as
    such.
  + Sound:
  - Prevent duplicate sound device entries.
  - Revert accidental libgvc downgrade.
  + Updated translations.
- Drop gnome-control-center-fix-6f1567f23.patch: Fixed upstream.
* Thu Apr 13 2023 Jonathan Kang <songchuan.kang@suse.com>
- Rebase gnome-control-center-disable-error-message-for-NM.patch
- Add gnome-control-center-fix-6f1567f23.patch:
  network/connection-editor: fix crash when removing a connection
  (glgo#GNOME/gnome-control-center/commit/8cb77b4d3, bsc#1210377).
* Fri Mar 31 2023 bjorn.lie@gmail.com
- Update to version 44.0+20:
  + datetime: Fix NTP switch getting out of sync.
  + shell/style: Add workaround to make disabled pictures are
    painted as such.
  + illustrated-row, split-row: Add widget name and css class.
  + region: Fix label of formats for the login screen.
  + keyboard: Fix cancel button issue.
  + Updated translations.
* Wed Mar 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0+7:
  + common: hostname-entry: Update hostname only after apply is
    clicked
  + sound: Prevent duplicate sound device entries
  + color: Do not try to access to null pointer in destruction
  + display: Allow configuring all monitors and apply settings at
    once
  + Updated translations.
- Switch to git checkout via source service, explicit tag from
  stable gnome-44 branch.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Mouse: Prevent infinit loop on Mouse setting changes.
  + Usage: Fix confirmation dialog when clearing file history.
  + Notifications: Replace occurrence of "Applications" with "Apps"
    string.
  + Power: Label the main "batery" as UPS when that's what it is.
  + Updated translations.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Improve state of switchers throughout the app
  + Keyboard: Various fixes to the shortcut editor
  + Mouse & Touchpad: Polish the panel redesign
  + Printers: Update to more modern CUPS APIs
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Redesigned Sound panel
  + Redesigned Mouse & Touchpad panel
  + Share Wi-Fi networks using QR code
  + Many consistency improvements
  + WireGuard support
  + Mouse & Touchpad:
  - Redesign the panel with videos of the preferences
  - Move mouse test into a separate dialog
  + Network:
  - Add support for sharing Wi-Fi networks through QR code
  - Add WireGuard support
  + Sound:
  - Move application volumes to a dialog
  - Move sound themes to a dialog
  + Updated translations.
- Disable gnome-control-center-disable-error-message-for-NM.patch
* Fri Feb 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 44.alpha:
  + Redesigned Accessibility panel.
  + Many consistency improvements.
  + About: Add "Firmware Version" row.
  + Accessibility: Redesign the panel with new a navigation
    pattern.
  + Cellular: Various fixes.
  + Date & Time: Improve month selector.
  + Device Security:
  - Improve date and time formatting.
  - Simplify technical descriptions.
  + Display: Improve error state of Night Light.
  + Sound: Start implementing the new designs.
  + Thunderbolt: Hide panel if no Thunderbolt device is found.
  + Updated translations.
- Drop gnome-control-center-network-use-AdwStatusPage.patch: fixed
  upstream.
* Fri Feb 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unneeded nor used pkgconfig(clutter-1.0) BuildRequires.
* Mon Feb 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.4.1:
  + Network: Fix possible race in tests.
  + Updated translations.
* Fri Dec 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + About: Update distro logo when dark-mode changes.
  + Applications: Don't recurse into symlinks when clearing cache.
  + Cellular: Avoid duplicated entries in SIM providers list.
  + Color: Fix crash when first device row is non-existent.
  + Common: Make list row switches work when annimations are OFF.
  + Display: Allow the Night Light error label to wrap for small
    screens.
  + Mouse: Fix activation of rows while navigating with keyboard.
  + Network:
  - Fix crashes when EAP password is missing.
  - Fix wrong signal of SEA password visibility toggle.
  + Notifications: Sync lock screen notification setting string.
  + Users: Show a missing-avatar image when avatars cannot be
    loaded.
  + Updated translations.
- Drop gnome-control-center-fix-ws-sea-pass-toggle.patch: Fixed
  upstream.
- Refresh patches with quilt.
* Mon Dec 19 2022 Jonathan Kang <songchuan.kang@suse.com>
- Modify gnome-control-center-disable-error-message-for-NM.patch:
  fix wifi panel(bsc#1206233).
* Tue Dec  6 2022 Jonathan Kang <songchuan.kang@suse.com>
- Rebase gnome-control-center-disable-error-message-for-NM.patch.
- Add gnome-control-center-network-use-AdwStatusPage.patch:
  network-panel: Use AdwStatusPage to show NetworkManager error.
  This is needed by the above rebased patch
  (glgo#GNOME/gnome-control-center/commit/2b3de01124).
* Tue Dec  6 2022 Alynx Zhou <alynx.zhou@suse.com>
- Add gnome-control-center-fix-ws-sea-pass-toggle.patch: Fix crash
  when user clicking password visibility toggle in Security page
  when method is WPA3 Personal
  (glgo#GNOME/gnome-control-center!1520).
* Tue Oct 18 2022 Milachew <milachew@mail.lv>
- Add gnome-control-center-info-fix-distro-logo.patch: Fix the size
  of logo icon in About system (boo#1200581).
* Tue Oct 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Network: Fix crashes editing networks.
  + Power: Don't assert if we can't find the widget for a profile.
  + Printers: Small visual improvements.
  + Updated translations.
* Thu Sep 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sun Sep  4 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 43.rc:
  + Fix AM/PM labeling issue;
  + Remove no longer used icon;
  + Select panel only if non-folded when search is canceled;
  + Several UI improvements regarding device security;
  + Fix primary monitor selection.
  + Allow backgrounds to use any image format;
  + Improve dark theme support;
  + Keyboard: Fix activation of input source toggle button and
    improve handling of Shift shortcuts.
  + Power: Fix blank screen and power button behavior settings;
  + Printers: Show empty state after removing last printer;
  + Fix Move Up and Move Down actions when searching;
  + Fix sound alert selection;
  + Improve support to Wacom Express Key Remote;
  + Updated translations.
- Update URL tag to https://apps.gnome.org/app/org.gnome.Settings/,
  the new upstream web page dedicated to Settings (this package).
- Bump meson build requirement from 0.53.0 to 0.57.0.
- Add noarch as BuildArch for color, goa, user-faces, and devel
  subpackages as they do not contain any native code/binaries.
- Add rpmlintrc to filter false-positives about
  desktopfile-without-binary warnings for color, goa and user-faces
  subpackages since they call "gnome-control-center color/goa/etc"
  rather than a binary of their own. Also filter the
  file-not-in-%%lang warning because we strip the English language
  from the lang subpackage and package it in the main package.
* Mon Aug 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(gcr-3) with pkgconfig(gcr-base-3)
  BuildRequires: Align with what meson checks for.
- Drop explicit pkgconfig(libsoup-2.4) BuildRequires: No longer
  needed, as color sub-module was ported away from it. See
  https://gitlab.gnome.org/GNOME/gnome-control-center/-/commit/a9c398e5d9d45fb4638b38d6bb3f677a2b12b249
* Fri Aug 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.beta:
  + Cellular: Add WWAN 5G connection support.
  + Device Security:
  - Polish failure messages.
  - Various style updates.
  + Display: Support privacy screens.
  + Info: Show build id in a separate row.
  + Network: Fix VPN empty state.
  + Sound: Update default sounds.
  + User Accounts: Fix back button not appearing sometimes.
  + Updated translations.
* Sun Jul 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Improved accessibility in various panels.
  + New Device Security panel.
  + Date & Time: Update visual style of the timezone map.
  + Display: Various visual improvements.
  + Sound: Remove dog barking sounds.
  + Updated translations.
* Sun Jul  3 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 42.3:
  + Display: Use virtual clone modes when mirroring.
  + Network:
  - Prevent crash bi disconnecting device.
  - Fix Wi-fi network with "&" in name not appearing.
  - Fix warning when panel closed.
  + Updated translations.
* Mon May 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + Applications:
  - Fix Snap permissions support failing to compile.
  - Fix CcInfoRow having the wrong parent.
  - Fix crash crash when switching between two apps.
  + Background: Make sure the size of the light/dark previews are
    the same.
  + Keyboard: Fix crash resetting all keyboard shortcuts.
  + Network: Stop freeze when closing wired connection properties
    with Escape.
  + Sharing:
  - Fix close button on Verify Encryption dialog
  - Turn off RDP gsettings key when turning off RDP
  + Shell: Initialise locale early.
  + Sound: Update theme correctly so other apps respond to change.
  + Updated translations.
* Wed Apr 27 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.1:
  + Display:
  - Various small behavior improvements.
  - Fix monitor labels.
  + Network: Improve handling of VPN connections.
  + Online Accounts:
  - Fix behavior of helper application on X11.
  - Fix changes to online accounts services not applying
    correctly.
  + User Accounts: Various small polishments.
  + Wacom: Properly translate various strings.
  + Updated translations.
- Drop upstream fixed patches:
  + gnome-control-center-reload-vpn-plugins.patch
  + gnome-control-center-goa-helper-on-X11.patch
  + gnome-control-center-42.0-fix-sharing-panel-crash.patch
  + 1283.patch
* Thu Apr 21 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add 1283.patch: user-accounts: close password change dialog.
  Addresses boo#1198235: Fail to change password on GNOME42.
* Wed Mar 30 2022 Luciano Santos <luc14n0@opensuse.org>
- Add gnome-control-center-42.0-fix-sharing-panel-crash.patch,
  based on commit c2f088ac5220f3a64edc2c15e60fc0d7f1dfc9e5, to fix
  Sharing panel segfaulting due to getlogin() returning NULL rather
  than the username (boo#1197529,
  glgo#GNOME/gnome-control-center!1727).
* Tue Mar 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add gnome-control-center-goa-helper-on-X11.patch: Fix GOA helper
  not showing up on X11 [glgo#GNOME/gnome-control-center!1651].
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated AppData screenshots.
  + Re-enable tests.
  + Updated translations.
- Disable tests for now, needs display, and that is somewhat hard
  to get during build on obs.
* Wed Mar 16 2022 Jonathan Kang <songchuan.kang@suse.com>
- Add gnome-control-center-reload-vpn-plugins.patch:
  network/connection-editor: always load all available VPN plugins
  (glgo#GNOME/gnome-control-center!1263).
* Mon Mar  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Keyboard: Restore _GNOME_WM_KEYBINDINGS support.
  + User Accounts:
  - Bring back Fingerprint dialog.
  - Fix avatar loading.
  + Wacom: Bring back empty state.
  + Updated translations.
- Add pkgconfig(gnutls) BuildRequires: New dependency.
* Tue Feb 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Port to GTK4
  + Various UI polish changes
  + New symbolic icons for panels
  + Application: Implement new design
  + Background:
  - Introduce dark & light mode selector
  - Rename to Appearance
  + Display: Implement new design
  + Region & Language: Implement new design
  + User Accounts: New design for the User Accounts panel
  + Wacom: Implement new design
  + Updated translations.
- Drop pkgconfig(cheese) and pkgconfig(cheese-gtk) BuildRequires.
- Replace the following BuildRequires:
  + pkgconfig(colord-gtk) with pkgconfig(colord-gtk4)
  + pkgconfig(gnome-bluetooth-1.0) with
    pkgconfig(gnome-bluetooth-3.0)
  + pkgconfig(gnome-desktop-3.0) with pkgconfig(gnome-desktop-4)
  + pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + pkgconfig(libhandy-1) with pkgconfig(libadwaita-1)
  + pkgconfig(libnma) with pkgconfig(libnma-gtk4)
- Disable patch that need rebase:
  + gnome-control-center-disable-error-message-for-NM.patch
- Drop patches fixed upstream:
  + gnome-control-center-fix-autologin-shortcut.patch
  + 496c719d7b1492b54c34ace648feb3802f34f774.patch
* Mon Feb 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.4:
  + Drop unused argument for i18n.merge_file() in Meson rules
  + Applications: Set the Icon key in desktop file to a icon that
    exists
  + Display: Do not invert order when constructing modes
  + Network: Show configuration button only for active/connecting
    connections
  + Printers: Fix error cancelling PPD dialog
  + Sound: Clear level bar when stream is empty
  + Updated translations.
- Drop 4f64deb5f1bc7b83fcc4381b7dbbaf71ad4a77c8.patch: Fixed
  upstream.
* Tue Feb  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 4f64deb5f1bc7b83fcc4381b7dbbaf71ad4a77c8.patch: Fix build
  with meson 0.61.0 and newer.
- Add 496c719d7b1492b54c34ace648feb3802f34f774.patch: Remove
  duplicate line from .desktop file
- Drop some ancient Provides and Obsoletes that are no longer
  needed: acme, fontilus, themus, control-center2,
  control-center2-devel, gnome-control-center-branding,
  gnome-control-center-branding-openSUSE and
  gnome-control-center-branding-upstream.
- Update our Supplements to current standard.
* Fri Dec  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + Updated translations.
* Wed Nov 10 2021 QK ZHU <qkzhu@suse.com>
- Add gnome-control-center-fix-autologin-shortcut.patch:
  If we don't add this property for autologin_row, the shortcut to
  toggle the GtkSwitch won't work (bsc#1191887,
  glgo#GNOME/gnome-control-center!1084).
* Fri Oct 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Mouse & Touchpad: Avoid cropping illustration.
  + Network: Fix enabling data after APN is set.
  + Power: Use translated strings for power button action
    behaviors.
  + Updated translations.
* Sun Sep 26 2021 Jonathan Kang <songchuan.kang@suse.com>
- Bring back gnome-control-center-disable-error-message-for-NM.patch
  and rebase it against latest code base(bsc#1190875).
* Fri Sep 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add power-profiles-daemon Recommends: Support the new power
  profiles available.
- Refresh patches with quilt.
* Mon Sep 20 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Cleanup the development Flatpak manifest.
  + User Accounts: Add parental controls keywords.
  + Updated translations.
* Sun Sep 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc1:
  + Cellular: Various translation fixes.
  + User Accounts: Improve parental controls behavior.
  + Updated translations.
* Sat Sep 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + Introduce the new Cellular panel.
  + Introduce the new Multitasking panel.
  + About: Fix a crash due to uninitialized variables.
  + Bluetooth: Fix Bluetooth switch transitions.
  + Location: Fix permission store id (again).
  + Power: Polish power profiles section.
- Changes from version 41.alpha:
  + Improve and fix the development Flatpak manifest.
  + Drop dependency on grilo.
  + About:
  - Don't show GNOME micro version number.
  - Look for dark and text distro logo variants.
  + Accessibility: Add "Enable Animations" option.
  + Location: Fix permission store id.
  + Mouse & Touchpad: Update artwork.
  + Online Accounts: Present all online accounts providers at once.
  + Power:
  - Integrate with new power profiles daemon API.
  - Show more information about power profiles.
  - Cleanup some preferences.
  + Updated translations.
- Drop pkgconfig(grilo-0.3) BuildRequires: no longer needed.
- Add pkgconfig(gcr-3) BuildRequires: dependency for the new
  cellular panel.
* Fri Sep 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.1:
  + About: Don't show GNOME micro version.
  + Location: Fix permission store table and id.
  + Network:
  - Show all IPv6 addresses for an interface.
  - Display IPv6 gateway.
  + Power: Fix D-Bus proxy leak.
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Mon Jul 19 2021 Yifan Jiang <yfjiang@suse.com>
- Add versioned BuildRequires to pkgconfig(udisks2):
  * https://gitlab.gnome.org/GNOME/gnome-control-center/-/blob/gnome-40/panels/info-overview/meson.build#L44
* Mon Apr 26 2021 Jonathan Kang <songchuan.kang@suse.com>
- Rebased gnome-control-center-info-never-use-gnome-software.patch,
  gnome-control-center-more-power-button-actions.patch and
  gnome-control-center-bring-back-firewall-zone.patch(bsc#1184098).
* Sun Mar 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Location: Wrap label to fit smaller window sizes.
  + Mouse & Touchpad: Allow horizontal scrolling in test page.
  + Network: Fix creation of the netmask widget.
  + Various fixes to the language chooser.
  + Updated translations.
* Mon Feb 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + Various improvements to fingerprint management.
  + Show hardware model and vendor in the About panel.
  + New Keyboard panel design.
  + New power mode selector in the Power panel.
  + About:
  - Show hardware model and vendor.
  - Use os-release to search for the OS logo.
  + Accessibility: Major code cleanup.
  + Display: Try harder to select a good and working scale.
  + Keyboard: Handle input sources.
  + Power:
  - Rearrange battery code to a new widget.
  - Add a new "Power Mode" section.
  + Sharing: Also disable Traker3.
  + Sound: Update mute button icon when volume changes.
  + User Accounts
  - Fix free of constant string
  - Use properly translated fingerprint strings
  - Improve transition to parental controls window
  - Many improvements to fingerprint management
  + Updated translations.
- Drop control-center-complete-SAE-support.patch: fixed upstreaam.
- Drop gnome-control-center-jscSLE16518-update-subprojects-libgvc.patch:
  fixed upstream
* Tue Feb 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.38.4:
  + User Accounts:
  - Properly handle claiming errors if we're already claiming.
  - Always call EnrollStop on enrollment complete.
  + Updated translations.
* Thu Jan  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.3:
  + Display: Fix crash when unable to get display configuration.
  + Network: Fix smal leak getting WiFi secrets.
  + Printers: Fix small leaks in new printer dialog.
  + User Accounts: Fix crash showing error in fingerprint dialog.
  + Updated translations.
* Fri Nov 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Applications: Fix NULL hash table being unreffed.
  + Keyboard: Fix gtk_widget_get_can_default assertion error.
  + Network: Correctly detect when ethernet devices are hotplugged.
  + Printers:
  - Make printers panel have a smaller minimum width.
  - Fix leak of printer name in callbacks.
  + Sharing: Disable Tracker 3.
  + Sound: Update libgvc to add support for recent UCM related
    changes in ALSA and PulseAudio.
  + Users: Fix free of const string.
  + Wacom: Fix a critical warning if loading a cursor fails.
  + Updated translations.
* Tue Oct 20 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Enable parental support integration:
  + Add pkgconfig(malcontent-0) BuildRequires.
  + Pass -Dmalcontent=true to meson.
* Thu Oct 15 2020 Jonathan Kang <songchuan.kang@suse.com>
- Only build control-center-complete-SAE-support.patch in
  Tumbleweed, Leap > 15.2 plus SLE > 15.2.
* Tue Oct 13 2020 QK ZHU <qkzhu@suse.com>
- Add gnome-control-center-jscSLE16518-update-subprojects-libgvc.patch:
  Update libgvc to revision 7a621180. This update is necessary to
  add support for recent UCM related changes in ALSA and PulseAudio
  (jsc#SLE-16518, glgo#GNOME/gnome-control-center!843).
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Keyboard: Fix behavior of "Replace" when adding custom
    shortcut.
  + Sound:
  - Update the profile list after getting the signal from gvc.
  - Fix subwoofer slider.
  + Updated translations.
- Drop python3-pytest-xvfb BuildRequires: no longer needed.
* Tue Sep 22 2020 Jonathan Kang <songchuan.kang@suse.com>
- Add control-center-complete-SAE-support.patch: network: complete
  SAE support(glgo#GNOME/gnome-control-center!831, jsc#SLE-14992).
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Display: Show screen orientation setting even when
    accelerometer is present.
  + Wacom: Group pad/stylus devices together with the group name.
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + Rename Universal to Accessibility.
  + Network:
  - Add support for Enhanced Open Wi-Fi security.
  - Fix connection editor blanking when removing manual entry.
  + Thunderbolt: Plug some memory leaks.
  + User Accounts: Show "Take a picture" button only when cam is
    available.
- Changes from version 3.37.3:
  + Update various panels with more modern GTK practices.
  + Improve how time periods are displayed.
  + Improve Settings icon.
  + Integrate with parental controls.
  + Date & Time: Add new time editor UI.
  + Keyboard: Various cleanups.
  + Lock Screen: Add USB protection entry when available.
  + Power:
  - Add option to show battery percentage.
  - Various smaller UI adjustments.
  + Printers: Do not authenticate SMB servers when search field is
    edited.
  + Sharing: Use gnome-remote-desktop instead of Vino on X11.
  + Sound: Stop non-interactive profile changes from triggering
    changed events.
  + User Accounts:
  - Always show permissions bar, even when no users are listed.
  - Use custom setting to override faces.
  - New Fingerprint dialog and various related improvements.
  - Integrate with parental controls.
  + Updated translations.
- Replace pkgconfig(libhandy-0.0) BuildRequires with
  pkgconfig(libhandy-1): follow upstream changes.
* Fri Jul  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Sound: Stop non-interactive profile changes from triggering
    changed events.
  + Users:
  - Don't limit the number of maximum fingerprint enroll stages.
  - Don't use sync calls for deleting fingerprints.
  - Only load the fingerprint state once.
  - Make the fingerprint operations cancellable.
  - Don't wait for fprintd on initialization.
  + Updated translations.
* Wed Jun  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Users:
  - Show add user button also if no users found.
  - Show permissions toolbar also if no users found.
  + Updated translations.
* Wed May 13 2020 Michael Gorse <mgorse@suse.com>
- Update to version 3.34.6:
  + Sound: fix translation of "System Sounds".
* Fri May  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Applications: Fix only connected snap interfaces showing.
  + Background: Allow adding multiple files to backgrounds.
  + Printers: Add whitespace between top right buttons.
  + Sharing: Set label for checkbox properly.
  + Sound: Fix translation of "System Sounds".
  + Info: Verify data coming from switcheroo-control.
  + Updated translations.
* Mon Mar 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Update man page for info panel change.
  + Display: Fix resolution options getting stuck in a low
    resolution.
  + Sound: Remove unused files.
  + Updated translations.
* Mon Mar 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated translations.
* Mon Mar 30 2020 mgorse@suse.com
- Update to version 3.35.92:
  + Applications: Update icon.
  + Background:
  - Remove split desktop and lock screen wallpapers.
  - Improve visuals of the background icons.
  + Network: Make VPN gear buttons consistent with other buttons.
  + Updated translations.
* Mon Mar 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Share GCancellable code
  + Background: Remove unused GCancellable.
  + Power: Fix mobile broadband switch logic.
  + Sharing: Remember password on remote desktop sharing.
  + Thunderbolt: Fix GCancellable leak.
  + User Accounts: Always generate user avatars.
  + Updated translations.
* Mon Mar 30 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + New sidebar panel order and grouping.
  + Introduce CcPermissionInfoBar.
  + More code style updates.
  + Applications:
  - Add "Run in Background" switch.
  - Add "Set Desktop Background" switch.
  - Show snap packages.
  + Network:
  - Add SAE support.
  - Many code refactorings.
  - Switch to use GtkTemplate.
  + Power: Hide power button the chassis is handset.
  + Printers: Use CcPermissionInfoBar.
  + Region & Language: New design for the Formats dialog.
  + User Accounts:
  - Use CcPermissionInfoBar.
  - Improved layout.
- Changes from version 3.35.2:
  + Tighten up code style.
  + Improve timezone for various countries.
  + Replace deprecated logging functions with modern equivalents.
  + Background: Update clock in both preview modes.
  + Date & Time: Allow changing the timezone when auto-update is
    prohibited.
  + Display: Replace CC_DISPLAY_*_GET_PRIVATE.
  + Info:
  - Implement new design.
  - Add windowing system field.
  + Network
  - Add new hotspot creation dialog.
  - Major cleanups and code refactorings.
  - Plug various memory leaks.
  + Privacy: Drop the panel and replace it by various subpanels.
  + Search: Make rows and its elements reachable via keyboard.
  + Sharing: Set new shared folder visible as soon as it gets
    added.
  + Sound: Remove leftover canberra-gtk header inclusion.
  + Universal Access: Make rows and its elements reachable via
    keyboard.
  + User Accounts: Use 'pw usershow' to check username validity on
    FreeBSD.
  + Updated translations.
- Drop gnome-control-center-can-not-find-usermod.patch,
  gnome-control-center-fno-common.patch and
  gnome-control-center-Initialize-GError-to-NULL-before-use.patch:
  fixed upstream.
- Switch back to regular release tarballs.
- Disable gnome-control-center-disable-error-message-for-NM.patch:
  Needs rebase.
* Mon Mar 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.5:
  + Remove some dead code.
  + Display: Fix resolution options getting stuck in a low
    resolution (bsc#1160173 glgo#GNOME/Settings#903).
  + Network:
  - Print warning if failed to save to libsecret.
  - Handle security combo box being not selected correctly.
  - Fix small memory leaks.
  + Sharing: Fix small memory leak.
  + User Accounts:
  - Fix uninitialized variable.
  - Fix small memory leak.
  + Updated translations.
* Thu Feb 13 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Thunderbolt: Fix memory leak.
  + Printers: Fix read of freed memory.
  + User Accounts:
  - Use absolute path of command usermod.
  - Fix carousel arrow location when animations are disabled.
  - Fix memory leak.
  - Fix uninitialized variable.
  + Region & Language: Fix LC_* variables not being correctly
    reset.
  + Sound: Add missing subwoofer icons.
  + Updated translations.
- Drop gnome-control-center-can-not-find-usermod.patch: Fixed
  upstream.
* Fri Jan 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend gnome-control-center-lang: the lang package
  has relevant supplements which pulls it in whenever needed.
- Move /usr/share/locale/en from the -lang package to the main
  package: English is installed on all systems. This avoids
  gnome-control-center-lang being triggered for installation on
  english-only systems.
* Thu Jan  9 2020 Michael Gorse <mgorse@suse.com>
- Add gnome-control-center-fno-common.patch: fix build with
  - fno-common (boo#1160393 glgo#GNOME/gnome-control-center!681).
* Thu Dec 12 2019 Xiaoguang Wang <xwang@suse.com>
- Add gnome-control-center-Initialize-GError-to-NULL-before-use.patch:
  backport upstream commit 54caab7b, initialize GError* to NULL
  before use, fix g-c-c crash.
* Fri Dec  6 2019 QK ZHU <qkzhu@suse.com>
- Rebase gnome-control-center-more-power-button-actions.patch for 3.34:
  Rename 'Shutdown' to 'Force Off' and adjust the order by severity
  (bsc#1091796, bsc#1158476).
* Thu Dec  5 2019 Xiaoguang Wang <xwang@suse.com>
- Add gnome-control-center-can-not-find-usermod.patch:
  g-c-c use command usermod to verify user is valid, usermod is in
  /usr/sbin, environment PATH doesn't include this path, so g-c-c
  can't find this command. Upstream commit c6be204
  (bsc#1158341 glgo#GNOME/gnome-control-center!653).
* Mon Nov 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Applications: Fix a memory leak.
  + Background: Fix crash if a BgRecentSource is unreffed during an
    async operation.
  + Display: Use correct mode for supported scale checking.
  + Printer: Provide a scheme to address parser.
  + User Accounts: Fix password dialog crashes and hangs.
  + Updated translations.
* Tue Nov 19 2019 Alynx Zhou <alynx.zhou@suse.com>
- Drop patches fixed upstream:
  + control-center-fix-crash-due-to-object-name-clashes.patch
  + control-center-fix-crash-opening-hidden-network.patch
  + control-center-sharing-fix-margin-issue.patch
  + gnome-control-center-fix-users-crash.patch
  + gnome-control-center-periodic-wifi-scan.patch
  + gnome-control-center-users-empty-state.patch
* Fri Nov 15 2019 Alynx Zhou <alynx.zhou@suse.com>
- Rebase gnome-control-center-bring-back-firewall-zone.patch
* Thu Nov 14 2019 Yifan Jiang <yfjiang@suse.com>
- BuildRequires /usr/bin/Xvfb instead of the xorg-x11-server-Xvfb
  package. This is for the compatibility with older X packages where
  Xvfb is not splitted.
* Sat Oct  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Background:
  - Allow load background file relative to XML file.
  - Update clock in both preview modes.
  + Date & Time: Allow changing the timezone when auto-update is
    prohibited.
  + Network:
  - Disable the "Apply" button until a change has been made.
  - Fix Add Connection dialog.
  - Accept empty values for the cloned mac address.
  + Online Accounts: Fix a crash.
  + Printers:
  - Give printer name fewer characters in width.
  - Check whether URI is valid while searching for printers.
  + Region & Language: Fix crash in keyboard layout population.
  + Search: Fix crash on clicking 'Search Locations'.
  + Sharing: Set new shared folder visible as soon as it gets
    added.
  + Sound: Remove leftover canberra-gtk header inclusion.
  + Updated translations.
- Drop patches fixed upstream:
  + gnome-control-center-Remove-leftover-canberra-gtk.patch.
  + control-center-network-fix-ce-apply-button.patch.
* Sat Sep 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-control-center-Remove-leftover-canberra-gtk.patch:
  sound: Remove leftover canberra-gtk header inclusion. Following
  this, drop pkgconfig(libcanberra-gtk3) BuildRequires: No longer
  needed, nor used.
- Add explicit xorg-x11-server-Xvfb BuildRequires: Previously
  pulled in by libcanberra-gtk3. Needed for tests to succeed.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0.1:
  + Sound: fix sliders not behaving properly.
  + Changes in version 3.34.0:
  + Updated translations.
* Wed Sep  4 2019 luke@ljones.dev
- Update to version 3.33.90:
  + Background: Clarify remove background button.
  + Display: Various bugfixes.
  + Search:
  - Introduce Drag n' Drop
  - Visual polishment.
  + Updated translations.
- Changes from version 3.33.3:
  + Various minor improvements from the Every Detail Matters
    session.
  + Add shadows to application icons
  + Documented Communication Guidelines
  + Development builds with Flatpak working again
  + Background: Redesigned panel.
  + Display: Move Night Light to a tab, instead of a dialog.
  + Keyboard Shortcuts:
  - Panel renamed from "Keyboard".
  - Minor UI adjustments.
  + Mouse & Touchpad: Reinstate keyboard navitation.
  + Power: Don't treat all batteries as laptop batteries.
  + Sharing: Use a HdyLeaflet.
  + User Accounts: Present the default avatar in the avatar
    popover.
  + Wacom: Ensure calibrator UI CSS only applies to its UI.
  + Updated translations.
- Remove control-center-fix-mtu-label.patch
- Remove control-center-network-add-domain-suffix-match.patch
- Remove gnome-control-center-disable-error-message-for-NM.patch
* Fri Aug  2 2019 bjorn.lie@gmail.com
- Update to version 3.32.2+9:
  + display:
  - Add guards for NULL display configuration.
  - Add failure returns into CcDisplayConfig.
  + universal-access:
  - Don't use widget names for GSettings keys.
  - Fix leaks checking settings.
  - Fix duplicate settings call.
  + Updated translations.
- Switch to git checkout via source service, upstream is lacking in
  stable releases. In the future we will use a stable tag when
  possible, but when upstream slacks off, we will use a checkout of
  the stable branch.
* Fri May 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Applications: Use larger icons.
  + Display:
  - Set Night Light screen temperature strings as translatable.
  - Fix crash if a monitor has no preferred mode.
  + Mouse & Touchpad: Reinstate keyboard navigation in the panel.
  + Power: Correct the value of 90 minutes to 5400.
  + Region & Language: Fix input source options not being applied.
  + Sound: Clean up labels of devices without origin.
  + Updated translations.
* Fri May 17 2019 Chingkai <qkzhu@suse.com>
- Update gnome-control-center-more-power-button-actions.patch:
  Rename 'Shutdown' to 'Force Off' and adjust the order by severity
  (bsc#1091796).
* Thu May 16 2019 Jonathan Kang <sckang@suse.com>
- Add control-center-fix-mtu-label.patch: network: Fix mtu label
  not requesting enough space (glgo#GNOME/gnome-control-center!475,
  bsc#1040055).
- Modify gnome-control-center-bring-back-firewall-zone.patch:
  rebase patch with control-center-fix-mtu-label.patch applied.
* Thu May  9 2019 Jonathan Kang <sckang@suse.com>
- Modified gnome-control-center-disable-error-message-for-NM.patch:
  Only prompt users to use Yast to configure network when
  NetworkManager is not running (boo#1134381).
* Mon Apr 22 2019 Max Lin <mlin@suse.com>
- Since libgomekbd has followed SLPP standard, replaced requires
  libgnomekbd to gnomekbd-tools.
* Mon Apr  1 2019 Jonathan Kang <sckang@suse.com>
- Modified gnome-control-center-disable-error-message-for-NM.patch:
  Disable tests for network panel.
* Fri Mar 29 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Add shadows to application icons.
  + Applications: Fix wrong IDs being passed to portal permission
    store.
  + Display: Various bugfixes to multimonitor setups.
  + Mouse & Touchpad: Sync touchpad scrolling switch states
    correctly.
  + Network: Only show Bluetooth devices in Bluetooth section.
  + Online Accounts: Fix invisible widgets.
  + Wi-Fi: Fix connection names with markup not showing up.
  + Updated translations.
* Fri Mar 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Refresh patches with refresh_service osc service.
- Disable meson_test as
  gnome-control-center-disable-error-message-for-NM.patch breaks
  the tests.
* Tue Mar 19 2019 sckang@suse.com
- Rebase gnome-control-center-disable-error-message-for-NM.patch
  (bsc#1128195).
* Mon Mar 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0.1:
  + Emergency release with a fix for broken translations and the
    Display panel.
- Drop gnome-control-center-fix-crash-retrive-disksize.patch: Fixed
  upstream.
* Mon Mar 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-control-center-fix-crash-retrive-disksize.patch: info:
  Fix crashes when retrieving disk size. Patch from upstream stable
  branch, to be dropped when switching to 3.32 branch as the issue
  is fixed in a different way there.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Revert making Settings responsive; it needs more polish to
    reach the quality we want.
  + User Accounts:
  - Improve behavior when dealing with very long names.
  - Fix crashes.
  - Remove custom file size limit for avatars.
  - Allow bigger custom avatars.
  + Updated translations.
- Add pkgconfig(udisks2) BuildRequires: New dependency.
* Thu Feb 28 2019 sckang@suse.com
- Modify gnome-control-center-bring-back-firewall-zone.patch,
  Add control-center-network-fix-ce-apply-button.patch:
  network: disable the "Apply" button until a change has been made
  (glgo#GNOME/gnome-control-center!402 bsc#1040054).
* Wed Feb 27 2019 sckang@suse.com
- Add control-center-network-fix-ce-apply-button.patch:
  network: disable the "Apply" button until a change has been made
  (glgo#GNOME/gnome-control-center!402 bsc#1040054).
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Make Settings and various panels responsive.
  + Various accessibility fixes.
  + Printers: Various cleanups.
  + Region and Language: Make rows reordetable with drag and drop.
  + Sound: Redesign the Sound panel.
  + User Accounts:
  - Allow ‘Remove User’ button to be focused.
  - Round user images.
  + Updated translations.
- Add pkgconfig(gsound) BuildRequires: New dependency.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Introduce the new Applications panel.
  + Panels can now expose a custom sidebar widget.
  + Improve CI image building scripts.
  + Applications: Introduce the new Applications panel.
  + Bluetooth: Cleanup and reorganize code.
  + Display: Add Night Light slider to set temperature.
  + Network:
  - Allow Wi-Fi panel to reach narrower sizes.
  - Cleanups and smaller performance improvement preparations.
  + Notifications: Use libhandy's HdyColumn.
  + Online Accounts: Use libhandy's HdyColumn.
  + Power: Label PENDING_CHARGE state as "Not Charging".
  + Printers: Cleanups and memory leaks plugs.
  + Privacy: Use libhandy's HdyColumn.
  + Thunderbolt: Fix double-free.
  + User Accounts: Rename classes.
  + Wacom: Map Wacom-driver-specific generic IDs to 0.
  + Updated translations.
- Add pkgconfig(libhandy-0.0) BuildRequires: New optional
  dependency. This is needed to access widgets to make the shell
  adaptive.
- Add bolt Recommends: Needed for the thunderbolt panel.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Use X-GNOME-UsesNotifications on various desktop files.
  + Introduce new icon.
  + Add interative test panels.
  + Date & Time: Grey out automatic timezone.
  + Display:
  - Correctly add minor axis to snapping.
  - Correctly snap on various situations.
  + Network: Cleanup many classes.
  + Online Accounts: Track lifecycle of CcGoaPanel across async
    calls.
  + Privacy: Use templates.
  + Region and Language:
  - Use a popover instead of a dialog for input options.
  - Redesign language chooser widget.
  - Plug various leaks.
  - Major cleanups.
  + Sharing: Bind hostname entry.
  + User Accounts:
  - Use templates.
  - Do not crash when libpwquality fails.
  + Wacom:
  - Port calibrator UI to GTK.
  - Remove clutter-gtk dependency.
  + Updated translations.
- Add python3-dbusmock and python3-pytest-xvfb BuildRequires:
  Needed to run tests during build.
- Drop explicit pkgconfig(clutter-gtk-1.0) BuildRequires: Only
  needed for cheese, and that should pull it in on it's own.
* Fri Feb  8 2019 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + Display: Various bugfixes.
  + Network: Move AP list population into an idle handler.
  + Power: Fix device label alignment.
  + Thunderbolt: Fix double free in bolt client.
  + Universal Access: Reverse Repeat Keys Speed direction.
  + Updated translations.
* Thu Nov  1 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Display:
  - Hide unsupported resolutions again.
  - Improve snapping.
  - Stop night light dialog being destroyed twice.
  + Online Accounts: Track the lifecycle of CcGoaPanel across async
    calls.
  + Region: Fix double-free when closing the input chooser dialog.
  + Wi-Fi: Disable periodic scan only when Wi-Fi is disabled.
  + Updated translations.
* Tue Oct 23 2018 sckang@suse.com
- Add gnome-control-center-periodic-wifi-scan.patch: Request
  periodic Wi-Fi scans (bsc#1097347, bgo#793647).
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix crash in the object cache system.
  + Color: Fix fallout from GtkTemplate port.
  + Power: Do not crash when canceling KDB brightness proxy
    creation.
  + Region:
  - Do not release locale keys in IM hash table.
  - Plug leaking GFile objects.
  - Replace tab characters by whitespaces.
  - Fix language section not marked as insensitive.
  - Cancel async permission when panel is closed.
  + Sharing: Bind hostname entry from UI.
  + Updated translations.
* Fri Sep  7 2018 luc14n0@linuxmail.org
- Update to version 3.30.0:
  + Updated translations.
- Enable tests run to increase QA of package.
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Fix a couple of memory leaks in the tests.
  + Don't hardcode Python path in tests.
  + Stop aggressively caching D-Bus objects not related to
    hardware.
  + CI: Improve Flatpak job.
  + User Accounts:
  - Silence some compiler warnings.
  - Remove stub string from translation.
  + Wacom: Remove unused widgets from the .ui file.
  + Wi-Fi: Fix a potential crash.
  + Updated translations.
- Drop gnome-control-center-remove-implicit-language-setting.patch:
  Fixed upstream.
* Fri Aug 17 2018 yfjiang@suse.com
- Add gnome-control-center-remove-implicit-language-setting.patch:
  user-accounts: remove implicit language setting when a new user
  navigating the user panel at the first time (bsc#1078968, commit
  a1066a2).
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Use symbolic icons in Shell search.
  + Network: Better device names.
  + Power: Improve wording of some strings.
  + Region & Language: Make Language Chooser dialog implement
    mockups.
  + Wi-Fi: Improve Airplane Mode.
- No longer export ACLOCAL_FLAGS="-I libgd" to buildroot, no longer
  needed.
- Drop removal of .la files, we are using meson buildsystem now, so
  no longer needed.
- Disable gnome-control-center-disable-error-message-for-NM.patch:
  This downstream patch needs rebase.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 3.29.4:
  + Introduce Dynamic Panel.
  + Many code cleanups and modernizations.
  + CI:
  - Support for multiarch builds (ARMv8 and PPC64).
  - Support generating Flatpaks on demand.
  + Display: Improve display arrangement widget.
  + Network: Add a testsuite.
  + Sharing: Expose Remote Desktop work on Wayland.
  + User Accounts:
  - Use term "Confirm" instead of "Verify".
  - Use the same phrase when passwords do not match.
  + Wacom:
  - Hide when no Wacom devices are connected.
  - Remove deprecated APIs.
  + Wi-Fi: Hide when no Wi-Fi adapters are available.
- Add pkgconfig(libsecret-1) BuildRequires: New dependency.
- Drop control-center-ignore-unmanaged-wifi-devices.patch and
  gcc-user-accounts-Force-symlink-creation.patch: Fixed upstream.
* Mon Jul 23 2018 dimstar@opensuse.org
- Help translation-update-upstream finding the right gettext domain
  name: pass "po gnome-control-center-2.0" to the call.
* Wed Jul 11 2018 bjorn.lie@gmail.com
- Add gcc-user-accounts-Force-symlink-creation.patch:
  user-accounts: Force symlink creation. So that we can run
  Settings more than once in GNOME Builder. Without the -f flag, ln
  errs out after these symlinks are created, and Builder refuses to
  run after that (glgo#GNOME/gnome-control-center#107).
* Fri Jun 22 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Improve logging engine.
  + Add an object caching mechanism.
  + Display: Fix a few crashers.
  + Power: Fix showing approximate percentages.
  + Thunderbolt: Introduce new Thunderbolt panel.
  + User Accounts: Fix hint for wrong enterprise user/password.
* Sat Jun  2 2018 bjorn.lie@gmail.com
- Drop pkgconfig(gconf-2.0) BuildRequires: No longer needed, nor
  used.
* Tue May 29 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Don't pass --overview on desktop file.
  + Display: Fix crashes on Night Light dialog.
  + Network: Fix various Bluetooth and VPN issues.
  + User Accounts:
  - Fix building without Cheese.
  - Fix wrong enterprise user/password hint.
  + Updated translations.
* Fri May 25 2018 sckang@suse.com
- Add control-center-ignore-unmanaged-wifi-devices.patch:
  wifi: only manage Wi-Fi devices managed by NM (bsc#1079320).
* Sat May 12 2018 lnussel@suse.de
- BuildRequire translation-update-upstream also for Leap
* Tue May  8 2018 qkzhu@suse.com
- Drop gnome-control-center-890979-change-remote-passwd.patch:
  Remote password could be changed without this patch.
- Enable gnome-control-center-info-never-use-gnome-software.patch,
  gnome-control-center-more-power-button-actions.patch and
  gnome-control-center-bring-back-firewall-zone.patch in Leap15
  (bsc#1091305).
* Tue May  8 2018 sckang@suse.com
- Add control-center-fix-crash-due-to-object-name-clashes.patch and
  control-center-fix-crash-opening-hidden-network.patch: fix crash
  due to object name clashes in NM and g-c-c
  (bsc#1083668, bgo#785099).
- Add control-center-sharing-fix-margin-issue.patch: set end margin
  for labels in Networks list box (bsc#1087134).
* Thu Apr 26 2018 mgorse@suse.com
- Add gnome-control-center-users-empty-state.patch and
  gnome-control-center-fix-users-crash.patch: fix crash opening
  users as root (bsc#1087583 bgo#773673).
* Tue Apr 17 2018 bjorn.lie@gmail.com
- Drop pkgconfig(libnm-glib-vpn) and pkgconfig(libnm-gtk)
  BuildRequires: No longer needed, nor checked for by meson.
* Wed Apr 11 2018 luc14n0@linuxmail.org
- Update to version 3.28.1:
  + Keyboard: Make "Set Shortcut" button accessible.
  + Online Accounts: Remove pending account when closing the panel.
  + Printers: Fix crash when panel is closed quickly.
  + User Accounts: Prevent freezes caused by external cameras.
  + Updated translations.
- Drop update-desktop-files BuildRequires: it is no longer required
  anymore.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Network: Don't crash when connecting to hidden networks.
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Network:
  - Use monospace font for Wi-Fi hotspot password.
  - Add a new empty page for Wi-Fi when no adapter is found.
  - Don't show "Auto-connect" option for VPNs.
  + Power: Don't treat device batteries as power supplies.
  + Printers:
  - Add new command line actions: "authenticate-jobs" and
    "show-jobs".
  - Add authentication dialog for print jobs.
  - Improve code robustness.
  + User Accounts: Don't show legacy faces.
  + Updated translations.
- Rebase gnome-control-center-disable-error-message-for-NM.patch.
- Drop gnome-control-center-icon-name.patch: fixed upstream.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb 19 2018 dimstar@opensuse.org
- Add gnome-control-center-icon-name.patch: Fix the icon names as
  installed to the system (glgo#GNOME/gnome-control-center#3).
* Tue Feb  6 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Split the window decorations between the header bars.
  + Disable the menubar. And drop the old shell.
  + Allow search to be filtered by panel "keywords".
  + Port to meson build system and drop autotools.
  + Make Bluetooth, Network, and Wacom panels mandatory on Linux.
  + Remember the last used panel.
  + Info: Ignore more virtual filesystems.
  + Network:
  - Make asynchronous calls cancellable;
  - Allow empty 802.1x certificate passwords;
  - Avoid crashing if NM reports no devices or no connections;
  - Consider empty IPv6 gateway to be valid;
  + Notifications: Add link to help/documentation.
  + Power:
  - Add gaming input devices label;
  - Add 20 and 25 minutes suspend timeouts (complying with EU
    energy regulations).
  + Printers:
  - Stay backwards compatible with old cups;
  - Don't show the supply level bar if there's no ink info.
  + Privacy: Add link to Location Services privacy policy.
  + Sound:
  - Update art work (new icons);
  - Respect setting (gsetting) for allowing output volume over
    100%%;
  - Update gvc to not require ALSA support.
  + User Accounts:
  - Fix password strength check;
  - Update user face pictures (new pictures);
  - Introduce a new avatar chooser popover.
  + Wacom: Add support for three-button styli.
  + Updated translation.
- Add meson BuildRequires, replace configure/make/make_install
  macros with meson/meson_build/meson_install and remove call for
  gnome-autogen.sh. All of these changes reflect the upstream port
  to Meson build system.
- Add gobject-2.0, gthread-2.0 and gdk-wayland-3.0 pkgconfig
  modules and xsltproc BuildRequires avoiding implicit
  dependencies.
- Drop gnome-common BuildRequires: it's no longer required anymore.
- Port gnome-control-center-bring-back-firewall-zone.patch's
  autotools-based chunk to Meson build system.
- Drop gnome-control-center-follow-polkit-permissions-for-tz.patch:
  merged upstream.
- Remove control-center-network-add-domain-suffix-match.patch's
  first part: merged upstream.
* Thu Dec  7 2017 fezhang@suse.com
- Drop gnome-control-center-allow-extra-tools-in-shell.patch and
  gnome-control-center-add-alacarte-for-sle.patch: The new UI
  doesn't have a main window with all icons any more (bsc#1071214).
* Wed Nov  1 2017 luc14n0@linuxmail.org
- Drop %%glib2_gsettings_schema_requires macro: the functionality
  now is  covered by file triggers.
* Wed Nov  1 2017 dimstar@opensuse.org
- Update to version 3.26.2:
  + Background: Fix background preview with newer gtk+ versions.
  + Info: Fix opening the panel from the .desktop file.
  + Network:
  - Don't require a private key password for TLS connections.
  - Avoid a crash with the proxy dialog.
  - Avoid crashing if NM doesn't report any devices or
    connections.
  + Notifications: Add help link.
  + Printers: Fix compilation with cups versions < 1.7.
  + Privacy: Fix the Empty Trash button.
  + Sound: Fix random selection of input/output device when the
    selected one is removed.
  + Wifi: Fix help link.
  + Updated translations.
* Wed Oct 25 2017 sckang@suse.com
- Add gnome-control-center-bring-back-firewall-zone.patch:
  network: Bring back the firewall zone combo box  to select proper
  firewall zone for each connection (fate#316719).
* Tue Oct 10 2017 sckang@suse.com
- Add control-center-network-add-domain-suffix-match.patch:
  wifi: Add domain-suffix-match entry (bgo#787882, bsc#1047509).
* Mon Oct  9 2017 sckang@suse.com
- Rebase gnome-control-center-disable-error-message-for-NM.patch
  on 3.26.1.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Honor OnlyShowIn/NotShowIn in panel desktop files.
  + Make alternative window decoration layouts work with the new
    split header bar.
  + Background: Improve panel responsiveness.
  + Color: Ensure a reasonable minimum height.
  + User Accounts: Fix password strength check.
  + Wifi: Prevent some potential crashes.
  + Updated translations.
* Wed Sep 13 2017 zaitor@opensuse.org
- Drop conditional and currently not applied
  gnome-control-center-probe-radius-server-cert.patch: All upstream
  bugs closed as fixed, so we do not need this anymore. Following
  this drop conditional NetworkManager(cacert-patch) Requires.
- Drop all suse_update_desktop_file macros, no longer needed.
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Sat Sep  9 2017 jengelh@inai.de
- Remove --with-pic which is a no-op due to --disable-static.
- Avoid running fdupes across hardlink boundaries.
  One summary grammar fix.
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 3.25.92.1:
  + Fix inability to run Settings shell caused by a broken
    translation.
  + Updated translations.
- Drop gnome-control-center-fix-finish-translation.patch: Fixed
  upstream.
* Fri Sep  1 2017 zaitor@opensuse.org
- Clean up the SLE patches structure, only keep what makes sense
  for openSUSE, move the rest to patch tag PATCH-FEATURE-SLE.
* Fri Sep  1 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + A few more layout adjustments for the new shell.
  + Make Devices and Details rows selectable.
  + Crash and memory leak fixes.
  + Display:
  - Fix the two output UI to start with the current
    configuration.
  - Ensure we generate the UI initially on two output mode.
  - Don't show inactive monitors in the arrangement widget.
  - Show refresh rates with two digits after the radix.
  - Round the displayed scale values logically.
  - Fix some valid scaled multi monitor layouts being rejected by
    mutter.
  + Sharing: Add Wayland screen sharing support - only shown if
    mutter advertises the capability.
  + Updated translations.
- Add gnome-control-center-fix-finish-translation.patch: Fix the
  finish translation, it broke the build.
* Thu Aug 31 2017 zaitor@opensuse.org
- Drop since a long time obsolete gnome-menus Requires.
* Wed Aug 23 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Several small UI improvements and layout adjustments.
  + Various crash fixes.
  + Updated translations.
- Disable gnome-control-center-disable-error-message-for-NM.patch
  again, needs rebase.
* Wed Aug 16 2017 sckang@suse.com
- Rebase gnome-control-center-disable-error-message-for-NM.patch
  on 3.25.90.
* Tue Aug 15 2017 fezhang@suse.com
- Rebase SLE / Leap patches and set applied suse_version to 1500:
  + gnome-control-center-allow-extra-tools-in-shell.patch.
  + gnome-control-center-info-never-use-gnome-software.patch.
  + gnome-control-center-more-power-button-actions.patch.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Changed to a new shell design with a side bar to switch panels.
  + The info panel was split into default apps, overview and
    removable media.
  + Fixed Toronto being translated as Tortola in some locales.
  + Display: Redesigned.
  + Network: Redesigned.
  + Power: Restore Power Off option for Power Button.
  + Updated translations.
- Disable gnome-control-center-allow-extra-tools-in-shell.patch and
  gnome-control-center-disable-error-message-for-NM.patch: Needs
  rebase.
* Sat Jul 22 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + A new Wi-Fi panel is introduced replacing the corresponding
    functionality in the Network panel.
  + Bluetooth: Center empty states in the panel.
  + Display: Adapt to new Mutter interface with scaling per mode.
  + Keyboard:
  - Fix several memory leaks.
  - Follow the usual search pattern for filtering.
  - Consider additional bindings in uniqueness checks.
  - Consider multiple bindings when resetting.
  + Network:
  - Replace the notebook with a stack.
  - Stop managing wi-fi devices.
  + Printers: Fix a crash when the user cancels the add new printer
    dialog.
  + Region & Language:
  - Embed "Restart session" button below the Language entry.
  - Make the "Restart" notification persist until the session
    restarts.
  + Wacom:
  - Make the calibrator only reactive to the tablet being
    calibrated.
  - Fix undesired cursor offsets after the calibration is
    applied.
  - Recognize and pair pad devices with others on the same
    tablet.
- Stop handling glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un) in
  post(un), we have file-triggers taking care of this for us now.
- Drop obsolete clean section.
* Sat Jul 22 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Fix memory leaks
  + Background: handle EXIF orientation in chooser
  + Network:
  - Reduce connection editor dialog width.
  - Rely on notebook tabs to switch connection editor pages.
  - Align details page labels at start.
  - Move checkboxes to Details page.
  - Drop Reset page.
  - Adapt forget button label according to connection type.
  - Move Security page to the end.
  - Use radio buttons instead of a combobox in IP pages.
  - Avoid crashing if the NMDevice doesn't have a hw-address.
  - Simplify the ignored Network interface types.
  + Online Accounts:
  - Move the margins and spacing lower down the hierarchy.
  - Increase the spacing above the "Remove Account" button.
  + Printers:
  - Don't block when removing printers.
  - Allow undoing deletion of a printer.
  - Add 10s timeout for printer removal.
  - Scroll view to show newly added Printer.
  - Move options dialog spinner out of the action area.
  - Add print "Test Page" button to Options Dialog.
  - Hide supply level bar when there is no inklevel data.
  + Region & Language:
  - Make the input source chooser back button activate on click.
  - Don't return the input chooser dialog if nothing is selected.
  - Avoid starting with a gap at the bottom of the input chooser.
  + Updated translations.
* Sat Jul 22 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Memory leak and correctness fixes.
  + Add keywords to several panels to ease search.
  + Make more dialogs use headerbars.
  + Display:
  - Fix blurry icons in night light dialogue.
  - Add support for mutter's new display config API.
  + Info:
  - Fix total disc size for btrfs subvolumes.
  - Split up "Base system" and "OS type" to separate lines.
  + Keyboard:
  - Discard the added shortcut on Escape.
  - Allow searching for shortcut accelerators.
  + Network:
  - Fix SSID not changing when enabling hotspot.
  - Fix initial state of Wi-Fi device when using Hotpost.
  - Update wireless-security from network-manager-applet.
  - Fix mobile broadband switch state.
  - Remove support for firewalld zones.
  - Update connection titles when they change.
  - Sort connections by title.
  + Notifications: Forward notification settings to portal.
  + Printers:
  - Add search capabilities to the panel.
  - Improve panel layout.
  - Allow printer model label to ellipsize.
  - Don't block on the network in the jobs dialogue.
  - Add an extra button "Clean Print Heads" when available.
  - Fix possible crash when exiting Printers panel.
  + Region: Use locale aware date time formats for previewing.
  + Search: UI improvements.
  + Universal Access: Add Cursor Size selection dialogue.
  + User Accounts:
  - Fix layout in add user dialog.
  - Add strength indicator level for weak passwords.
  - Improve password hints.
  - Fix photo popup position on wayland.
  - Handle EXIF orientation.
  + Updated translations.
- Drop gnome-control-center-info-disc-size-for-btrfs.patch: Fixed
  upstream.
* Sat Jul 22 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Memory leak and correctness fixes.
  + Network:
  - Update connection titles when they change.
  - Sort connections by title.
  + Wacom:
  - Make the calibrator only reactive to the tablet being
    calibrated.
  - Fix undesired cursor offsets after the calibration is
    applied.
  - Recognize and pair pad devices with others on the same
    tablet.
  + Updated translations.
* Wed May 24 2017 zaitor@opensuse.org
- Apply gnome-control-center-more-power-button-actions.patch for
  SLE and Leap 42.x only (boo#1040245).
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Memory leak and correctness fixes.
  + Keyboard: Discard the added shortcut on Escape.
  + Network: Fix mobile broadband switch state.
  + Updated translations.
* Wed May  3 2017 fezhang@suse.com
- Add gnome-control-center-info-disc-size-for-btrfs.patch:
  Fix total disc size for btrfs subvolumes displayed in info panel,
  backported upstream commit b619f7c (bsc#890385, bsc#1037234,
  bgo#708786).
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + Fix check for existing shortcut settings.
  + Fix possible crash when exiting Printers panel.
  + Fix blurry icons in night light dialogue.
* Thu Apr 13 2017 fezhang@suse.com
- Add gnome-control-center-more-power-button-actions.patch:
  Bring back the "shutdown" and "interactive" power key actions in
  "Power" panel (bsc#993381).
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Wed Mar 15 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Universal Access: Add cursor size configuration.
  + Network:
  - Fix SSID not changing when enabling hotspot.
  - Fix initial state of Wi-Fi device when using hotspot.
  + Notifications: Forward notification settings to portal.
  + Printers:
  - Improve panel layout.
  - Allow printer model label to ellipsize.
  - Don't block on the network in the jobs dialogue.
  + Updated translations.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Display:
  - Bump dependencies for Night Light schemas.
  - Really fix typo in "Tomorrow".
  - Tweak night light dialog UI to match latest mockups.
  + Online Accounts: New panel design.
  + Printers:
  - Make the printer address always sensitive.
  - Do not apply rename/location changes in focus-out-event.
  - Don't block when renaming printers.
  - Ellipsize the "Details Dialog" title and the "location" in
    the printer entry.
  - Tweak the printer supply level bar.
  - Subscribe to jobs notifications.
  - Count only current user's jobs.
  + Privacy: Set destructive-action for confirmation buttons only.
  + User Accounts: Fix crash when name is changed and dialogue
    closed.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + New Printers, User Accounts and Online Accounts designs.
  + Keyboard shortcuts bug fixes.
  + Add "Night Light" functionality to Display settings.
  + Add Wayland support to Wacom settings, and update design.
- Drop
  gnome-control-center-display-fix-possible-crash-on-startup.patch:
  fixed upstream.
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Display: Ensure the preselected resolution matches the current
    mode.
  + Keyboard: Fix capture of Alt+PrintScreen shortcuts.
  + Updated translations.
- Drop gnome-control-center-printers-fix-compilation-warning.patch:
  Fixed upstream.
* Sat Sep 24 2016 zaitor@opensuse.org
- Add gnome-control-center-printers-fix-compilation-warning.patch:
  Adapt to changes in cups.
- Add
  gnome-control-center-display-fix-possible-crash-on-startup.patch:
  Display: Fix possible crash on startup (bgo#771875).
- Stop passing V=1 to make, we do debugging locally.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Network:
  - Only show a gateway entry for the first IPv4 address,
    NetworkManager ignored every subsequent ones, but we still
    had a UI for those.
  - Fix application of the default gateway.
  - Fix possible crashes when editing IPv4 gateways or routes.
  + Power:
  - Fix "automatic suspend" label not taking batteries into
    account.
  - Fix initial state of the Wi-Fi switch.
  + Updated translations.
* Sun Sep 18 2016 fezhang@suse.com
- Rebase gnome-control-center-890979-change-remote-passwd.patch on
  3.21.92.
* Fri Sep 16 2016 fezhang@suse.com
- Add gnome-control-center-info-never-use-gnome-software.patch:
  On SLE12-SP2 and Leap42.2, never search for gnome-software as an
  option when checking for updates in info panel, because we use
  gpk-update-viewer (bsc#999336).
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Privacy: Fix quoting of distro name and privacy URL.
  + Network:
  - Fix warning when enabling hotspot.
  - Fix saving of IPv6 gateway.
  - Fix warning if IPv6 gateway is empty.
  - Fix IPv6 settings not being applicable when method changes.
  - Return better error when 8021x security is invalid.
  - Avoid warning when ad-hoc mode is invalid.
  - Re-set the SSID when enabling the Hotspot.
  - Fix crash when changing IPv4 DNS.
  + Keyboard:
  - Many UI changes following up from the panel redesign.
  - Don't grab the mouse pointer when capturing shortcuts.
  - Don't regrab the keyboard after an event if already grabbed.
  - Fix grabs not working when initially showing the dialog.
  - Don't apply "Backspace" straight away.
  - Allow Tab and Super in accels.
  - Normalise Shift and Tab in shortcuts.
  - Fix shortcut label in RTL languages.
  + Region: Avoid a crash on panel destruction.
* Thu Sep  8 2016 dimstar@opensuse.org
- Rebase and re-enable
  gnome-control-center-allow-extra-tools-in-shell.patch.
* Wed Sep  7 2016 zaitor@opensuse.org
- Disable gnome-control-center-allow-extra-tools-in-shell.patch:
  Needs rebase.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Tue Sep  6 2016 dimstar@opensuse.org
- Drop gnome-control-center-hide-firewall-zone-entry.patch: no
  longer needed, since upstream code now checks if firewalld is
  running and hides the widgets dynamically.
* Sat Sep  3 2016 fezhang@suse.com
- Update gnome-control-center-add-alacarte-for-sle.patch:
  Rebase on top of rebased
  gnome-control-center-allow-extra-tools-in-shell.patch.
* Fri Sep  2 2016 fezhang@suse.com
- Update gnome-control-center-allow-extra-tools-in-shell.patch:
  + Fix leak of strings.
  + Add tools with category X-GNOME-DesktopSettings into the
    personal g-c-c category to enable itweb-settings.
  + Disable logspam in absence of optional components (bnc#866235
    bsc#952008).
* Wed Aug 31 2016 zaitor@opensuse.org
- Drop Mesa-demo-x Requires: No longer needed. Fixes boo#996633.
* Wed Aug 31 2016 zaitor@opensuse.org
- Drop long disabled and no longer needed patches:
  + gnome-control-center-system-proxy-configuration.patch.
  + gcc-private-connection.patch.
* Fri Aug 26 2016 badshah400@gmail.com
- Update to version 3.21.90:
  + Fix truncated panel names for larger fonts.
  + Port to libnm 1.2.
  + Display:
  - Add option to enable and disable overscan compensation when
    supported by the driver.
  - Ensure only one output is set as primary.
  - Separate interlaced from normal modes.
  + Info:
  - Fetch renderer information from gnome-session.
  - Show OS build-id.
  + Keyboard: Update to a new design.
  + Mouse:
  - Show only relevant widgets for the hardware we're able to
    detect.
  - Detect and warn if we're running on the synaptics driver.
  - Make all listbox rows unactivatable.
  - Remove superfluous GtkListBoxRow.
  - Allow keyboard navigation/focus to the Touchpad section
    switches.
  - Offer a separate option for edge scrolling.
  - Don't allow two-finger and edge scrolling at the same time.
  + Network:
  - Use VPN plugin paths as specified in the .name files.
  - Ensure the Wifi list is updated as networks appear/disapper.
  - Hide firewall zone combo when firewalld is not running.
  - Remove bridge, bond, team, VLAN and virtual devices support
    these are most useful on non-desktop systems for which a UI
    like Cockpit is better suited.
  - Remove the first page of the "Add Connection" wizard.
  - Update wireless-security UI from network-manager-applet.
  - Remember "Ignore CA certificate".
  - Fix removed connections not disappearing.
  - Fix hotspot silently failing with long hostname.
  - Fix several crashes.
  + Online Accounts:
  - Don't use deprecated GoaProviderGroup API.
  - Add a Calendar group.
  - Let goa_provider_show_account create the full UI.
  + Power:
  - Translate the "When the Power Button is pressed" drop-down.
  - Show "Suspend & Power Off" section only when relevant.
  + Printers:
  - Add compatibility code for older cups.
  - Use a panel wide page for empty state.
  - Present spinner while populating the panel.
  - Rename printers asynchronously.
  - Added new async API to check availability of maintenance
    commands.
  - Check all supported CUPS commands, not just the first one.
  + Privacy:
  - React to changes in permissions store.
  - Various layout and cosmetic cleanups.
  + Region:
  - Reset the input chooser on escape.
  - Improve widget spacing.
  + Search:
  - Work around applications not shipping icons at all sizes.
  - Introduce the new Search Locations dialog.
  + Sharing: Update to a new design.
  + Universal Access:
  - Specify a window when testing visual bell.
  - Correct label for "Sound Keys".
  - Allow keyboard navigation/focus to the settings switches.
  + User Accounts:
  - Update to a new design.
  - Fix missing records in the history dialog.
  + Updated translations.
- Drop gnome-control-center-touchpad-wayland-cap.patch;
  incorporated upstream.
- Set define with_cacert_patch to 0,
  gnome-control-center-probe-radius-server-cert.patch needs rebase.
* Tue Jul 26 2016 sckang@suse.com
- Add gnome-control-center-disable-error-message-for-NM.patch:
  Improve the check whether NM or wicked is running, so it won't
  show an error about NM on systems where wicked instead of NM is
  being used (bsc#989801).
* Fri Jul  8 2016 dimstar@opensuse.org
- Drop pkgconfig(libsystemd-login) BuildRequires: this dependency
  has ot been in use since version 3.7.4.
* Mon May 30 2016 fcrozat@suse.com
- Move online accounts panel to a separate subpackage and ensure
  gnome-online-accounts is required by this subpackage (icons are
  provided by it). Add Supplements to ensure it will be pulled when
  gnome-online-accounts is installed. (FATE#318572)
* Fri May 20 2016 zaitor@opensuse.org
- Add gnome-control-center-touchpad-wayland-cap.patch: mouse: Make
  touchpad capability checking on wayland work as intended
  (bgo#765879).
* Mon Apr 18 2016 mgorse@suse.com
- Don't require NetworkManager for SLE. It isn't used on SLES.
* Mon Apr 18 2016 alarrosa@suse.com
- Adjust BuildRequired versions according to configure:
  + gsettings-desktop-schemas >= 3.19.3.
  + gnome-settings-daemon >= 3.19.1.
* Thu Apr 14 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Translate the "When the Power Button is pressed" drop-down.
  + Fix a number of build warnings.
  + Fix crash opening Wacom panel under Wayland.
  + Fix Wi-Fi list being empty when enabled within the Network
    panel.
  + Throw an error when using the Synaptics touchpad driver.
  + Add support for older versions of CUPS.
  + Hide firewall zone combo when firewalld isn't running.
  + Fix the visual bell test not working in some cases.
  + Updated translations.
- Drop 0001-network-Fix-empty-Wifi-list.patch: Fixed upstream.
* Tue Apr 12 2016 fezhang@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop commit-0f5e433: fixed upstream
- Drop commit-23c4ea2: fixed upstream
- Drop commit-a53065d: fixed upstream
- Drop commit-b242a00: fixed upstream
- Drop commit-ccebd62: fixed upstream
- Drop commit-d2074fa: fixed upstream
- Drop commit-eed8f71: fixed upstream
- Drop gnome-control-center-bnc862415-timezone.patch:
  Fixed upstream (bnc#862415).
- Drop gnome-control-center-bnc865632-disable-popup-for-NM.patch:
  Fixed upstream (bnc#865632).
- Drop
  gnome-control-center-bnc894394-hide-firewall-zone-entry.patch:
  Fixed upstream (bnc#894394).
- Drop gnome-control-center-bnc947761-fix-color-dialog-translations.patch:
  Fixed upstream (bnc#947761).
- Drop gnome-control-center-change-password-i18n.patch:
  Fixed upstream (bnc#880303).
- Drop gnome-control-center-datetime-i18n.patch:
  Fixed upstream (bnc#884425 bgo#732585).
- Drop gnome-control-center-display-login-region.patch:
  Fixed upstream (bsc#955322).
- Drop gnome-control-center-fix-wifi-list.patch:
  Replaced by 0001-network-Fix-empty-Wifi-list.patch (bsc#870322).
- Rebase gcc-private-connection.patch (bnc#751211).
- Rebase gnome-control-center-allow-extra-tools-in-shell.patch
  (bnc#866235).
- Rebase gnome-control-center-probe-radius-server-cert.patch:
  Toggle with_cacert_patch to 1 to enable it (bnc#574266).
* Tue Apr 12 2016 zaitor@opensuse.org
- Set define with_cacert_patch to 0, needed now since we have
  non-rebased patches in NetworkManager.
* Wed Mar 30 2016 sckang@suse.com
- Add 0001-network-Fix-empty-Wifi-list.patch: Fix Wifi list not
  showing APs correctly (bsc#870322, bgo#709641).
* Thu Mar 24 2016 sckang@suse.com
- Add gnome-control-center-fix-wifi-list.patch:
  Fix Wifi list not showing APs correctly (bsc#870322).
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + All: Dialogues sizing fixes.
  + Color: Fix dialogue title not being translated.
  + Display: Add a frequency/refresh rate drop-down.
  + Privacy:
  - Fix margins around location dialogue widgets.
  - Better description for 'Location Services'.
  - Vertically center "Location Services" label.
  - Only disable apps switches, not the whole row.
  + Printers:
  - Drop border of the "Add" new printer button.
  - Fix manual PPD selection dialogue not having a parent.
* Fri Mar  4 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Privacy: Add Location Services permissions for sandboxed
    applications.
  + Printers: Fix a lot (but not all) of possible hangs.
  + Universal Access: Fix empty panel when using newer GTK+.
  + User accounts: Don't link directly to GStreamer.
- Drop pkgconfig(gstreamer-1.0) BuildRequires: no longer needed.
* Sat Feb 20 2016 dimstar@opensuse.org
- Drop nautilus requires: nothing in g-c-c depends on nautilus'
  presence.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Network:
  - Prevent secrets from getting lost on each connection edit.
  - Fix a crash when clicking to forget a VPN on the editor.
  + Printers: Redesign the Printer Jobs Dialog.
  + Region & Language: Prevent a potential crash when exiting the
    panel.
  + Wacom: Workaround deadlocks in Clutter event handlers.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.5:
  + Added plenty of missing widget mnemonics for better UI keyboard
    navigation.
  + Bluetooth:
  - Avoid broken state when enabling Bluetooth.
  - Don't change the switch status when transitioning.
  - Bump required gnome-bluetooth version to 3.18.2.
  + Network: Elipsize device metadata fields.
  + Region & Language: Ensure that system and user formats are
    consistent.
  + Sharing: Ensure Tracker rygel plugin is disabled.
  + Wacom: Avoid crashing when opening the panel on wayland
    sessions.
  + Updated translations.
* Mon Dec 28 2015 qzhao@suse.com
- Add gnome-control-center-display-login-region.patch:
  Fix bug login language button in region list disappear
  (bsc#955322).
* Mon Dec 21 2015 damjanovic.ivo@gmail.com
- Update to version 3.19.4:
  + Port to newer Grilo 0.3.0 API.
  + Build fix: Update grl_registry_load_plugin_by_id API change.
- Replace pkgconfig(grilo-0.2) BuildRequires with
  pkgconfig(grilo-0.3), following upstream port to Grilo 0.3 API.
* Mon Dec 14 2015 badshah400@gmail.com
- Rebase
  gnome-control-center-follow-polkit-permissions-for-tz.patch to
  apply cleanly against g-c-c 3.18.2; re-enable patch in specfile
  (boo#956879).
* Mon Dec 14 2015 badshah400@gmail.com
- Modify gnome-control-center-allow-extra-tools-in-shell.patch to
  not include alacarte in the control center any longer, this
  stopped working on gnome-shell a long time ago (boo#901843,
  bgo#734237).
- SLE still requires alacarte in their g-c-c, so add separate
  patch gnome-control-center-add-alacarte-for-sle.patch and apply
  it only for SLE 12 for now.
* Mon Nov 30 2015 fezhang@suse.com
- Add gnome-control-center-bnc947761-fix-color-dialog-translations.patch
  Fix the unlocalised heading on the Add Profile dialog on Color
  panel (bnc#947761).
* Tue Nov 10 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Build fixes.
  + Fix a number of memory leaks.
  + Updated translations.
- Drop gnome-control-center-fix-desktop-file-trans.patch and
  gnome-control-center-fix-nb-tans.patch: Fixed upstream.
* Tue Oct 20 2015 qzhao@suse.com
- Fix bug The keyboard display window missed (bnc#951122)
  Add require libgnomekbd in spec file.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix a crash when disabling Sharing.
  + Make section headings accessible in Universal Access, and
    Region & Language.
  + Fix a warning about an unparented dialogue in the Printers
    panel.
  + Updated translations.
- Add gnome-control-center-fix-desktop-file-trans.patch: Fix syntax
  errors in gnome-sharing-panel.desktop translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Build fixes.
  + Power: Fix "automatically brightness" setting not showing up.
  + Printers: Fix crash when certain characters were used, adding a
    printer manually.
  + Region & Language:
  - Show the current locale instead of en_US as the language if
    not already set. This happened for newly created users.
  - Fix keyboard navigation in the input chooser.
  + User Accounts: Don't crash if GDM isn't installed.
  + Updated translations.
* Fri Sep  4 2015 dimstar@opensuse.org
- Rebase gnome-control-center-allow-extra-tools-in-shell.patch.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Date & Time: Support for new "Pyongyang Time".
  + Network:
  - Rename hotspot security key to "Password".
  - Fix unintentionally centered checkbutton labels.
  + Notifications: Don't crash because of zero-length string.
  + Power:
  - Improve labels for wifi and mobile broadband toggles.
  - Replace WiMax reference with LTE.
  + Printers: Fix a problem where the wrong printer driver would
    get installed.
  + Region and Language: Don't ever show all input sources in the
    chooser.
  + Sharing:
  - Accessibility improvements.
  - Remove "Bluetooth" (Obex) sharing, moved into the
    Bluetooth panel.
  - Better UI when Bluetooth is disabled.
- Rebase gnome-control-center-fix-nb-tans.patch.
- Drop gnome-control-center-Pyongyang-Time.patch and corresponding
  source files, no longer needed.
* Mon Aug 31 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Shell: Plenty of command-line options handling fixes.
  + Date & Time:
  - Show date buttons in the order that the locale uses them.
  - Further date button ordering fixes for Cechen and HK English.
  - Fix incorrect sensitivity when permission is missing.
  - Fix accessibility of the hour and minutes spinbuttons.
  + Display:
  - Don't show rotation for builtin display on tablets.
  - Add support for tiled monitors (usually 4K monitors).
  + Network:
  - Fix all Wi-Fi networks having gear buttons.
  - Only share a new wifi connection if the user is allowed to.
  - Fix possible crash when changing airplane mode.
  - Fix possible crash when connections change after Network
    panel was closed.
  + Power:
  - Describe batteries properly when not called BAT0.
  - Fix possible crash if up_client_get_devices() fails.
  - Make the automatic suspend row accessible.
  + Printers:
  - Fix possible crash after closing the panel.
  - Set focus of the 'New printer dialog' correctly.
  - Fix focus chain of the 'New printer dialog'.
  - Install selected printer when the row is activated.
  - Fix setting of page size.
  - Don't expand search entry.
  - Show border around 'No printers detected' text.
  - Don't show the same device multiple times.
  + Region & Language: Fixes to the region and language lists.
  + Sharing: Make it possible to override SSHD_SERVICE for
    Debian-based systems.
  + Sound: Support more channels in speaker test.
  + User Accounts: Fix enterprise user login never working.
  + Wacom: Fix window decorations being visible in calibrator
    window.
- Temp disable
  gnome-control-center-allow-extra-tools-in-shell.patch,
  gcc-private-connection.patch and
  gnome-control-center-follow-polkit-permissions-for-tz.patch:
  Needs rebase.
* Mon Aug 31 2015 dimstar@opensuse.org
- Update to version 3.17.2:
  + Keyboard: Honor immutable command/name in custom commands.
  + Network:
  - Make the gear buttons round.
  - Prevent a use after free crash when removing virtual devices.
  + Power:
  - Add support for display dimming using an ambient light
    sensor.
  - Hide Bluetooth power section when w/o BT.
  - Remove "When battery power is critical" label which isn't
    configurable by normal users since UPower 1.0.
  + Updated translations.
- Rebase gnome-control-center-hide-firewall-zone-entry.patch and
  gcc-private-connection.patch.
* Sun Aug 30 2015 dimstar@opensuse.org
- Ensure ./panels/common/gsd-common-enums.h is created before
  starting the full make process. In some rare cases, parallel
  build triggers this file too late.
* Wed Aug 19 2015 dimstar@opensuse.org
- Toggle with_cacert_patch to 1: the patch has been rebased.
* Wed Jul 29 2015 zaitor@opensuse.org
- Add gnome-control-center-fix-nb-tans.patch: Fix translation of
  Keyboard brightness in Norwegian bokmål (bgo#753005).
* Wed Jul 22 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Date & Time: Fix accessibility of the hour and minutes
    spinbuttons.
  + Network:
  - Prevent a use after free crash when removing virtual devices.
  - Fix all Wi-Fi networks having gear buttons.
  - Only share a new wifi connection if the user is allowed to.
  - Fix possible crash when changing airplane mode.
  - Fix possible crash when connections change after Network
    panel was closed.
  + Power:
  - Hide Bluetooth power section when w/o BT.
  - Fix "When battery power is critical" label with UPower 1.0.
  - Fix possible crash if up_client_get_devices() fails.
  - Make the automatic suspend row accessible.
  + Printers:
  - Set focus of the 'New printer dialog' correctly.
  - Fix focus chain of the 'New printer dialog'.
  - Fix setting of page size.
  - Don't expand search entry.
  - Show border around 'No printers detected' text.
  - Check whether we have a device name.
  - Don't show the same device multiple times.
  + Region & Language: Fixes to the region and language lists.
- Disable gcc-private-connection.patch for now.
* Wed Jul 15 2015 zaitor@opensuse.org
- Set define with_cacert_patch to 0, stop applying
  gnome-control-center-probe-radius-server-cert.patch as it has
  been disabled in NetworkManager.
* Fri May 15 2015 antoine.belvire@laposte.net
- Keep translations in the desktop files for GNOME Shell search
  results (boo#913870):
  + Add -n (--no-i18n) to %%suse_update_desktop_file.
  + Add some missing desktop files.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix a couple of minor memory leaks.
  + Network: Prevent some dialogs from becoming too wide.
  + Notifications:
  - Make section headings accessible.
  - Do not show nameless apps.
  - Align icons.
  + Printers: Update printer options correctly.
  + Wacom: Stop using removed last-calibration-resolution gsetting.
  + Updated translations.
* Wed Apr 15 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Add AppData file so it cannot be removed in GNOME Software.
  + Color:
  - Set the default profile quality at startup.
  - Set the users profile title when generating a profile.
  - Allow to change profile color by activating the list box row.
  + Display:
  - Fix some memory leaks.
  - Close the dialog when the RR configuration changes.
  + Mouse and Touchpad:
  - Fix checking touchpad capabilities when multiple devices
    are present
  - Fix sensitivity of two-finger scroll toggle with libinput X11
    driver.
  - Fix tap-to-click toggle sensitivity with libinput X11 driver.
  + Network: Fix a crash on IPv6 settings dialog.
  + Online accounts:
  - Disable the remove button for locked accounts
  - Prevent the attention-needed icon from getting hidden and
    widen the list.
  + Power: Make section headings accessible.
  + Printers: Recognize more supply types.
  + Sound: Fix duplicated Bluetooth devices.
  + User Accounts: Show restart notification when account type
    changed.
  + Wacom:
  - Support tablets where the stylus doesn't have an eraser such
    as the Huion and UC-Logic tablets.
  - Require udev to be present to build Wayland support.
  - Fix possible crashes.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Network: Fix many reference leaks and potential crashers.
  + Online Accounts: Remove scrollbars with single entry lists.
  + Updated translations.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Revert "Disable SSLv3 because of POODLE": gnome-online-accounts
    now uses WebKit2.
  + Make HighContrast icons work
  + Network:
  - Don't save hidden configuration options.
  - Make "only for this network" work for IPv6 VPNs.
  + Power: Fix alignment of "Screen brightness" label.
  + Region:
  - Fix leak in input chooser.
  - Reuse the input chooser instance.
  + Sharing: Update help URI.
  + Sound:
  - Prevent two alerts being played at the same time under
    certain circumstances.
  - Fix visibility of bar when orientation is the same as the
    default.
  - Fix a crash when switching inputs or outputs.
  + User Accounts: Fix fingerprint delete dialog formatting.
  + Wacom:
  - Allow button mapping if the stylus has one button too.
  - test: add Huion H610 Pro panel.
  + Updated translations.
* Thu Mar 12 2015 zaitor@opensuse.org
- Update to version 3.15.91:
  + Details: Fix a possible crash with Firefox' nightly builds.
  + Display: Fix clone mode leading to broken setups in some cases.
  + Region: Add a way to sort input sources, so that the default
    source can be chosen.
  + User Accounts:
  - Don't show fingerprint options if disabled.
  - Fix possible crash handling Enterprise logins.
  + Updated translations.
* Thu Mar 12 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Common:
  - Fix build on non-Linux systems.
  - Remove list box header when remove first item.
  + Details: Fix spelling of VMware.
  + Display: Replace display labeler with gnome-shell's one.
  + Keyboard: Custom shortcut should require name and command.
  + Network: Fix possible crash when handling zone names.
  + Power:
  - Fix initial state of Bluetooth switch.
  - Fix iDevice batteries appearing before they're ready.
  - Fix ambiguous wifi and mobile broadband labels.
  + Privacy: Add automatic problem reporting setting.
  + Sharing: Don't add the folder if the dialog isn't explicity
    accepted.
  + User Accounts: Update padding on style-updated.
  + Wacom: Fix final use-stock deprecated property.
* Thu Mar 12 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Common:
  - Lots of clean ups and porting to non-deprecated GTK+ APIs.
  - Reset language chooser to original state when used the 2nd
    time.
  - Use 'UTF-8' instead of 'utf8' as locale codeset suffix
    improving compatibility with non-GNU libc's.
  - Unset sort terms when search entry is programatically
    cleared.
  - Adapted to peripheral settings schemas move to
    gsettings-desktop-schemas.
  + UI:
  - Marked several dialog suggested action buttons as such
    resulting in the intended blue shade.
  - Removed several superfluous frames.
  - Fixed several spacing issues.
  + Background: Fix crash when choosing background due to missing
    icon.
  + Network:
  - Also work with NM 1.0.
  - Display an error instead of the panel on NM absence.
  - Use a GtkStack to switch between button/spinner fixing the
    big spinners.
  + Mouse: Fixed to work on wayland sessions.
  + Notifications:
  - Force smaller icons.
  - Scroll the view not just the list.
  - Design improvements.
  + Printers:
  - Improve scrolling in new printers list.
  - Make driver installation dialog modal.
  + Privacy: Fix mnemonic widget for software switch.
  + Region: Fix a crash when iterating locales.
  + Sharing:
  - Prevent an endless loop and resulting stack overflow.
  - Put a real description string in the media dialog.
  + Universal access: Disable hover on non-clickable rows.
  + User acounts:
  - Fix enterprise accounts deleting.
  - Change default size for avatar cropping.
  - Don't crash when closing fingerprint dialog.
  - Don't show empty row for remote users.
  - Do not show notification if not needed.
  - HiDpi support for user's icons.
- Add pkgconfig(gudev-1.0) BuildRequires: new verified dependency.
* Thu Mar 12 2015 zaitor@opensuse.org
- Update to version 3.14.3 (boo#916784):
  + Background: Fix crash to missing icon.
  + Network:
  - Also work with NetworkManager 1.0.
  - Allocate storage for zone name during D-Bus call.
  + Power: Fix initial state of Bluetooth switch.
  + Printers: Remove border around model name.
  + Sharing:
  - Prevent an endless loop and resulting stack overflow.
  - Don't add the folder if the dialog isn't explicity accepted.
  - Update help URI.
  + Shell: Unset sort terms when search entry is programatically
    cleared.
  + Universal Access: Fix typo.
  + User Accounts:
  - Change default size for avatar cropping to match Cheese.
  - Don't crash when closing fingerprint dialog.
  - Don't crash when network changes.
  - Don't show empty row for remote users.
- Drop
  gnome-control-center-power-fix-initial-state-of-Bluetooth.patch
  and gnome-control-center-NM-1.0.patch: Fixed upstream.
* Thu Mar 12 2015 dimstar@opensuse.org
- Add with_cacert_patch condition. When enabled:
  + Add NetworkManager(cacert-patch) Requires
  + Apply gnome-control-center-probe-radius-server-cert.patch
  + This needs to be toggled whenever NetworkManager is updated
    and the nm-probe-radius-server-cert.patch there is not rebased
    yet.
* Wed Mar 11 2015 glin@suse.com
- Refresh gnome-control-center-probe-radius-server-cert.patch
* Fri Feb 13 2015 zaitor@opensuse.org
- Add
  gnome-control-center-power-fix-initial-state-of-Bluetooth.patch:
  The initial state of the switch was never set, so if it happened
  to be on, the switch didn't match reality (bgo#725654).
* Tue Jan 27 2015 dimstar@opensuse.org
- Add gnome-control-center-NM-1.0.patch: Add compatibility to
  NetworkManager 1.0.
- Disable gnome-control-center-probe-radius-server-cert.patch until
  NetworkManager has been fixed up again.
* Fri Nov 21 2014 zaitor@opensuse.org
- Re-enable translation-update-upstream.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Disable SSLv3 because of POODLE.
  + Background:
  - Fix possible crash when date isn't available.
  - Fix crash when adding the second color.
  + Power: Disable hover on non-clickable rows.
  + Printers: Automatically keep the selected row scrolled in view.
  + Region:
  - Make Add/Done buttons blue as intended.
  - Don't crash for locales with no country code.
  + Search: Use g_get_system_data_dirs() to discover providers.
  + Sound: Fix the main volume bars to correctly display changes in
    volume.
  + Universal Access: Make Add/Done buttons blue as intended.
  + User Accounts:
  - Fix a crash when taking a photo in the avatar chooser.
  - Reset language dialog to original state when used the 2nd
    time.
  + Updated translations.
- Drop gnome-control-center-no-country-code-crash.patch,
  gnome-control-center-user-account-cheese-crash.patch, and
  gnome-control-center-crash-when-date-unavailable.patch: Fixed
  upstream.
* Mon Nov  3 2014 badshah400@gmail.com
- Downgrade cups-pk-helper Requires to Recommends (boo#904047)
- Add gnome-control-center-follow-polkit-permissions-for-tz.patch
  to allow timezone changes by user if permitted by polkit
  permissions (boo#904058)
- Add patches from upstream for critical issues:
  + gnome-control-center-no-country-code-crash.patch: fix
    a crash for locales with no country codes (boo#904071,
    bgo#738963)
  + gnome-control-center-user-account-cheese-crash.patch:
    user-account -- do not crash while taking a picture for user
    avatar using cheese (boo#904070, bgo#697039)
  + gnome-control-center-crash-when-date-unavailable.patch:
    background -- do not crash when date is unavailable
    (boo#904073, bgo#736475).
* Fri Oct 17 2014 dimstar@opensuse.org
- Recommend the installation of dbus(com.intel.dleyna-server):
  through the online-accounts panel, it is possible to configure
  DLNA Media Servers (for gnome-photos). This feature relies on
  dleyna-server.
* Tue Oct 14 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Keyboard: Allow shortcut explanation text to wrap.
  + Network: Hide airplane switch when g-s-d says so.
  + Power: Conditionally display the bluetooth button.
  + Printers: Don't crash for URIs with leading "//".
  + Region: Obtain keyboard variant from IBus.
  + User Accounts:
  - Show correct language if it isn't set.
  - Make sure widgets are the same height.
  - Fix language chooser response if language is unknown.
  - Preset language chooser if language is known.
* Sat Oct 11 2014 dimstar@opensuse.org
- Update gnome-control-center-allow-extra-tools-in-shell.patch:
  ensure g_strconcat has a NULL Sentinel (boo#900782).
* Tue Oct  7 2014 sbrabec@suse.cz
- Fix untranslatability of "Change Password" (bnc#880303,
  gnome-control-center-change-password-l10n.patch)
- Add gnome-control-center-Pyongyang-Time.patch:
  North Korea changed its timezone to UTC+08:30.
- Add timezone_8.5.png, timezone_8.5_dim.png, timezone_9.png and
  timezone_9_dim.png as source files: patch is not willing to patch
  binary files (bsc#951590 boo#941290 bgo#753643).
* Tue Sep 30 2014 dimstar@opensuse.org
- Update gnome-control-center-allow-extra-tools-in-shell.patch:
  dconf-editor.desktop was renamed to
  ca.desrt.dconf-editor.desktop.
* Wed Sep 24 2014 badshah400@gmail.com
- Add explicit libgnomekbd Requires to fix issue with keyboard
  layout utility not showing up when "Show keyboard layout" is
  chosen from control-center or top-bar (boo#898096).
* Tue Sep 23 2014 dliang@suse.com
- Add gnome-control-center-890979-change-remote-passwd.patch:
  Enable remote user to change password in user panel (bsc#890979).
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fix restart notifications' text getting clipped under some
    translations.
  + Updated translations
- Drop gnome-control-center-bg-translation.patch: Fixed upstream.
* Sun Sep 21 2014 fezhang@suse.com
- Add gnome-control-center-hide-firewall-zone-entry.patch: Hide
  Firewall zone entry in Network panel (bnc#894394). The Firewall
  Zone entry is only activated if firewalld package is installed.
  As openSUSE doesn't have this package, the entry never works.
  So removing the entry to avoid confusions.
* Tue Sep 16 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Background:
  - Fix background chooser dialog resizing when switching views.
  - Use a stack with three views for the chooser dialog.
  - Fix memory leak in Flickr support.
  + Date & Time: Don't hard-code font size.
  + Keyboard: Fix a crash if the WM changes (or restarts).
  + Network:
  - Fix possible crash when wireless-enabled changes.
  - Fix more potential crashers for WWAN.
  - Report hotspot is running only if device is active.
  - Really hide all of the virtualisation bridges.
  - Don't show underlying device for VPN connections.
  + Sharing: Fix empty folder list by default.
  + User Accounts:
  - Fix various UI padding issues.
  - Fix focus in the account dialog.
  + Updated libgd to fix GdNotification theming
  + Updated translations.
- Add gnome-control-center-bg-translation.patch: Fix Bulgarian
  translation for Sharing desktop file.
* Tue Sep  9 2014 fezhang@suse.com
- Add gnome-control-center-bnc894394-hide-firewall-zone-entry.patch
  Hide Firewall zone entry in Network panel (bnc#894394).
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Date & Time: Fix crash when setting year to 0.
  + Network:
  - Center "Wi-Fi hotspot" properties.
  - Fix warning on startup with hotspot enabled.
  - Show an error when we fail to turn off hotspot.
  + Updated translations.
* Fri Sep  5 2014 sreeves@suse.com
- Add gnome-control-center-bnc862415-timezone.patch:
  Allow changing timezone without root privs (bnc#862415).
* Thu Aug 28 2014 fcrozat@suse.com
- Move online accounts panel to a separate subpackage and ensure
  gnome-online-accounts is required by this subpackage (icons are
  provided by it).
* Fri Aug 22 2014 glin@suse.com
- Enable gnome-control-center-probe-radius-server-cert.patch since
  the patch in NetworkManager-gnome was rebased.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Color: Do not set the 'Details' button for virtual profiles.
  + Keyboard: Suggest to automatically set reverse bindings.
  + Network:
  - Make broken configuration entries red.
  - Create WPA protected AP hotspot if supported.
  - Fix network icon names for newer versions.
  - Remove "..." from dialogue titles.
  - Add DNS to the keywords.
  - Fix typo in NetworkManager version checking.
  + Printers: Allow to add AppSocket/HP JetDirect and LPD printers.
  + Privacy: Add location setting.
  + Search: add support for default disabled search providers.
  + Sharing:
  - Fix crash in media preferences.
  - Avoid truncated folders list in media sharing.
  - Make it possible to share remote folders.
  + User Accounts:
  - fix response sensitivity of photo dialog.
  - allow password changing if old password isn't set or empty.
  - Add restart notification.
  - fix enterprise toggle.
  - prefill domain entry.
- Rebase gcc-private-connection.patch.
* Fri Aug  8 2014 sbrabec@suse.cz
- Add gnome-control-center-datetime-i18n.patch:
  Make punctuation translatable in datetime preferences (bnc#884425
  bgo#732585).
* Thu Aug  7 2014 fcrozat@suse.com
- Update gnome-control-center-allow-extra-tools-in-shell.patch:
  Improve patch (no longer need to change 3 files to add one icon)
  and add alacarte and icedtea settings to available icons.
* Thu Aug  7 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Use correct window icon.
  + Background:
  - Several small fixes.
  - Fix emblems on HiDPI.
  - Re-add drag'n'drop support.
  - Allow dropping colours as well.
  - Remember added colours.
  - Copy all the manually added backgrounds.
  + Info: Fix logo on HiDPI.
  + Keyboard: Allow "print screen" and "scroll lock" as compose key
    options.
  + Mouse: Fix scroll test background on HiDPI.
  + Notifications: Fix duplicates in application list.
  + Power: Update automatic suspend label when CanHibernate is
    false.
  + Region: Make it possible to add an input source by activating
    its row.
  + Sharing:
  - Add maximum height for the networks list box.
  - Use the selected URI from the file chooser, instead of the
    current directory.
  + User Accounts: Do not generate previews for directories.
  + Wacom:
  - Fix x/y ranges' swapping when calibrating on rotated screens.
  - Fix stylus back/forward button assignments.
  + Updated translations.
- Add pkgconfig(cairo-gobject) BuildRequires: new dependency.
* Thu Aug  7 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Fix automake warnings.
  + Fix compilation warnings in a number of panels.
  + Update Sharing panel for gnome-settings-daemon API change.
- Changes from version 3.13.2:
  + Use new RTL icons support in GTK+.
  + Background: Use higher resolution thumbnails on HiDpi displays.
  + Color: Update the UI if the ICC profile title changes.
  + Date & Time: Fix initial state when NTP isn't supported.
  + Details: Fix crash when using vboxvideo glx driver.
  + Display:
  - Make monitor label look better.
  - Add "Monitor" to keywords.
  - Make the Apply button unsensitive for invalid configuration.
  - Fix layout when rotating the left-most of the displays.
  + Keyboard: Add shortcut to launch gnome-control-center.
  + Network:
  - Fix warning on startup.
  - Hide the Virtualisation bridge.
  + Notifications: Drop the dep on libgnome-menu.
  + Online Accounts: Use a header bar for the "Add Account" dialog.
  + Privacy: Fix "Immediately" option not truthful.
  + Printers: Ellipsize long names and locations.
  + Sharing: Add per-network Media, File and Screen sharing.
  + Shell: Make search results sorting smarter.
  + User Accounts:
  - Fix DateTime instance leaks.
  - Fix wrong language being shown.
  - Add filter to the avatar file chooser.
- Changes from version 3.13.1:
  + Use header bars in dialogs.
  + Color: Do not crash when toggling devices and reopening the
    panel.
  + Details: Don't crash on Wayland.
  + Keyboard: Drop hard X dependency.
  + Network: Do not pretend we can overrule hardware rfkill.
  + Updated translations.
- Drop pkgconfig(libgnome-menu-3.0) BuildRequires: no longer
  required.
- Rebase gcc-private-connection.patch.
- Disable gnome-control-center-probe-radius-server-cert.patch for
  now: NetworkManager must have this capability rebased first.
* Thu Aug  7 2014 fcrozat@suse.com
- Update gnome-control-center-allow-extra-tools-in-shell.patch:
  Improve patch (no longer need to change 3 files to add one icon)
  and add alacarte and icedtea settings to available icons.
* Mon Jul 21 2014 fezhang@suse.com
- Update gnome-control-center-bnc865632-disable-popup-for-NM.patch:
  Remove the device add / remove button in Network panel when NM is
  not running (bnc#865632).
* Fri Jun 27 2014 sreeves@suse.com
- Add commit-*. Upstream bugfixes from the 3_10_X branch
    Fix bnc#884827 - color crashes
    Fix bnc#884525 - wrong virtualization detection
* Mon Jun 23 2014 fcrozat@suse.com
- Update gnome-control-center-allow-extra-tools-in-shell.patch:
  restore online-accounts panel.
* Fri Jun 13 2014 fezhang@suse.com
- Rename gnome-control-center-allow-yast-in-shell.patch to
  gnome-control-center-allow-extra-tools-in-shell.patch
  (bnc#866235). Add dconf-editor, gnome-tweak-tool, pkg-prefs and
  tracker-preferences, alongside yast, to the patch so that g-c-c
  shell show them all.
  %%suse_update_desktop_file are meanwhile added to specfiles of the
  added tools with category X-GNOME-PersonalSettings and/or
  X-GNOME-SystemSettings to make this patch properly taking effect.
* Thu May 15 2014 fezhang@suse.com
- Add gnome-control-center-bnc865632-disable-popup-for-NM.patch:
  Remove the popup error message in Network (bnc#865632).
* Wed May  7 2014 dliang@suse.com
- Lower 'Requires' to 'Recommends' for cups-pk-helper (bnc#875606)
* Wed Apr 16 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Background:
  - Remove black from the preset colours.
  - Make sure the whole dialog is visible on small screens.
  + Info:
  - Fix incorrect virtualisation technology being displayed.
  - Don't display "Check for updates" button when neither
    gnome-software nor gpk-update-viewer are available.
  + Printers: Don't fail when adding Samba printers with spaces on
    their name.
  + Users: Fix hang on password change.
  + Wacom: Unconditionally build the panel on supported platforms.
  + Updated translations.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Date & Time: Fix the width of hour and minute spinbuttons.
  + Privacy: Disable the software usage reporting.
  + Updated translations.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Color: Toolbar buttons are not refreshed when user changes
    profile.
  + Online Accounts: Panel is too wide.
  + Printers:
  - Fix build with CUPS <= 1.6.
  - Improve description of discovered printers.
  + Shell: Improve hostname ASCIIfication.
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Background:
  - Add Flickr support for backgrounds.
  - Fix linking of test program.
  - Guard against XDG_PICTURES_DIR not being defined.
  + Info: Show a static "Check for updates" button.
  + Mouse: Fix touch support for the testing widget.
  + Network:
  - Fix build with NM 0.9.8.x.
  - Don't warn for invalid settings.
  - Allow an empty gateway address in the connection editor.
  - Allow selecting a specific VPN or virtual interface.
  - Handle argv after cold-plugging connections.
  + Keyboard: Whitelist a few more options for the 3rd level
    chooser.
  + Printers:
  - Vertically center text for no devices.
  - Use "Default printer" instead of "Default".
  - Don't wait for "Return" to start search.
  - Don't show tooltip on clear icon when searching for printers.
  - Don't react to icon-press when searching for new printers.
  - Delay searching for remote printers.
  + Privacy: Add option to control GNOME Software usage stats.
  + Sharing: Address ambiguity in the screen sharing dialog.
  + Universal Access: Use '&' instead of 'and'.
  + User Accounts: Use POSIX for max login name length.
- Drop gcc-fix-build-with-old-NM.patch: fixed upstream.
* Mon Mar  3 2014 zaitor@opensuse.org
- Add gcc-fix-build-with-old-NM.patch, fix build with
  NetworkManager-0.9.8.x (bgo#723769).
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Background:
  - The chooser should have exactly 3 columns.
  - Add PNM and JPEG 2000 to the list of valid content types.
  - Add a placeholder icon before creating thumbnails.
  + Date & Time: Set the filechooser clock format too.
  + Display:
  - Hide Size label when empty.
  - Only show rotation options if we support them.
  + Info: Fix possible crasher when exiting panel.
  + Network:
  - Add a Team type to connection editor.
  - Give an empty title to the hotspot dialog.
  - Hide hotspot dialog on Escape.
  + Notifications: Fix invalid format string.
  + Online Accounts: Mention Pocket in the keywords.
  + Power: If battery is fully charged but 99%%, just round it up.
  + Printers:
  - Show correct time of print job.
  - Plug a memory leak.
  + Privacy: Fix the alignment of the combobox in the Screen Lock
    dialog.
  + Region: Do not show Login button if localed is not available.
  + Shell:
  - Activate application when launching a panel.
  - Disable type-ahead in search window.
  - Fix headerbar item positions following gtk+ headerbar
    changes.
  + Users: Improve logged-in check when deleting users to catch
    console logins.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Background: Fix small memory leak.
  + Bluetooth: New panel.
  + Color:
  - Fix a crash if the user closes the window after calibrating.
  - Actually show the whitepoint selector.
  + Display: Add an 'upside-down' button.
  + Network: Set mnemonic widget for labels and values in
    connection details.
  + Sharing and Power: Use gnome-settings-daemon's rfkill Bluetooth
    support.
  + Shell: Set iconview number of columns to 6.
  + Wacom:
  - Hide tab borders by default.
  - Clear background on "target" actor in calibration UI.
  - Don't use monitor geometry X/Y when calculating calibration.
  - Forgive inconspicuous double clicks when calibrating.
  - Fix possible crashers when the calibration window goes away.
  - Protect calibrator UI to spawn animations multiple times.
  - Fix first animation of calibration UI.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Background:
  - Fix compilation with libsocialweb.
  + Everywhere:
  - Improve rtl appearance by flipping margins.
  + Power:
  - Fix automatic suspend popup sizing.
  + Sharing:
  - Remove OBEX FTP support.
  - Fix Bluetooth label always being off.
  - Make it possible to add new folders.
  - Fix a crash when turning off sharing.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Details:
  - Remove apparently duplicated autostart category.
  - Use gnome-software for showing the list of updates if
    installed.
  + Power, Display:
  - Update for new UPower API
  + Region:
  - Allow setting system-wide formats.
  - Never show "None" for language and formats.
  + Universal Access:
  - Split keywords with spaces.
- Rebase gcc-private-connection.patch.
- Drop gnome-control-center-linker.patch: fixed upstream.
- Drop UPower 1.0 related patches (fixed upstream):
  + gnome-control-center-upower-DeviceChanged-signal.patch.
  + gnome-control-center-upower-display.patch.
  + gnome-control-center-upower-fix-build.patch.
  + gnome-control-center-upower-icons.patch.
  + gnome-control-center-upower-changed-signal.patch.
* Mon Mar  3 2014 zaitor@opensuse.org
- Update to version 3.10.3:
  + Background: Chooser dialog is too wide.
  + Color:
  - Fix a crash if the user closes the window after calibrating.
  - Show the whitepoint selector.
  + Display:
  - Hide unsupported UI elements.
  - Add an 'upside-down' button.
  + Info:
  - Crash if PackageKit is not present.
  - Use gnome-software for showing the list of updates if
    installed.
  + Network:
  - Fix build with NM 0.9.8.x.
  - Can't assign IP address without gateway.
  - Can't create team connection.
  + Online Accounts: Panel is too wide.
  + Power: Wrong battery indicator when fully charged (99%% instead
    of 100%%).
  + Printers: Show correct time of print job.
  + Sharing:
  - Fix crash when turning off Sharing.
  - Make it possible to add new folders.
  - Not able to enable bluetooth.
  + Shell:
  - Activate application when launching a panel.
  - Overview is too wide.
  + Users:
  - Improve logged-in check when deleting users.
  + Wacom:
  - Fix animations on the calibration UI.
  - Calibration on monitors other than (x,y=0,0) come out wrong.
  - Clear background on "target" actor in calibration UI.
- Drop gnome-control-center-BT-sharing.patch: fixed upstream.
* Thu Jan 30 2014 fcrozat@suse.com
- Move color management parts to gnome-control-center-color
  subpackage, allowing colord and gnome-color-manager to be
  uninstalled [bnc#861076].
- Ensure gnome-control-center-color Supplements
  gnome-control-center.
* Tue Dec 17 2013 mgorse@suse.com
- Add patches to support UPower 0.99:
  + gnome-control-center-upower-DeviceChanged-signal.patch
  + gnome-control-center-upower-display.patch
  + gnome-control-center-upower-fix-build.patch
  + gnome-control-center-upower-icons.patch
  + gnome-control-center-upower-changed-signal.patch -- update for
    libupower-glib API changes, from 3.11.
- Up libupower-glib dependency
* Tue Nov 12 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Background:
  - Fix test-chooser-dialog build with some linkers.
  - Fix compilation with libsocialweb support.
  + Sharing:
  - Remove OBEX FTP support as it's been removed from
    gnome-user-share.
  + Wacom:
  - Fix slider on Inking Pen page.
  + Updated translations.
- Drop gnome-control-center-linker.patch: fixed upstream.
- Add gnome-control-center-BT-sharing.patch: Fix Bluetooth sharing.
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Background:
  - Fix several memory leaks.
  - Some code cleanups.
  - Be robust against missing directories, and warn otherwise.
  - Use a consistent set of permissions when creating
    directories.
  + Display: Always label the built in display as "1".
  + Mouse: Do not reset mouse speed when unset.
  + Network:
  - Fix a few crashes and memory leaks.
  - Some code cleanups.
  - Just dismiss forget dialog if response is not OK.
  - Update forget button sensitivity when rows are destroyed.
  - Use the command line parameters property for 8021x.
  - Only start the spinner when we can stop it.
  + Power: Use device models as names.
  + Sharing:
  - Allow screen sharing approving without remote control
    enabled.
  - Ensure the hostname in labels is updated.
  - Prevent duplicate folders being selected for media sharing.
  - When enabling DLNA, also make sure to enable the MediaExport
    plugin.
  + Shell: Align the buttons in the headerbar.
  + Universal Access: Fix a crash.
  + Wacom:
  - Align the stylus section with the tablet section.
  - Fix device filtering in calibration UI.
  - Fix use after free causing random values in the calibration
    data.
  - Fix incorrect default window information.
  - Fix ~100 pixel offset when calibrating.
  - Reset the calibration before starting a new one.
- Drop gnome-control-center-network-8021x-entry.patch: fixed
  upstream.
- Add gnome-control-center-linker.patch: Fix test-chooser-dialog
  build with some linkers.
- Rebase gcc-private-connection.patch (Gary Lin).
* Sun Oct 13 2013 dimstar@opensuse.org
- Fix gnome-control-center-allow-yast-in-shell.patch: launching
  YaST should not give the feedback to the shell that we managed
  to switch panel (bnc#845643).
* Mon Oct  7 2013 glin@suse.com
- Rebase gcc-private-connection.patch (bnc#751211)
- Add gnome-control-center-probe-radius-server-cert.patch to probe
  the certificate of the RADIUS server (bnc#574266)
- Add gnome-control-center-network-8021x-entry.patch to fix the
  8021x settings dialog (bgo#709545)
* Fri Sep 27 2013 idonmez@suse.com
- Introduce with_wacom defines, set to 0 on s390{x}, otherwise 1:
  + Disable wacom support on s390{x}, those machines have no
    viable input ports.
  + Have pkgconfig(libwacom) BuildRequires depend on with_wacom.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Bluetooth:
  - Fix crash when exiting during a connection.
  + Display:
  - Add an option to turn off a particular display.
  + Universal Access:
  - Fix non-expanding sliders in zoom options.
* Sun Sep 22 2013 dimstar@opensuse.org
- Add gnome-color-manager Requires: the color panel interacts with
  binaries (gcm-viewer, gcm-calibrate) from gnome-color-manager.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Background:
  - Don't access possibly invalid object.
  - Fix top bar location on dual-head.
  - Fix a crash.
  + Date & Time:
  - Fix keyboard navigation.
  - Plug a small memory leak.
  - A11y improvements.
  + Display:
  - Disable the "Apply" button until a change has been made.
  - Close any open dialog if the panel is destroyed.
  + Network:
  - Fix a few crashes.
  - Don't show unmanaged devices.
  - Don't include spaces in proxy's ignore-hosts setting.
  + Power:
  - Don't show the estimated battery capacity.
  - Fix getting the keyboard brightness value.
  + Sharing:
  - Prevent incorrect sensitivity of the screen sharing password
    entry.
  + Universal Access:
  - Fix keyboard navigation.
  - Toggle switch when its parent row is activated.
  - Remove a bogus mnemonic-widget to not confuse Orca.
  + User Accounts:
  - Fix history dialog background color.
* Sun Sep 15 2013 zaitor@opensuse.org
- Stop passing --enable-systemd to %%configure, as it is not
  recognized anymore, and clean spec file of previous needed
  with_systemd macro and %%if with_systemd statments.
- Reenable translation-update-upstream.
* Wed Sep  4 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Date & Time:
  - Hide the NTP switch when the service is unavailable.
  - Show the automatic timezone switch.
  - Display timezone offset in a slightly nicer way.
  + Display:
  - Add the current background to the display previews and
    improve the display number indicators.
  + Network:
  - Wrap the DNS list for mobile networks.
  - Mark connection editor as changed when toggling the 'Only use
    for resources on its network' checkbox.
  + Online Accounts:
  - Add keywords for Kerberos, SMTP and IMAP to ease search
  - Increase the height of the "Add Account" dialog to
    accommodate the list of Chat providers.
  + Printers:
  - When adding a printer, do not prompt for user crendentials on
    every network samba server we discover that needs them.
    Instead, show such servers in the list and prompt only when
    users explicitly select them.
  + Shell:
  - Avoid width changes when searching.
* Sat Aug 24 2013 dimstar@opensuse.org
- Drop gnome-control-center-fine-grained-tz-polkit.patch: the
  Date & Time panel had a major overhaul and the patch in this form
  does not make sense. The patch was disabled for some time
  already.
- Drop gnome-control-center-hide-region-system-tab.patch: the
  region panel had a major overhaul and the patch in this form does
  not make sense. The patch was disabled for some time already.
- Drop gnome-control-center-nma-nialog.patch and
  gnome-control-center-build.patch: these patches are long out of
  service, as they targetted build fixes for NM 0.9.6.2.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90.1:
  + Mouse:
  - Fix stretched "Test Your Settings" button.
  + Network:
  - Remove placeholder label contents.
  + Online Accounts:
  - Support Telepathy accounts.
  + Region:
  - Fix stretched "Login Screen" button.
  + Shell:
  - Fix stretched header bar lock button.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Background:
  - Add support for lock screen background.
  + Date & Time:
  - New design.
  + Display:
  - New design.
  + Keyboard:
  - Add a screencast shortcut entry.
  + Network:
  - Activate wired profiles when clicked.
  - Don't show the airplane mode switch if the system doesn't
    support it.
  + Power:
  - Add a slider to control keyboard brightness.
  + Privacy:
  - Remove Name & Visibility section.
  - Confirm before emptying trash or purging temporary files.
  + Sharing:
  - Don't allow empty passwords in screen sharing.
  + Shell:
  - Prevent the window from being taller than the height of the
    monitor.
  - Use a GtkHeaderBar as the window's title bar.
  - Use a GtkSearchBar for the search entry.
  - Start search when typing.
  + User Accounts:
  - Enable checking for sequences in password.
  - Add a short explanation of what enterprise login is and a
    note about reduced functionality when offline.
  - Design and interaction refinements.
- Disable gnome-control-center-fine-grained-tz-polkit.patch: the
  patch needs rebasing.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Use GtkListBox instead of EggListBox.
  + Port away from deprecated GtkStock.
  + Fix the look of lock buttons and header switches.
  + Universal Access panel redesign.
  + Display:
  - Prevent a crash when the screen being dragged gets removed.
  - Fix "floating screens".
  - Use the preferred width and height when moving inactive
    displays.
  - Prevent the built-in display from being turned on when the
    lid is closed.
  + Mouse:
  - Use a dialogue window for the mouse test.
  - Show the "enable trackpad" slider button even if the mouse
    isn't present when the trackpad is currently disabled.
  + Network:
  - Use gnome-settings-daemon interface for switching on/off
    Airplane Mode.
  + Power:
  - Adapt to new brightness interface in gnome-settings-daemon.
  - Fix primary battery section getting resized when the label
    changed.
  - Fix crash when no batteries are available.
  + Privacy:
  - Fix default "Retain history" value.
  + Region:
  - Ensure the current language's name gets translated.
  + Sharing:
  - Hide the vino password by default.
  - Limit the sharing password to 8 bytes.
  - Avoid conflicts with the sensitivity of the "remote control"
    options.
  - Hide Bluetooth bits if Bluetooth is disabled.
  + Shell:
  - Ensure we cannot activate a panel if the search is off.
  + Sound:
  - Don't show applications playing event sounds.
  + User Accounts:
  - Don't count inactive users as administrators.
  - Make the Enter key work on the password dialogue.
  - More work not to show system accounts.
  - Correctly select the newly created user.
  + Wacom:
  - Update OLED labels for hard-coded actions too.
  - Redesign button assignment dialogue.
  - Try to use the OSD to assign buttons if a layout is
    available for the device in question.
- No longer take care of building egg-list-box explicitly in the
  build phase.
* Sat Jul 20 2013 hillwood@linuxfans.org
- Enable ibus intergration (define with_ibus 1).
* Tue Jul  2 2013 dliang@suse.com
- Rebase gnome-control-center-allow-yast-in-shell.patch.
  to prevent it from crash.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + All:
  - Make a number of dialogues non-resizable.
  + Background:
  - show explanation of why pictures source might be empty.
  + Bluetooth:
  - Port to BlueZ 5.
  + Mouse:
  - Rename "Content sticks to fingers" to "Natural Scrolling".
  + Power:
  - Update UI strings to follow the HIG.
  + Region:
  - Make sure not to display an empty input sources list.
  + Region, Wacom, Shell:
  - Set button arrow icons according to locale's text direction.
  + Sharing:
  - Retrieve the mDNS hostname from Avahi, if available.
  + Sound, Background:
  - Ensure dialogs are closed if panel changed.
  + Shell:
  - Raise the existing window when already opened.
  - Go back to overview when setting panel to NULL.
  + User Accounts:
  - Don't let user disable own account.
  - Don't show heading for other accounts if there are none.
  - Hide 'Add Account' dialog when panel goes away.
  - After the add account dialog is cancelled, discard results.
  - Remove autologin when an account is deleted.
  - Avoid problems with automatic login and disabled accounts.
  - Prevent the only Administrator from being demoted.
  - Prevent the only admin from being deleted or disabled.
  - User friendly password hints.
  - "Add user account" and password dialogs redesign.
  - Set the password mode to regular immediately.
  - Fix possible crashes when changing the language in the region
    panel if done after the user panel was opened.
  + Wacom:
  - Add command line argument support for choosing the tablet.
  - Add command line support for calibration.
  - Fix discrepancy when switching monitors from g-c-c.
- Changes from version 3.9.2.1:
  + Fix compilation failure due to missing files in tarball.
  + Updated translations.
- Drop gnome-control-center-remove-password-options.patch: no
  longer needed.
* Wed May 29 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Background:
  - Offload the sorting of the initial list of files.
  - Monitor the Pictures and cache directory for new files.
  - Fix possible crashes when exiting the panel.
  + Bluetooth:
  - Don't show label next to power switch.
  + Color:
  - Bump required colord version.
  - Improve accessibility.
  - When calibrating inhibit logout, switching users and
    suspending.
  - Expand profiles assigned to the device when single clicked.
  - Add translatable strings for newer display types.
  + Date & Time:
  - Add support for new timedated CanNTP property.
  + Details:
  - Fix display of graphic driver name.
  + Keyboard:
  - Be more specific in input source switch label.
  - Allow input of Hangul and Modifier+space shortcuts.
  + Mouse:
  - Fix bad state and critical error caused by reopening mouse
    test panel in clicked state.
  - Enable horizontal scrolling when changing scroll method.
  - Fix incorrect initial values.
  + Network:
  - Fix some alignment problems.
  - Display "device state reason", and remove duplicate code.
  - Improve accessibility.
  - Be more careful in ignoring shared connection.
  - Add support for ModemManager 1.x API.
  - Try to guess operator name from MCCMNC or SID.
  - Disable the Hotspot button if the device does not support it.
  - Mark connection editor changed when editing IPv4/IPv6 pages.
  - Fix initial sensitivity of editor "Add" button.
  - Add firewall zone support for wifi, wired and VPN.
  - Add icon for WWAN.
  - Fix display of some characters in WiFi AP names.
  - Fix possible crash in connection editor.
  - Update VPN switch when enabled from shell.
  + Online Accounts:
  - Use g_warning instead of goa_warning.
  - Scroll the tree view when showing an account.
  - Accept requests for account creation on DBus/cmdline.
  + Power:
  - Improve accessibility.
  - Change the range of idle time and suspend idle time.
  - Simplify "Mark As Inactive After" string.
  - Clarify "Lock Screen After" string.
  - Expand the "Automatic suspend" dialogue's layout.
  + Printers:
  - Visual improvements of driver selection dialog.
  - Add authentication dialog for samba printers.
  - Search for samba printers in new printer dialog.
  - Show printer name only in the title of options dialog.
  + Privacy:
  - Remove redundant option from the recent files combobox.
  + Region and Language:
  - Update interface.
  - Fix crash when changing the language.
  - Always add ibus engine widgets regardless of locale info.
  - Prevent window from getting too tall with many input sources.
  - Improve explanation when there are no input sources.
  - Display current locale country in formats if setting is
    empty.
  - Translate restart notification into the target language.
  - Show restart notification only if strictly needed.
  - Apply user settings system-wide on single account systems.
  - Handle input switching through mutter/gnome-shell.
  + Search:
  - Don't use a label for the enabled switch.
  - Special case gnome-control-center.
  - Unescape the names in Search Locations.
  - Fix ordering and sorting of applications.
  + Sharing:
  - Start or stop Rygel when Media Sharing is enabled or
    disabled.
  - Add master switch.
  + Shell:
  - Sort completion items.
  - Add support for additional arguments.
  - Do not forcibly suppress debug messages if --verbose not set.
  - Remove gnomecc.directory.
  - Add a gnome-shell search-provider for settings panel.
  - Put the panel title in the shell's header.
  - Update panel comments.
  - Add navigation support through back button.
  - Don't prelight icons in the icon view.
  - Use GVariant to convey panel arguments instead of a string
    array.
  - Expose panel launching with D-Bus activation.
  - Remove unneeded libnotify dependency.
  + Sound:
  - Show a different icon for different input/output ports.
  - Fix potential memory corruption.
  + User Accounts:
  - Add accessible labels in history dialog.
  - Don't reject passwords that pwquality says are ok.
  - Deal with pre-loaded users.
  - Remove password hints feature from UI.
  - Stop crash when changing the password.
  - Fix fingerprint dialogue causing a crash.
  - Ellipsize long user names in the password dialog.
  - Disallow whitespace-only names.
  + Wacom:
  - Add basic OLED handling for Intuos4.
  - Add animations to calibration window.
- Rebase gnome-control-center-allow-yast-in-shell.patch.
* Wed May 22 2013 dimstar@opensuse.org
- Require colord: the color panel in gnome-control-center needs to
  be able to read the configuration and requires the ColorHelper
  glib schema to be present.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Color:
  - Don't check for /proc/cmdline on non-Linux.
  - Fix sizing of back button.
  + Network:
  - Fix crash when clicking "Connect to hidden network".
  + Region and Language:
  - Don't crash if the user disabled Input sources switch
    keybindings.
  - Don't focus the input chooser if it is already focused, as
    this will select the text in the entry.
  - Rate limit the input chooser filtering.
  + User Accounts:
  - Ellipsize long user names in the password dialog.
* Mon May  6 2013 dimstar@opensuse.org
- Update to version 3.8.1.5:
  + Mouse:
  - Restore the mouse and touchpad pointer speeds.
  + Online Accounts:
  - Add ownCloud to the keywords.
  + Printers:
  - Don't crash without system-config-printer installed.
  + Shell:
  - Fix small memory leak.
  + User Accounts:
  - Fix possible crash in history dialogue.
  - Fix possible crash when changing the password.
  - Fix fingerprint reader dialogue crashing.
  - Reacquire permissions before adding account if necessary.
  - Make Enter work in the 'Add Account' dialogue.
  - Handle "incorrect password" kerberos error.
  - Ellipsise long user names.
  - When enterprise account disabled, join as admin.
- Rebase gnome-control-center-allow-yast-in-shell.patch.
* Sat Apr 20 2013 mike.catanzaro@gmail.com
- Add gnome-control-center-remove-password-options.patch - users
  will get locked out of their computers if they try to
  'Choose password at next login' or 'Login without password'
  since these conflict with our PAM configuration (bnc#779408)
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Background:
  - Fix cancellation of asynchronous calls when exiting panel.
  + Info:
  - Fix crash with NVidia's GLX implementation.
  - Fix error handling when PackageKit isn't installed.
  + Network:
  - Make VLANs, bridges and bonds deletable
  - Set the connection editor's title for VPNs and Wired
    connections.
  - Fix display of some characters in Wi-Fi AP names.
  - Fix possible crash in the connection editor.
  - Fix some strings not being marked as translatable.
  - Make sure "Apply" becomes sensitive when changing some
    options.
  - Fix jumping dialogues when showing the connection editor.
  + Notifications:
  - Don't fail if a referenced application does not exist.
  + Power:
  - Fix strings not being marked as translatable.
  + Region:
  - Automatically apply settings system-wide on a single account
    system.
  - Fix settings the system language.
  + Search:
  - Fix sorting when moving the last entry.
  - Fix moving unsorted applications.
  - Align the locations box with the close button.
  + Shell:
  - Fix translation of the window title.
  - Remove obsolete libnotify dependency.
  + Sound:
  - Fix possible crasher when changing the alert sound.
  + User Accounts:
  - Tell realmd to not setup system management.
- Drop pkgconfig(libnotify) BuildRequires: no longer needed.
* Thu Apr 11 2013 dimstar@opensuse.org
- Obsolete gnome-control-center-branding <= 12.3: as there is no
  branding package left for g-c-c, we need to obsolete it for a
  clean upgrade path.
- Also explicitly obsolete gnome-control-center-branding-upstream
  and gnome-control-center-branding-openSUSE.
- Really drop g-c-c-online-accounts.patch.
* Sat Mar 30 2013 dimstar@opensuse.org
- Rebase gnome-control-center-allow-yast-in-shell.patch: allow
  YaST to be added to the gnome-control-center again.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Online Accounts:
  - Scroll to the account in question when it was requested from
    an external application.
  + Printers:
  - Ensure that all the types of printers are discovered.
  + Region:
  - Make sure that engines we don't have locale information for
    end up in the "Other" row.
  - Prevent the window getting too tall with many input sources.
  - Improve explanation when there are no input sources.
  - Make sure the "None" input source row gets removed when
    adding a new one.
  - Display the current locale country in formats if the setting
    is empty.
  - Translate the restart notification in the target language.
  - Fix possible crashes when leaving the panel.
  - Only show a restart notification if strictly needed.
  - Improve matching when searching language names with accents
    or different case.
  - Add separators to the language list and formats chooser.
  - Use the "view-more-symbolic" icon instead of the
    unclear "...".
  - Ensure that labels are centered when adding the tick mark.
  + Shell:
  - Fix resized back button depending on the panel selected.
  + User Accounts:
  - Fix crash when changing the password.
  - Fix empty panel when going back to it.
  + Updated translations.
- Drop gnome-control-center-libgd.patch: fixed upstream.
* Sun Mar 17 2013 dimstar@opensuse.org
- Disable gnome-control-center-allow-yast-in-shell.patch: the
  rebase is not fully completed; currently, this patch makes the
  build fail.
* Wed Mar 13 2013 dimstar@opensuse.org
- Rebase gnome-control-center-allow-yast-in-shell.patch and
  reenable the patch.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Fix titlebar bug.
  + Use the new GdStack widget to switch panels.
  + Don't prelight icons in the icon view.
  + Make search be "and" instead of "or" by default.
  + Make it possible to look for multiple keywords in the search.
  + Background:
  - Monitor the Pictures and the cache directory for new files.
  + Online accounts:
  - Nicer error states.
  - Add a new "Other" providers page.
  + Printers:
  - Don't crash after changing an option.
  + Region & Language:
  - Center the text in the language and format choosers.
  + Search:
  - Fix folder names in non-ASCII languages.
  + Search provider:
  - Escape the description passed to gnome-shell.
  + Sharing:
  - Check if SSH is available before showing it in the UI.
  + User accounts:
  - Make login history dialog title translatable.
- Add gnome-control-center-libgd.patch: Fix brp error for implicit
  declaration of strcmp.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Use header bar to show the current panel's name.
  + Add sound and user-accounts panels to the command-line
    completion, and ensure the completion is sorted by default.
  + Update man page.
  + Do not forcibly suppress debug messages if --verbose not set.
  + Add GNOME Shell search provider and remove unused menu
    definition.
  + Update descriptions for all the panels.
  + Use a back arrow in the header bar, and go back to the previous
    panel if navigated from one.
  + Color:
  - Bump the required colord version.
  - Don't stretch the device switch.
  - Add widget relations for accessibility, and make all buttons
    keyboard accessible.
  - When calibrating inhibit logout, switching users and
    suspending.
  - Expand profiles assigned to the device when single clicked.
  + Details:
  - Remove fallback from keywords.
  + Keyboard:
  - Be more specific in input source switch label.
  + Network:
  - Require newly released NetworkManager 0.9.8.
  - Disable the Hotspot button if the device does not support it.
  - Add support for newer versions of ModemManager.
  - Try to guess the operator name for WWAN connections.
  - Fix warnings when virtual connections exist.
  - Display "device state reason" to show, eg., locked modems.
  - Fix some alignment, spacing problems.
  - Make symbolic icons sharper.
  - Add widget relations for accessibility.
  - Avoid all access points being named after the shared
    connection in some cases.
  - Fix connection editor's apply button not working.
  - Plug some memory leaks.
  + Notifications:
  - Fix some spacing problems.
  + Mouse:
  - Fix possible bad state when reopening the mouse panel.
  + Online Accounts:
  - Don't use GOA specific warning macro.
  + Power:
  - Update idle time and suspend idle time ranges.
  - Fix layout of the automatic suspend dialogue.
  - Better label for the idle-delay selection.
  - Add widget relations for accessibility.
  + Printers:
  - Visual improvements of driver selection dialog.
  - Search for samba printers in new printer dialog.
  - Add authentication dialog for samba printers.
  - Disable building the printers panel if libsmbclient isn't
    available.
  + Privacy:
  - Clarify "Lock Screen After" string.
  - Remove redundant option from the recent files combobox.
  + Region & Language:
  - Update design based.
  + Search:
  - Don't make the settings search configurable.
  + Sharing:
  - Start or stop Rygel when Media Sharing is enabled or disabled
  - Add a master switch to disable all the services.
  + Sound:
  - Show a different icon for different input/output ports.
  + User Accounts:
  - Add widget relations for accessibility.
  - Don't reject passwords that pwquality says are ok.
  - Remove password hints feature from the UI as they are not
    implemented in GDM.
- Add pkgconfig(mm-glib) and pkgconfig(smbclient) BuildRequires:
  new dependencies for the network panel and printer panel.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires:
  dependency for egg-list-box.
- Build the new submodule egg-list-box.
- Add gnome-control-center-nma-nialog.patch: Fix some missing
  includes. A more complete patch, taking care of removing
  deprecates is already pushed upstream.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.5.1:
  + Color:
  - Make medium quality the default.
  + Network
  - Allow compiling against NetworkManager 0.9.6.
  - Disable 'Apply' until things have changed.
  - Use symbolic icons consistently.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Background:
  - Sort Pictures in order of most recently modified.
  - Update for gnome-shell Screenshot API changes.
  + Color:
  - Allow the user to remove automatically added profiles.
  - Show a summary page when running on a LiveCD.
  - Show sRGB and AdobeRGB profiles when selecting a profile for
    a display.
  - Use a EggListBox for the main device display to match the new
    mockups.
  - Use colord-session to calibrate the display.
  + Display:
  - Add support for 21:9 displays.
  + Network:
  - Add a spinner while connecting.
  - Add integrated "Add New Connection".
  - Add VPN support to the connection editor.
  - Support new AP-mode hotspot functionality.
  + Power:
  - Add a dim screen switch.
  - Add idle-delay configuration.
  + Printers:
  - Attach toolbar controlling jobs to list of jobs.
  + Screen:
  - Remove screen panel.
  + Sharing:
  - Add a "show password" check button to the screen sharing
    dialog.
  - Don't show Media sharing without rygel.
  - Hide Bluetooth sharing when there is no Bluetooth adapter.
  + Shell:
  - Activate items on single click.
- Add pkgconfig(colord-gtk) and pkgconfig(libnm-glib-vpn)
  BuildRequires: new dependencies.
- Add pkgconfig(gio-2.0), pkgconfig(gl) and pkgconfig(gmodule-2.0)
  BuildRequires: new verified dependencies.
- Drop pkgconfig(iso-codes) BuildRequires: no longer needed.
- Drop g-c-c-online-accounts.patch: fixed upstream.
* Tue Feb 26 2013 vuntz@opensuse.org
- Rebase gnome-control-center-allow-yast-in-shell.patch to work
  with the new code.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Add new Sharing panel.
  + Add bash completion file.
  + Use GResources to handle UI files.
  + Color:
  - Only show the calibrate or add buttons when the device is
    selected
  - Don't crash if no sensors are plugged in
  + Details:
  - Remove Graphics section
  + Keyboard:
  - Allow key repeat rate of 110 chars/sec
  - Add input-source-switcher to the shortcuts
  + Power:
  - Implement the new Power panel design
  + Printers:
  - Control acceptance of jobs with enable switch
  + Region & Language:
  - Add per-window input sources setting
  + Shell:
  - Make scrollbars reach to the edge of the window
  - Don't search in .desktop file descriptions
  - Remove prelight from search results
  - Make search results descriptions dimmer
  - Fix keyboard navigation in the search results and the main
    view
  - Add --search and --list command-line options
  - Add support for the back mouse button
  + User Accounts:
  - Port to use libaccountsservice (and drop the systemd direct
    dependency)
  - Fix crash when built with cheese support
  - Handle the real name not being set
  - Add login history dialogue
- Add pkgconfig(accountsservice) BuildRequires: new dependency for
  the user accounts panel.
- Add g-c-c-online-accounts.patch: fix implicit declaration in
  online-accounts panel.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Remove fallback session handling code
  + Add search panel
  + Add privacy panel
  + Add notifications panel
  + Use the proper Unicode ellipsis (…) instead of three dots
  + Background:
  - Hide in Unity
  - Fix not having 3 columns in high contrast
  + Bluetooth:
  - Avoid possible loops when Connection fails
  - Fix main switch acting bizarrely
  - Use spinner when connecting
  - Align the device list with the all settings button
  - Remove ObexFTP browsing from the UI
  + Color:
  - Do not use a combobox when listing profiles to add to devices
  + Date & Time:
  - Do not offer the 12 hr clock in locales without AM/PM
  + Details:
  - Add distro information
  - Add CPU model on ARM
  - Avoid adding phantom "Unknown model" CPU on PPC64
  + Info:
  - Set the hostname only after a small delay
  + Keyboard:
  - Point to a more specific help page
  - Add support for msgctxt in keybindings
  - Improve shortcuts tab keynav
  + Network:
  - Make sure flight mode is always visible
  - Make sure Airplane mode switch everything off
  - Ensure IMEI is displayed and reload Operator Name when it changes
  - Also load IMEI and Operator Name for LTE-only modems
  + Online accounts:
  - Don't preselect the first item when adding an account
  - Align the accounts list with the all settings button
  - Only allow adding accounts if the network is available
  + Printers:
  - Show in Unity
  - Fix problems when adding new printers
  + Region:
  - Show in Unity
  - Fix possible crasher on startup when the X11Variant are empty
  - Offer logout options after changing language
  - Add Japanese to the popular languages
  - Show popular languages in their own language
  - Fix other user's languages never getting added
  - Make 'Add' dialogs consistent
  - Reinstate the separator in the languages list
  - Fix button alignment problem
  + Shell:
  - Remove the previous panel when switching to a new one
  - Don't remove old panel if new one is broken
  - Add F1 shortcut to show the help
  - Rename to Settings
  - Ensure the home button is the correct height
  - Fix alignment of home button in RTL languages
  - Make all the plugins static
  + Sound:
  - Clarify "sound events"
  - Fix possible crasher
  - Use libgnome-volume-control
  + Universal Access:
  - Set the dialog hint on the zoom options
  - Also set the WM HighContrast theme when the switch is flipped
  + Users:
  - Rename from User Accounts
  - Show the password by default once generated
  - Fix resetting one's avatar
  - Add "last login" field
  + Wacom:
  - Add support for the new OSD help display
- Rebase gnome-control-center-allow-yast-in-shell.patch.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + All:
  - Improve contexts for ambiguous strings.
  + Background:
  - Optimise preview for the usual shell layout.
  - Handle copy cancellation correctly.
  - Fix crash when exiting panel too quickly.
  + Keyboard:
  - Ensure the dir name shown matches the XDG Pictures dir.
  + Network:
  - Rename "Wireless" to "Wi-Fi" in the UI.
  - Add more keywords to the desktop file.
  - Fix 8021x connections.
  - Add an 'Ignore Hosts' entry to the proxy page.
  - Minimal support for unrecognized device types.
  - Add support for showing bond slaves.
  + Mouse:
  - Don't show touchpad disable button when there's no mouse.
  + Screen:
  - Handle brightness calls finishing after we're done.
  + Info:
  - Don't block for PackageKit.
  - Detect and display Virtualisation method used.
  + User Accounts:
  - Remove the autologin checkmark.
  - Logged in status identification.
  - Complete discover on failure.
  - Remove the realmd version check.
  - Recognize that some kerberos domains cannot be joined.
  - Set timeouts on all realmd interface proxies.
  - Don't have domains twice in the drop down.
  - Require logind for session tracking.
  - fix wrong sensitivity of the autologin combo.
- Rebase gcc-private-connection.patch.
- Add gnome-control-center-build.patch: Fix build with
  NetworkManager stable branch.
* Tue Feb 26 2013 dimstar@opensuse.org
- Do not package gnome-control-center.rules (bnc#804966): On
  openSUSE defining the use of the wheel group is up to the
  administrator.
* Tue Jan 29 2013 idonmez@suse.com
- Drop gnome-control-center-probe-radius-server-cert.patch for now.
  The patch is incomplete and breaks WPA-Enterprise completely
  (bnc#798793)
* Thu Dec 27 2012 mike.catanzaro@gmail.com
- Drop apg recommends: automatic password generatoion is no longer
  done by spawning apg, but rather by using libpwquality directly.
* Thu Nov 15 2012 dimstar@opensuse.org
- Update to version 3.6.3:
  + Add F1 accelerator to show help.
  + Background: Hide in Unity.
  + Bluetooth:
  - Fix the master switch not following the actual adapter state.
  - Fix the Connection switch being in the wrong state when
    connecting fails.
  - Show a spinner when connecting to a device.
  - Align left hand pane with the "All Settings" button.
  + Keyboard: Show more specific help page
  + Network: Make Airplane mode switch off all the radios,
    including Bluetooth.
  + Online Accounts:
  - Don't preselect the first item when adding an account.
  - Align left hand pane with the "All Settings" button.
  + Printers:
  - Fix renaming printers with recent versions of CUPS.
  - Show in Unity.
  + Region: Fix possible crasher on startup.
* Wed Nov 14 2012 dimstar@opensuse.org
- Don't own %%{_datadir}/polkit-1/rules.d: it's owned (with special
  attr()) by polkit.
* Wed Nov 14 2012 dimstar@opensuse.org
- Change with_systemd defines to 1 in order to enable systemd.
* Fri Oct 26 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Background:
  - Fix crash when exiting panel too quickly.
  + Network:
  - Fix 8021x connections.
  + Screen:
  - Avoid accessing destroyed panel.
  + User accounts:
  - Complete discover on failure.
  - Recognize that some kerberos domains cannot be joined.
  - Remove the realmd version check.
  - Set timeouts on all realmd interface proxies.
  - Don't have domains twice in the drop down.
  - Fix wrong sensitivity of the autologin combo.
* Thu Oct 11 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Background:
  - Fix multi-monitor handling
  - Use a lighter texture for solid colours
  + Date & Time:
  - Update the current time when we change the timezone
  + Mouse:
  - Fix mouse test area not being in the correct position in some
    cases
  + Network:
  - Fix arrow direction in RTL languages
  - Don't resize the panel or the Wi-Fi list
  - Top align the back button in the Wi-Fi panel
  - Fix parenting problems when spawing a network dialogue
  - Don't try to activate out-of-range connections
  - Fix WPA Enterprise connections not working
  - Use a regular button for "Connect to Hidden Network"
  + Online Accounts:
  - Fix a warning on exit
  + Printers:
  - Fix wrong icon being used in the search entry
  + Region & Language:
  - Remove the unused "Remove" button
  - Reduce the number of required m17n desktop files
  - Repopulate the input sources when IBus becomes available
    again
  - Add support for inscript2 and Marathi phonetic input sources
  + Shell:
  - Fix entering the same panel twice
  + Sound:
  - Fix input level bar direction in RTL languages
  + User Accounts:
  - Fix the autologin icon not being recoloured.
- Rebase gcc-private-connection.patch.
* Tue Oct  2 2012 dimstar@opensuse.org
- Add with_ibus condition (currently set to 0), as we do not have
  a recent enough version of IBus in Factory at this moment.
  + when with_ibus is set to 1; pkconfig(ibus) BuildRequires will
    be used and --enable-ibus is being passed to configure
  + when with_ibus is set to 0, pkgconfigu(ibus) is being ignored
    and --disable-ibus is being passed to configure.
* Sat Sep 29 2012 dimstar@opensuse.org
- Really replace pkgconfig(gstreamer-0.10) BuildRequires with
  pkgconfig(gstreamer-1.0): cheese-devel already correctly pulled
  in gstreamer 1.0 devel files, so there is no factual change now.
  But it stops us from pulling in GStreamer 0.10 while we don't
  need it anymore.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Network:
  - Make connecting to Enterprise WPA Wi-Fi networks work again.
  + Region:
  - Jump directly to the correct shortcuts section when following
    the link.
  + Shell:
  - Fix broken panels when launching the same one twice
  + User Accounts:
  - Don't ask for the old password when none is set.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Ensure that all sources are GPLv2+ instead of a mix of GPLv2+
    and GPLv3+.
  + Set blank window titles for a number of dialogues.
  + Fix accessible labels for switches.
  + Bluetooth:
  - Fix setting up dial-up networking for phones.
  + Display:
  - Fix mouse events not working in preview.
  + Background:
  - Use a more varied colour palette.
  - Fix the small size of the "changes throughout the day"
    emblem.
  + Network:
  - Mark all rows representing saved connections as such.
  - Make the 'Settings...' buttons work properly.
  - Handle disconnected APs better.
  - Show a "Connect" button for disconnected APs.
  - Show 'Last used' item for non-active, in-range access points.
  - Improve the Wi-Fi list appearance.
  + User Accounts:
  - Use GStreamer 1.0
  - Fix "enterpise" typo
  + Power:
  - Fix a wrong use of GCancellable that could lead to crashes.
  + Region:
  - Use consistent strings for layout/engine names.
  - Handle empty layout sources, especially when adding a new
    one.
  - Handle input sources in the system tab.
  - Fix layout problem on the system tab.
  - Update IBus engines whitelist.
  + Printers:
  - Fix building against CUPS 1.6.
  + Universal Access:
  - Fix whitespace in the zoom options dialogue.
  + Screen & Brightness:
  - Make notification checkbox focusable.
  + Wacom:
  - Fix link to docs.
- Replace pkgconfig(gstreamer-0.10) BuildRequires with
  pkgconfig(gstreamer-1.0) BuildRequires, due to upstream changes.
- Rebase gcc-private-connection.patch.
* Wed Sep 12 2012 vuntz@opensuse.org
- Rebase gcc-private-connection.patch.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Common:
  - Fix memory leaks in language sorting
  - Fix too big editable labels
  + Date & Time:
  - Make map look unsensitive when the panel is locked
  + Display:
  - Fix possible warning on exit
  - Make 'Mirrored Displays' string consistent with
    GnomeRRLabeler
  + Info:
  - Add PolicyKit rules for hostname setting
  - Set related mime types when changing preferred apps
  + Mouse:
  - New testing area
  - Remove italics from test page
  - Fix left/right mouse-handedness radio buttons in RTL
    languages
  + Network:
  - Ignore unrecognised device types
  - Fix wired and mobile activations
  - Don't try to activate slave connections
  + Printers:
  - Redesign the "new printer" dialogue
  + Region & Language:
  - Add Russian and Egyptian Arabic as common languages
  - Don't use IBus in fallback mode
  - Honor the 'show-all-sources' setting
  - Don't block getting the IBus engines
  - Expand the default list of input sources
  + User Accounts:
  - Simplify some drawing code
  - Fix login keyring password not getting updated
  - Fix match icon not updating in some cases.
- Drop gnome-control-center-bgpanel.patch: fixed upstream.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Background:
  - Implement new design
  + Bluetooth:
  - Require a newer version of gnome-bluetooth
  + Keyboard:
  - Add common keyboard layout related options to the shortcuts tab
  + Mouse:
  - Implement new design, including support for natural scroll
  + Network:
  - Improve the Wi-Fi page layout
  + Online Accounts:
  - Allow opening a particular account from the command-line
  - Avoid spurious "No online accounts configured" overlay
  - Fix crash when loading the panel a second time
  + Shell:
  - Remove animations, they were causing a number of problems,
    but were a useful exercise for future developments.
  + Sound:
  - Remove hardware page, and offer different connectors directly
    from the input and output pages
  + Universal Access:
  - Add zoom shader options, and reorganise zoom dialogue
  + User Accounts:
  - UI changes for better remote accounts support
  - Fix crash with incompatible versions of realmd
  + Wacom:
  - Add support for "switch monitor" shortcut
  + Updated translations.
- Add gnome-control-center-bgpanel.patch: add missing includes.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 3.5.6:
  + Add man page
  + Brightness & Lock:
  - Make "show notifications" available even if we don't lock
    the screen automatically
  + Display:
  - Fix possible error when the preferred mode is only
    available on one of the two outputs in mirror mode
  + Info:
  - Adapt for changed API in PackageKit
  - Small UI bug fixes
  + Network:
  - Refactoring for mobile broadband support and bug fixes
  - Split the wireless panel
  - Only show extra details for the active connection
  - Add network strength to the details panel
  - Only show the disconnect button when a device is fully
    activated
  - Fix crash with Access Points with non UTF-8 names
  - Forget the last selected wireless network when the button is
    clicked
  - Improve hotspot dialogue
  + Printers:
  - Add support for CUPS 1.6
  - Don't restrict the PPD list to PPDs with DeviceIDs
  - Cancel async operations correctly
  - Move jobs to a separate dialogue
  + Region:
  - Make ibus code more robust
  - Handle being opened twice gracefully
  - Require ibus 1.4.99 if ibus support is requested
  + User accounts:
  - Update for realmd 0.6
  - Strip remote D-Bus errors from user-visible messages
  - Fix memory leaks
  + Wacom:
  - Fix critical warning after calibration
  - Only do calibration for the selected tool
  + Updated translations.
- Disable gcc-private-connection.patch for now: needs rebasing.
* Fri Aug  3 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Brightness & Lock:
  - Add a "Show Notifications" setting
  + Keyboard:
  - Fix a memory leak
  - Fix some shortcuts used by the shell not being available for
    capture
  + Network:
  - Fix a number of crashers that occurred after the network
    panel was closed
  - Make mobile broadband support usable
  - Sort Wi-Fi access points by strength
  - Fix VPN information
  + Printers:
  - Allow users to change printer's PPD file
  - Add "Options" dialogue with more options than available
    readily
  + Power and User Accounts:
  - Port to use GtkLevelBar
  + Region:
  - Add support for IBus input sources
  + Sound:
  - Move input streams when the default source changes
  - Add backend code to track inputs and outputs in PulseAudio
    2.0
  + Wacom:
  - Apply display rotation to devices
  - Destroy the display mapping dialogue on unplug
  - Show a mark when calibration succeeds.
- Add pkgconfig(ibus-1.0) BuildRequires: new dependency.
* Fri Aug  3 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Wacom:
  - Fix crasher related to display matching.
- Rebase gcc-private-connection.patch.
* Fri Aug  3 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + All:
  - Use '&' instead of 'and', keeping the names shorter but also
    keep the user focused on other words which compose the name
  + Background:
  - Make sure background can get cancelled
  - Avoid escaped wallpaper name in the UI
  + Brightness & Lock:
  - Update slider when changing the brightness via keyboard keys
  + Info:
  - Add software media to "other media" dialogue
  - Add title for the "other media" dialog
  + Network:
  - Don't crash on hidden SSIDs
  - Fix packing order of children in the service dialog
  - Add mnemonic for a number of controls
  - Sort wireless first
  - Make list of Access Points more similar to the shell menu
  - Stop buttons jumping when switching between devices
  + Online Accounts:
  - Updated "Add Account" dialogue design
  - Improve layout when there are no configured accounts
  + Power:
  - Fix reference to "Screen" settings
  + Shell:
  - Fix crash when using keynav in overview
  - Don't animate between overview and search pages
  - Use GtkSearchEntry
  - Crasher fixes
  + Sound:
  - Add "audio" keyword
  - Fix mouse scrolls and clicking behaviour on sliders
  - Fix unmuting not working when dragging the event role slider
  + User accounts:
  - Add support for remote Kerberos accounts
  + Wacom:
  - Add keep aspect ratio option
  - Cancel calibration if window loses focus.
- Add krb5-devel BuildRequires: new dependency.
* Thu Aug  2 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Shell:
  - Many layout improvements
  - Format search results in 3 columns
  - Animate page switches
  - Add an app menu
  + User accounts:
  - Make controls insensitive when no user selected
  - Simplify generated password handling
  - Use libpwquality for password quality checks
  + Backgrounds:
  - Ignore screenshots
  - Only show supported image types
  + Display:
  - Translate the rotation drop-down again
  + Info:
  - Ignore NFS and removable mounts for disk size
  + Network:
  - Allow configuring wired network devices when not connected
  + Universal Access:
  - Redesign for consistency and smallness
  + Printers:
  - Set default media sizes
  + Region:
  - Replace layouts tab with input sources tab
  + Wacom:
  - Rename to "Wacom Tablet"
  - Update ui on hotplug
  - Disable on s390 and !linux
  + Updated translations.
- Rebase gnome-control-center-allow-yast-in-shell.patch.
- Drop upstream fixed patches:
  + gnome-control-center-fix-screen-brightness.patch
  + gnome-control-center-shortcut-assignment-fixes.patch
  + gnome-control-center-allow-wallpapers-with-weird-names.patch
  + gnome-control-center-fix-crash-on-hidden-ssid.patch
- Drop pkgconfig(libgnomekbd), pkgconfig(libgnomekbdui) and
  pkgconfig(libxklavier) BuildRequires: no longer needed.
- Add pkgconfig(clutter-gtk-1.0) BuildRequires: new dependency.
* Thu Aug  2 2012 badshah400@gmail.com
- Add gnome-control-center-fix-screen-brightness.patch to fix
  screen brightness slider not picking up the right value when
  brightness is changed by some other means, e.g., Function keys
  (bgo#662117, bnc#774190); patch came from upstream git and was
  rebased to current version
- Add gnome-control-center-shortcut-assignment-fixes.patch to fix
  user not being able to re-assign previously assigned shortcuts
  like Ctrl+Q, etc (bgo#675475, bgo#671448); patch came from
  upstream git
- Add gnome-control-center-allow-wallpapers-with-weird-names.patch
  to allow setting wallpapers with weird names involving special
  characters (bgo#673015); patch came from upstream git.
* Wed Jul 18 2012 glin@suse.com
- Add gnome-control-center-probe-radius-server-cert.patch to probe
  the certificate of the RADIUS server (bnc#574266, bnc#771185)
- Add gnome-control-center-fix-crash-on-hidden-ssid.patch to fix
  crash when the network panel receives a hidden ssid.
* Sun Jul  1 2012 dimstar@opensuse.org
- No longer pass --with-libsocialweb to configure:
  It is used to enable the Flickr background image integration, but
  is not functional. So instead of offering a feature that does not
  work, it's cleaner to not offer the feature (bnc#732690).
- Drop pkgconfig(libsocialweb-client) BuildRequires, which was
  only used to provide the integration above.
* Thu Jun 28 2012 dimstar@opensuse.org
- Add gcc-private-connection.patch: network: create private
  connections if the user if not authorized [bnc#751211].
- Add call to gnome-autogen.sh in setup section.
* Fri May 25 2012 vuntz@opensuse.org
- Add gnome-control-center-fine-grained-tz-polkit.patch: do not
  require the privilege to change the time to change the timezone.
  In the default configuration, this makes it possible to change
  the timezone without authentication. Fix bnc#749453.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Info:
  - Ignore NFS and removable mounts when calculating disk size
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Display:
  - Fix translation of the rotation drop-down
  + Printers:
  - Use PrinterAddOption method to set media size
  + User Accounts:
  - Make controls insensitive when a user is not selected
  + Wacom:
  - Fix alignment of the "Map to Monitor..." button
  + Updated translations.
* Sun Apr  1 2012 dimstar@opensuse.org
- Change /usr/bin/glxinfo Recommends to Mesa-demo-x Requires. Since
  bnc#748373 has been resolved, we can require the real package
  again.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Network:
  - Fix a crash by disconnecting idle sources
  + Printers:
  - Fix crash in actualize_printers_list
  + Updated translations.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 3.3.92:
  + Common:
  - Add missing git.mk to two panels.
  + Color:
  - Do not select the device in the treeview if it changes.
  - Don't allow the user to add existing profiles to devices.
  - Prevent a crash when hotplugging monitors when the color
    panel is open.
  + Date Time:
  - Fix broken time setting on 32-bit machines.
  + Display:
  - Simplify add_key() calls and function.
  - Sort resolutions by width first.
  - Use symbolic name.
  + Mouse:
  - Don't enable two-finger scrolling based on width.
  + Region:
  - Don't make the dialogue overly wide.
  - Fix possible crasher with empty layout.
  + Universal Access:
  - Hide zoom options when not in shell.
  + User Accounts:
  - Minimum of 200 width for the users list.
  + Updated translations.
* Tue Mar  6 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + Color:
  - Layout fixes
  - Ensure the "Set profile system-wide" button is visible
  + Display:
  - Fix crash when the screen setup changes and the Display
    panel has been closed
  + Info:
  - Fix updates buttons never saying "No updates"
  - Fix empty dialogue when bringing up "Other media" dialog
    again
  - Avoid empty entries in "Other types" dialogue
  - Remove unused and broken icons
  + Network:
  - Fix huge inline toolbar icons
  + Power:
  - Fix reference to "Screen" panel, got renamed to
    "Brightness & Lock"
  + Printers:
  - Port to GDBus
  + Region & Language:
  - Fix handling of variants in "Copy" button
  + Use Accounts:
  - Fix sizing problems in the user list
  - Fix possible crash for incomplete locales (such as Esperanto)
  + Wacom:
  - Fix resetting display mapping
  - Layout fixes
  - Add touchring and touchstrips to the mapped buttons
  - Fix crasher when XRandR isn't available
- Drop gnome-doc-utils-devel BuildRequires, removed dependency
  from upstream as the help was obsolete and almost empty.
- Drop pkgconfig(dbus-glib-1) BuildRequires: removed dependency, as
  "Printers" has been ported to GDBus.
- Remove --disable-scrollkeeper from configure, as it's no longer
  known.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + All:
  - Remove use of deprecated widgets
  + Shell:
  - Force a pixel size for the "All Settings" button
  + Color:
  - Don't print (null) for virtual printer profiles
  - Don't block the UI settings the default profile
  + Date & Time:
  - Fix crasher when systemd is unavailable
  - Respect LINGUAS for timezone translations
  + Keyboard:
  - Fix description not matching reality for setting shortcuts
  - Refuse Shift+unmodified key shortcuts
  - Fix crasher setting new custom shortcuts
  + Network:
  - Add "Forget Network" button
  - Remove unused "Unlock" button
  + Printers:
  - Prevent possible crashes when level, name and color
    information are parsed
  + Power:
  - Redesigned dialogue
  - Fix updating not working due to recent gnome-settings-daemon
    changes
  + User Accounts:
  - Port to GDBus
  - Fix crasher on startup when compiled with Cheese avatar
    capture
  - Use new strength bar widget from Power
  + Wacom:
  - Add simple display mapping dialogue
  - Add button mapping dialogue
  - Switch to last used stylus automatically
  - Loads of small layout fixes
- Add pkgconfig(cheese) BuildRequires: new dependency for the user
  accounts panel.
- Change freeglut Requires to a /usr/bin/glxinfo Recommends for
  now, as freeglut doesn't exist anymore, and /usr/bin/glxinfo is
  not shipped in a package anymore. This should get resolved soon.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Shell:
  - Unblur the all-settings button icon
  + Brightness & Lock:
  - Renamed from Screen
  + Date & Time:
  - Use the timedated D-Bus service
  + Keyboard:
  - Add support for new screenshot shortcuts
  - Remove use of italics for sliders
  + Mouse:
  - Remove use of italics for sliders
  + Network:
  - Only show flight mode toggle when there are wireless devices
  + Printers:
  - Update list of print jobs in a better place
  + Screen:
  - Rename to Brightness & Lock
  + Sound:
  - Fix wheel scrolling not working for right balance
  + Universal access:
  - Add configuration dialogue for zoom options
  + User accounts:
  - Use cheese init functions
  + Wacom:
  - Calibrate tablet on the screen it's attached to
  - Update and add missing stylus artwork
  - Fix incorrect page numbering
  - Hide cursor during calibration
  - Fix Scroll Up/Down actions being inverted
  - Add link to the Display Settings
  - Fix 1-button stylus button mapping
  - Remove use of italics for sliders
  - Plenty of layout fixes
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Remove pkgconfig(clutter-gst-1.0) and pkgconfig(dbus-1)
  BuildRequires: those dependencies are gone now.
* Wed Jan 18 2012 vuntz@opensuse.org
- Update to version 3.3.4.1:
  + Bluetooth:
  - Update for change in BluetoothChooser API
- Add pkgconfig(gnome-bluetooth-1.0) BuildRequires: it was somehow
  missing before.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Shell:
  - Fix unfocused windows theming
  + Bluetooth:
  - Remove omnipresent scrollbar and only show it when needed
  + Display:
  - Port to GDBus
  + Network:
  - Move the device speed up to the device header
  - Move "Airplane Mode" switch to the shell header
  + Printers:
  - Show correct hostnames for printers
  + Region:
  - Fix "extra" layouts not appearing in italics
  + Sound:
  - Fix compile time warnings
  + Users:
  - Fix capturing a picture with the webcam
  - Add optional systemd support for session tracking
  + Wacom:
  - Add calibration for screen tablets
  - Add per-stylus configuration
- Add new pkgconfig(clutter-gst-1.0) and pkgconfig(fontconfig)
  BuildRequires, following upstream change.
- Get ready for full-switch to systemd:
  + Add a with_systemd macro, currently set to 0 as the systemd
    support implies no support for ConsoleKit, which we want to
    keep until sysvinit is not supported anymore.
  + Add pkgconfig(libsystemd-login) BuildRequires and pass
  - -enable-systemd to configure if we build systemd support.
* Thu Jan  5 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Display:
  - Use consistent label style (bgo#665057)
  + Info:
  - Use consistent label style (bgo#665059)
  + Printers:
  - Unsubscribe from D-Bus signals when no longer needed
  - Don't crash because of external panel switch
  + Region:
  - Small language chooser improvements (bgo#664505, bgo#664503)
  + System Info:
  - Rename to 'Details' (bgo#661696)
  + Wacom:
  - Many improvements that I can't really summarize here
  - Better graphics
  - Use libwacom for tablet information
  - Visual improvements
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add pkgconfig(libwacom) and pkgconfig(x11) BuildRequires: new
  dependencies upstream.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Common:
  - Do not install private libgnome-control-center (bgo#655287)
  - Fix handling of <Primary> (bgo#748444)
  + Background:
  - Added D'n'D support for adding wallpapers (bgo#655375)
  - Force a toolbar style
  + Bluetooth:
  - Move Bluetooth panel from gnome-bluetooth
  + Color:
  - Update icon cache only on MAINTAINER_MODE
  - Do not allow the 'Add profile' modal dialog to be resizable
  - Improve the 'Add profile' modal dialog (bgo#661657)
  - Don't show profile ages for EDID, test and colorspace
    profiles (bgo#661669)
  - Show 'Uncalibrated' when a device has a test profile assigned
  - After removing a profile select the device so the UI is
    correct (bgo#661658)
  - Fix a critical warning in the new GtkTreeIter code
  - Make toolbar buttons focusable (bgo#662430)
  + Date & time:
  - Fix showing actual clock format on panel open
  + Info:
  - Use x-content/unix-software as mime for the Software combobox
    (bgo#660803)
  - Add labelling relations
  + Keyboard:
  - Don't load duplicate keybindings
  - Fix ATK descriptions (bgo#574073)
  - Make the '+' button work all the time (bgo#662253)
  - Remove broken allowed_keys checks
  - Use GtkCellRendererAccel
  - Adjust shortcut files (bgo#663626)
  - Rename a11y keyboard shortcuts
  - Remove support for conditional shortcuts (bgo#663431)
  - Stop monitoring num-workspaces
  - Port custom shortcuts to GSettings
  + Mouse:
  - Fix ATK descriptions
  + Network:
  - Allocate nm-connection for nma-wireless-dialog (bgo#648174)
  - Show wireless dialog even if there is no active AP
    (bgo#661526)
  - Accessibility improvements
  - Add proxy to the keywords (bgo#663340)
  - Make tabbing through the proxy page work
  + Online accounts:
  - Add title for "Add Account" dialogue (bgo#661573)
  + Power:
  - Use the correct item in the combo boxes when
    sleep-when-inactive is disabled
  - Don't set the sleep-inactive-x GSettings keys that have been
    removed
  - Use "Power off" instead of "Shutdown" (bgo#661559)
  + Printers:
  - Check state of CUPS after start (bgo#659721)
  - Fix build on systems without LC_PAPER (bgo#660692)
  - Don't hide address entry
  - Make +/- buttons insensitive when can not connect to CUPS
  - Set requesting-user-name when getting job info
  - Detect disconnection of printer
  - Don't allow "/" in printer name (bgo#661774)
  + Region:
  - Hide system tab if no localed
  - Simplify getting the current Locale
  - Implement copying layouts (bgo#659300)
  - Fix build on systems without LC_MEASUREMENT (bgo#660787)
  - Align the example dates
  - Only show locales for languages that have translations
  - Always add English to the list, as it should always be
    available
  + Screen:
  - Never set gnome-session's idle-delay to 1
  + Shell:
  - Make sure we gtk_widget_show the search view
  - Avoid crash when searching if a .desktop has no comment
    (bgo#661494)
  - Make Ctrl+Q work outside the overview
  - Make Ctrl+W close panels (bgo#660814)
  - Give focus to the search entry when showing the overview page
  - Don't crash when loading the icon fails (bgo#660513)
  - Use icon for "All Settings" button (bgo#657043)
  - Add a11y label for the All Settings button
  - Merge libgnome-control-center into main binary
  + Sound:
  - Fix possible infinite loop in combo box
  - Add a minimum height for the output list (bgo#660582)
  - Export sysfs path in stream properties
  - Port audible-bell to GSettings (bgo#625899)
  + Universal access:
  - Fix ATK descriptions
  - Avoid crashing when GConf is broken (bgo#751007)
  - Update for metacity GSettings port (bgo#625899)
  + User accounts:
  - Make unlock icon in tooltip match reality
  + Updated translations.
- Drop gnome-control-center-shell-no-crash.patch: fixed upstream.
- Drop libgnome-control-center1 subpackage. The private library is
  no longer being installed.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Fix a number of static analysis bugs
  + Color:
  - Fix possible crasher
  - Make toolbar focusable
  + Info:
  - Avoid reuse of an error, leading to a warning
  + Keyboard:
  - Fix handling of Control keys in keyboard shortcuts with
    GTK+ 3.2.1
  + Printers:
  - Fix possible crashers
  - Fix updating the print jobs list
  - Detect printers getting disconnected
  - Fix adding printers with '/' in the model name
* Thu Oct 20 2011 vuntz@opensuse.org
- Add gnome-control-center-hide-region-system-tab.patch: hide
  system tab in region panel until we really use the same files as
  systemd for setting the system-wide locale configuration. See
  bnc#703833 for more details.
- Really drop
  gnome-control-center-network-allocate-nm-connection.patch.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Common:
  - Always collect locales from the directory (bgo#660725)
  + Color:
  - After removing a profile select the device so the UI is
    correct (bgo#661658)
  + Date & time:
  - Fix showing actual clock format on panel open
  + Info:
  - Use new GtkAppChooserButton API (bgo#658693)
  - Use x-content/unix-software as mime for the Software combobox
  + Network:
  - Allocate nm-connection for nma-wireless-dialog (bgo#648174)
  - Show wireless dialog even if there is no active AP
    (bgo#661526)
  + Printers:
  - Check state of CUPS after start (bgo#659721)
  - Fix build on systems without LC_PAPER (bgo#660692)
  - Don't hide address entry
  - Disable remove button if no printer is selected (bgo#659724)
  - Hide spinner after search (bgo#659753)
  - Make +/- buttons insensitive when can not connect to CUPS
  + Region:
  - Hide system tab if no localed
  - Simplify getting the current Locale
  - Implement copying layouts (bgo#659300)
  - Fix build on systems without LC_MEASUREMENT (bgo#660787)
  - Only show locales for languages that have translations
  + Screen:
  - Never set gnome-session's idle-delay to 1
  + Shell:
  - Use gtk_widget_show instead of _show_all in
    gnome_control_center_show
  - Show the label for the category sections
  - Make sure we gtk_widget_show the search view
  - Make Ctrl+Q work outside the overview
  - Give focus to the search entry when showing the overview page
  - Don't crash when loading the icon fails (bgo#660513)
  + Updated translations.
- Drop gnome-control-center-setup-wpa-eap-no-active-ap.patch: fixed
  upstream.
- Drop gnome-control-center-network-allocate-nm-connection.patch:
  fixed upstream.
* Wed Oct 12 2011 glin@suse.com
- Add gnome-control-center-setup-wpa-eap-no-active-ap.patch: show
  the wireless setup dialog regardless of whether there is an
  active AP or not (bgo#661526).
* Tue Oct 11 2011 vuntz@opensuse.org
- Add gnome-control-center-allow-yast-in-shell.patch: allow the
  launch of the YaST shell from the gnome-control-center shell. We
  need a special case as the gnome-control-center shell only
  supports internal panels, but we want an exception for the YaST
  shell.
- Add gnome-control-center-shell-no-crash.patch: fix crash on
  search when a .desktop file has no comment.
- Split /etc/xdg/menus/gnomecc.menu in a branding-upstream
  subpackage, so that we can have a branding-openSUSE package that
  will add YaST to the control center shell.
- Add a Requires on gnome-control-center-branding to the main
  subpackage, to make sure we always have a menu definition for the
  shell.
* Thu Oct  6 2011 glin@suse.com
- Add gnome-control-center-network-allocate-nm-connection.patch:
  allocate nm-connection for nma-wireless-dialog so that the user
  can configure the wireless conection settings (bgo#648174).
* Mon Oct  3 2011 vuntz@opensuse.org
- Remove usage of %%mime_database_{post,postun} macros as there is
  no MIME definition installed.
- Do not pass --disable-update-mimedb to configure since it's not
  useful anymore.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + System info:
  - Don't crash when systemd isn't used (bgo#659367)
  - Don't warn if PackageKit isn't around
  - Continue on filesystem query info (bgo#654563)
  + Wacom:
  - Show "stand-by" page when Wacom not available (bgo#657424)
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Color:
  - Fix help links for gnome-help 3.1*
  - Don't assert if the user double clicks the delete profile
    button
  - Fix spawning of gcm-viewer
  - Do not allow the user to choose profiles owned by other users
  - Do not allow the user to set default a profile they cannot
    access
  - Disable 'View details' button if gcm-viewer is not installed
  - Escape profile titles that have markup in the titles
    (bgo#659127)
  - Pack the left and right button groups into two GtkBox
    containers (bgo#659273)
  + Common:
  - Add a way for panels to receive additional arguments
    (bgo#657093)
  - Bump GTK+ deps
  - Tell the actual required version for NM
  + Display:
  - Remove duplicate/unused translations
  + Info:
  - Don't warn when the hostname is empty
  - Do fallback correctly when reading hostnames
  - Split the hostname setting
  + Keyboard:
  - Link directly to the layouts page
  + Network:
  - Show wireless dialogs when asked (bgo#657093)
  - Fix memleak when argv changes
  - A segfault was introduced when assigning to args (bgo#658670)
  - Bind HTTP host entry to the 'host' setting in GSettings
  + Printers:
  - Match lower-case properly
  + Region:
  - Add ability to switch pages
  - Fix display of layouts on the system tab
  - Only offer to copy settings if they are different
  + Screen:
  - Don't fill up the space
  - Fix resulting top-padding (bgo#657606)
  - Remove indent on "Turn off..." label
  + Shell:
  - Replace window sizing code (bgo#658068)
  + Sound:
  - Put the level bar at 0 when muting (bgo#644537)
  - Allow switching tabs from the command-line
  + Universal access:
  - Fix sensitivity of keyboard a11y (bgo#649452)
  - Add context for text sizes (bgo#645729)
  - Set contrast combo on startup (bgo#658990)
  + User accounts:
  - Hide old message when enrolling
  + Wacom:
  - Add a left-handed switch (bgo#657810)
  - Improve alignment of lines and widgets (bgo#657425)
  - Make string as translatable
  + Updated translations.
- Add pkgconfig(libnm-gtk) BuildRequires: new dependency.
* Tue Sep  6 2011 vuntz@opensuse.org
- Add system-config-printer-dbus-service Recommends: the printers
  panel can used the dbus service (to find the best drivers for a
  printer, for instance).
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Color:
  - Ensure the calibrate program gets run correctly
  - Use a mnemonic character on the Import button (bgo#658167)
  - If cancelling profile import don't show the empty assign
    dialog (bgo#658180)
  - Do not use a GtkSeparatorToolItem in the GtkToolbar
  + Display:
  - Clean up signal handling when finalized (bgo#657919)
  + Media:
  - Use new media-removable icon (bgo#657801)
  + Network:
  - Set the org.gnome.system.proxy.http 'enabled' key if the user
    sets a HTTP proxy
  - Explicitly unset 'use-same-proxy' as there's no UI for that
    (bgo#657235)
  + Power:
  - Don't print a message to .xsession-errors if it's not an
    error
  - Use a proper icon for the panel (bgo#645536)
  - Update the UI to reflect the new mockup
  + Screen:
  - Hide brightness heading when unused (bgo#657606)
  + Shell:
  - Use symbolic name for minimum height
  + Sound:
  - Add some (element-type) annotations to appease g-i master
  + Wacom:
  - Dim the labels (grey, not black) (bgo#657812)
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Background:
  - Allow SVG image files as background (bgo#648764)
  + Color:
  - Fix a crash where out internal state gets screwed up
  - Only allow the user to import custom profiles with colord >=
    0.1.12
  - Remove color managed devices if they are deleted by another
    process
  - Do not attempt to delete the device if it's already added
  - If there are no profiles or devices then hide the toolbar
  - Add a small italic indication when there are no color managed
    devices
  - Add a new 'Learn more' button to the color panel
  - If we have only a few devices and profiles expand the
    treeview at startup
  - Remove unneeded category
  - When setting the default profile for a display, use the
    correct device
  + Common:
  - Simplify language display
  - Add api for region names
  - Add a region mode to the language chooser
  - Tweak default user list
  - Fix distribution of language chooser glade file
  + Date & Time:
  - Use radio buttons for 24h time (bgo#640059)
  + Display:
  - Clean up ifdef's
  - Simplify panel code
  - Fix the labeller not disappearing
  - Prefer higher frequency modes (bgo#655041)
  + Keyboard:
  - Add link to the Region panel (bgo#643101)
  - Simplify GtkBuilder calls
  - Use icon without a spanner (bgo#657556)
  + Network:
  - Mobile broadband bug fixes (bgo#657303)
  - Fix possible double-free
  - Fix display of IP info for some configs (bgo#657303)
  - Fix updating VPN info when edited (bgo#723489)
  - Show VPN type and info in panel
  - Clarify the VPN service type setting
  - Rename "Options..." to "Configure..." (bgo#657002)
  - Fallback to GNOME as a hotspot name
  - Use icon without a spanner (bgo#657556)
  + Online accounts:
  - Disable buttons when D-Bus service not available (bgo#652572)
  + Power:
  - Remove power and suspend buttons config (bgo#652183,
    bgo#657068)
  - Don't shrink the panel on desktops
  + Region:
  - Avoid a crash in the absence of configured layouts
  - Fix locale-changing code
  - Redo the language tab
  - Redo the formats tab
  - Use region names on the region tab
  - Show fewer regions
  - Ensure the system tab is updated
  - Add some spacing to the system tab
  - Initial implementation of 'copy to system'
  - Avoid crash when systemd is not available
  - Don't show region panel in Unity, it uses its own language
    selector
  + Shell:
  - Only load desktop files from our dirs
  - Don't repeat the item title when searching (bgo#657020)
  - Add Ctrl+Q as a way to exit the shell (bgo#653443)
  + Sound:
  - Remove trailing spaces in strings (bgo#657169)
  - Track PulseAudio connection state and expose it (bgo#645708)
  - Update volume-control applet for GVC API changes (bgo#645708)
  - Don't warn without a sizegroup
  - Fix sizing of sliders
  + System info:
  - Always show the "Updates" button (bgo#645274)
  + Universal access:
  - Add more keywords to the desktop file (bgo#657189)
  - Add translator comments (bgo#657167)
  - Keep "text size" items a constant size (bgo#657188)
  - Don't crash when metacity isn't installed
  + User accounts:
  - Remove some dead code
  - Add a filter entry to the language dialog
  - Prepopulate the language combo
  - Remove trailing space in string (bgo#657169)
  - Add translator comments for split line (bgo#657168)
  - Prevent autologin for disabled users (bgo#649816)
  - Fix life-cycle issues
  + Wacom:
  - Add a wacom control panel (bgo#640981)
  + Updated translations.
- Drop removal of no translations: it is gone now.
* Thu Aug 18 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Common:
  - Add some more debug when listing languages
  + Network:
  - Default to g_get_host_name if pretty hostname call failed
  + Printers:
  - Open firewall for required connections when searching
  - Use system-config-printer's GetBestDrivers method
  - Use system-config-printer's GroupPhysicalDevices method
  - Use system-config-printer's MissingExecutables method
  + Region:
  - Keep selection when moving layout up/down
  - Sort locales for format selection
  - Display user's input source in System tab
  + Shell:
  - Port to new gnome-menus API
  - Do not add a trailing dash in search target when comment is
    empty
  + Sound:
  - Update the sound theme for speaker testing
  + Bugs fixed: bgo#654742, bgo#654880, bgo#655110, bgo#655487.
  + Updated translations.
- Change pkgconfig(libgnome-menu) to pkgconfig(libgnome-menu-3.0)
  to follow move to new gnome-menus API.
- Add pkgconfig(libnotify) BuildRequires: new dependency.
* Wed Aug  3 2011 andrea@opensuse.org
- split out faces package so that any Display manager other than
  gnome with gdm can use it
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Background:
  - Add "swap" button for gradients (bgo#34498)
  + Common:
  - Add safeguards for empty language
  + Date & Time:
  - Restore TZ envvar as it was (bgo#649568)
  + Info:
  - Use the new g_format_size() glib function
  + Network:
  - Kill compilation warnings
  + Power:
  - Use the new gnome-settings-daemon DBus names now the power
    plugin has moved to g-s-d
  - Make insensitive any sleep actions the hardware cannot do
  + Printers:
  - Make model label and ip address label selectable (bgo#651545)
  - Add translation context in some places (bgo#654725)
  + Region:
  - Add weak ref for locale settings
  - Set LC_ specific variables, not LC_ALL
  - If no regional settings, use the configured language
  - Show measurement
  - Don't use markup in bold labels
  + Screen:
  - Avoid making lots of DBus calls to set the brightness when
    the slider change too quickly
  + Shell:
  - Shrink vertically (bgo#645808)
  + Sound:
  - Make hadware page tree a little taller
  + Universal access:
  - Remove unused column in model
  + User accounts:
  - Improved new username format message (bgo#647851)
  - Remove unneeded markup in label
  + Updated translations.
* Wed Jul 20 2011 vuntz@opensuse.org
- Add gnome-themes-accessibility Requires, as the themes are used
  in the Universal Access panel. Fix bnc#690176.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Common:
  - Bump gsettings-desktop-schemas requirement for locale
    settings
  - Add Unity to OnlyShowIn fields (bgo#653661)
  + Library:
  - Typo preventing compilation on some platforms (bgo#651162)
  + Color:
  - Add new color setting panel
  + Date & Time:
  - Fix date sensitivity on permission changes
  + Info:
  - Skip test-hostnames if en_US.UTF-8 is not available
  - Fix disk space showing free space (bgo#639376)
  - Fix https scheme handler app setting (bgo#653211)
  + Keyboard:
  - Force "icons" toolbar style (bgo#651595)
  - Change precedence for schema in KeyList parser (bgo#653685)
  - Fix a small memory leak (bgo#653613)
  - Support string array keybindings
  + Network:
  - Implement network sharing
  - Fix the wpad warning
  - Avoid a possible crash
  - Use the correct condition for the option button
  - Refresh ui in an idle
  - Add warning dialogs
  - Remove spaces before question marks
  - Avoid uninitialised variable
  - Fix toolbar style (bgo#651595)
  + Online accounts:
  - Add panel for gnome-online-accounts
  + Printers:
  - Allow editing of printer name and location (bgo#649511)
  - Use SNMP CUPS backend to discover printers on given address
  - Move check for availability of CUPS to better place
  - Include cups/ppd.h explicitly
  - Force icons toolbar style (bgo#651599)
  + Region:
  - Add 'formats' tab
  - Add 'system' tab
  - Fix the labels according to the usability gurus (bgo#641021)
  - Fix a couple of memory leaks (bgo#652360)
  - Fix infinite loop dealing with gsettings 'changed' signal
    (bgo#652361)
  - Remove helper function not needed since GTK+ 3.0 (bgo#652374)
  - Trigger the layout chooser dialog response on 'row-activated'
    signal (bgo#652409)
  - Force icons only toolbar style
  + Shell:
  - Move the raised class hint to the tool item
  - Don't update the visibility of the lock button (bgo#652299)
  - Make --help-all and --help-gtk work (bgo#652165)
  - Use proper Unicode ellipses in the search renderer
  - Fix bad rendering of search results (bgo#652709)
  - Print warning for uninstantiable panels (bgo#652585)
  + Sound:
  - Fix direction of speaker test in RTL languages (bgo#651273)
  + User accounts:
  - Fix fingerprint assistant (bgo#649678)
  - Fix deleting users on 32-bit systems (bgo#652073)
  + Xrandr:
  - Change "Anti-Clockwise" to "Counterclockwise" (bgo#652569)
  + Updated translations.
- Add pkgconfig(colord) BuildRequires for the new Color panel.
- Add pkgconfig(goa-1.0) and pkgconfig(goa-backend-1.0)
  BuildRequires for the new Online accounts panel.
- Change Group of devel subpackage from System/GUI/GNOME to
  Development/Libraries/GNOME to fix rpmlint warning.
- Call %%suse_update_desktop_file for gnome-sound-applet,
  gnome-color-panel and gnome-online-accounts-panel.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Common:
  - Buildsystem fixes
  + Mouse:
  - Update from gnome-settings-daemon [bgo#695041]
  + Network:
  - Properly select the active ap [#649934]
  + Power:
  - Only show the 'When power is critically low' when there is a
    laptop battery or UPS attached [#646053]
  + Printers:
  - Remove the subscription renewal timeout when the panel
    goes away
  - Make Add button insensitive until user select a printer
  - Improve search for PPDs for new devices
  - Check presence of new printer
  + Shell:
  - Add raised style to "All Settings" button [bgo#645809]
  - Kill warning in g_print call
  + User accounts:
  - Show username when no real name [bgo#648348]
  - Fix bug when name is changed to contain markup
  - Don't call gtk_main_quit if AccountService is unavailable
  + Updated translations.
* Thu Apr 28 2011 fcrozat@novell.com
- Update to version 3.0.1.1:
  + Shell:
  - Fix initial state of 'search' icon in entry
  + Display:
  - bgo#648620: Avoid critical warnings at startup
  + Keyboard:
  - bgo#648091: always add 'custom shortcuts' section.
  - bgo#648187: make adding custom shortcuts work.
  - Make unsetting custom shortcuts work
  + Region:
  - bgo#647717: add 'clear' icon in search entry.
  + Updated translations.
- Changes from version 3.0.1:
  + Shell:
  - Don't exit when --help is called and the shell is already
    running.
  - Center by default.
  + Background:
  - Allow adding multiple images at once.
  + Date & Time:
  - Fix critical on startup.
  - Add support for all the possible TZ set on a Linux system.
  + Info:
  - Fix possible crash.
  - Don't block the UI when checking for free space.
  + Keyboard:
  - Fix shortcuts disappearing when creating a new workspace.
  - Handle shortcut conflicts when they occur in a different
    section.
  + Network:
  - Add support for connecting to hidden wireless networks.
  + Printers:
  - Fix setting the default printer.
  - Fix initial state of printer list.
  - Make it possible to cancel adding new printers.
  - Set default papersize according to the locale.
  - Make it faster by caching PPDs for the local printer.
  + Removable Media:
  - Make "never autorun" checkbox work.
  + Sound:
  - Only autostart panel applet in GNOME.
  - Fix clipping when sound volume is > 100%%.
  + User accounts:
  - Try hard to not show the "root" account.
  - Use local documentation for "good password".
- Remove gconf schema handling as everything was moved to
  gsettings.
* Mon Apr 25 2011 vuntz@opensuse.org
- Add cups-pk-helper Requires, since it is needed for the Printers
  panel.
- Add gnome-version Requires, as it is used by the sysinfo panel.
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 3.0.0.1:
  + Background:
  - Fix a compiler warning
  + Date & Time:
  - Fix test-endianess on OpenSUSE (bgo#646780)
  + Network:
  - Avoid assertions with mobile broadband devices
  + Printers:
  - Actualize printer and job lists automatically
  - Avoid crash if policy is unavailable
  - Don't set a reason when setting AcceptJobs
- Changes from version 3.0.0:
  + Common:
  - Remove API reference, as it's incomplete and going away for
    next cycle.
  - Fix build on fresh checkouts
  + Shell:
  - Turn off spinner cursor when launched (bgo#646045).
  + Background:
  - Don't show errors when loading default bg (bgo#646056).
  - Don't use the GnomeBG thumbnails for the preview area
    (bgo#646180).
  - Don't assert() for typos in XML files (bgo#646250).
  + Keyboard:
  - Set repeat-interval correctly (bgo#646241)
  - Bump gnome-settings-daemon requirement
  + Network:
  - Use symbolic icon for ad-hoc wireless connections
    (bgo#646140).
  - Hide the security cell renderer if there's no icon to display
    (bgo#646140)
  - Do not add bluetooth devices to the panel to avoid asserting
    the control-center.
  - Fix build against NetworkManager on Debian (bgo#646349).
  - Reset the network name combo when disconnected (bgo#646031).
  - Display more detailed status for unavailable devices
    (bgo#646027).
  - Make creating vpn connections work again.
  + Printers:
  - Make "Print Test Page" button always sensitive
  - Do not delete browsed printers
  + Region:
  - Make the layout options modal (bgo#646183).
  + Sound:
  - Make the volume icons smaller and center them properly in the
    bar (bgo#646153).
  - Make sound applet work again in fallback (bgo#646044).
  + Universal Access:
  - Don't incorrectly mark some hboxes as insensitive
    (bgo#646240).
- Drop fix-timezone-build.patch: fixed upstream
- Ensure suse_update_desktop_files is called on all .desktop files.
* Wed Mar 30 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Common:
  - Add a --verbose option to the shell
  - Make sure the desktop file uses categories that show up in
    menus.
  + Background:
  - Make the window fit on small screens
  + Date & Time:
  - Fix time widget ordering in RTL locales
  + Network:
  - Drop creation of custom connections for now, except for VPN
  - Show a padlock icon for 'secure' access points
  - Memory leak fixes
  - Implement on/off switch for wired devices
  - Properly track VPN connection state
  - Use grids for better UI alignment
  - Handle NetworkManager restarts gracefully
  + Power:
  - Use a better icon
  + Printing:
  - Use a single privilege to unlock the entire page
  - Honor disable-print-setup lockdown setting
  - Use CUPS printer test page
  + Region:
  - Remove tooltips from layout list
  + Sound:
  - Port to GSettings
  - Fallback if loading a non-existent custom theme
  + Universal Access:
  - Bring screen reader option back
  + User Accounts:
  - Remove stray debugging output
  - Make crop window modal
  - Fix crop window background color
  + Updated translations.
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + Common:
  - Bump GTK+ dep to 3.0.2 (bgo#644182)
  - Fix linking of libshortcuts against (bgo#644410)
  - Improve CUPS detection (bgo#644064)
  - Set the 'inline-toolbar' style class to toolbars which need
    it (bgo#645059)
  + Background:
  - Use new picture-uri GSettings key (bgo#633983)
  + Date and Time:
  - Change combobox when map is clicked
  - Make 24h setting changeable without unlocking (bgo#643891)
  - Add missing timezone files (bgo#630261)
  - Add hacks to support more timezones
  - Don't crash when the timezone is unknown
  + Display:
  - Fix dragging rotated monitors (bgo#641345)
  + Info:
  - Use dim labels
  + Keyboard:
  - Fix crasher when num workspace changes (bgo#644784)
  - Mark the scales as insensitive when the checkboxes are off
    (bgo#645151)
  - Correct labels for blinking speed (bgo#645314)
  + Mouse:
  - Don't destroy the touchpad tab
  - Check caps of the touchpad when added
  - Make sure we fit within our minimum vertical size
  - Don't reset scrolling method on start (bgo#642474)
  + Network:
  - Show the wireless security currently being used
  - Do not show a provider string for mobile broadband devices
    when not connected.
  - Do not show the IPv6 address if nm_device_get_dhcp6_config()
    failed.
  - nm_device_wifi_get_bitrate() returns values in kb/s, not
    Mb/s.
  - Hide UI controls that are not connected up to anything yet.
  - Display the IPv6 address if one is provided for the device.
  - Never show the loop device if IP4 data isn't available.
  - Use an abstract device so we can get the VPN connection data/
  - Show the VPN connection state in the panel header.
  - A disconnected wired connection is 'Unplugged', not
    'Disconnected'.
  - Display a different icon if the wired ethernet device is
    disconnected.
  - Do not show a speed of zero for any device
  - Ensure we refresh the UI if coldplug devices are changed
  - Add Option buttons
  - Fix some alignment and focus issues
  - Add a device off switch
  - Implement and show on/off switch for wireless/wimax
  - Refresh UI when active connections change
  - Add Option buttons to allow editing connections
  - Watch for new VPN connections being added and add them to the
    panel.
  - Drop tooltips on the device list (bgo#644964)
  - Use dim-label style class for labels (bgo#644964)
  - Fix version compatibility warning dialog (bgo#644973)
  - Avoid header pixel noise and inconsistent spacing
    (bgo#644954, bgo#644955)
  + Printers:
  - Attach 'add printer' dialog to toplevel (bgo#644213)
  - Call cupsGetDevices() asynchronously (bgo#644212)
  - Use dim-label to accentuate values
  - Set longer timeout for installation of printer driver
  - Don't sort printers by usage
  - Handle no printers situation better (bgo#641421)
  - Show IP address of printer
  - Change text about unavailability of CUPS (bgo#641421)
  - Fix alignment in secondary notebook pages
  - Show computer-fail icon when can not connect to CUPS (bgo#641421)
  + Region:
  - Using separate window group to avoid modal shadowing
  - Stop layout add dialogue from "jumping"
  - Make drag'n'drop work
  + Screen:
  - Fix the delay acrobatics (bgo#644403)
  - Drop converting between seconds and minutes
  - Set the label as insensitive when Lock is off (bgo#645149)
  - Honor disable-lock-screen setting
  + Shell:
  - Fix resizing when switching from panel to panel (bgo#636596)
  + Sound:
  - Fix scroll event handling of channel bars (bgo#644462)
  - Fix ordering of typedefs
  - Use upstream value for amplified volume (bgo#644292)
  - Add introspection info for new GIcon function
  - Remove old support code for PA < 0.9.15
  + Universal access:
  - Set the name to the right hboxes (bgo#645135)
  - Use NO_SENSITIVITY flag for g_settings_bind() (bgo#645171)
  + User accounts:
  - Use dim-label class instead of hardcoded color
  - Update cheeese minimum requirements
  - Nuke supervised accounts
  - Don't warn if there are no faces pixmaps (bgo#645347)
- Changes from version 2.91.91:
  + Shell:
  - Reload the list of panels when new ones are added
  + Date and Time:
  - Use correct order for date widgets when in non-US locales
  + Info:
  - Look for which device is being driven by the VESA driver
  - Remove (tm) from GNOME logo
  + Keyboard:
  - Add support for the magnifier zoom in/out shortcuts
  - Fix loading of custom shortcuts
  - Fix initial selection in the shortcut pane
  - Make shortcut conflicts code actually work
  - Fix warning about "editing-canceled"
  - Make repeat rate and speed follow a11y guidelines
  + Network:
  - Update for recent NetworkManager changes
  + Printers:
  - Don't show driver version in the model name
  - Add dialogue for adding new printers
  + Region and Language:
  - Don't block the interface when loading the panel
  - Do not allow adding the same keyboard layout twice
  + Sound:
  - Fix only starting applet in fallback session
  + Universal Access:
  - Show actual keyboard shortcuts as defined in Keyboard
  - Make "on-screen keyboard" switch work
  - Fix initial state of typing help
  - Add "smaller text" size
- Add fix-timezone-build.patch: fix locale path, used at build time
  to check if timezone data are available.
- Add pkgconfig(cheese-gtk) BuildRequires: allow to take user
  face snapshot from user account dialog.
- Add freeglut Requires: system info panel needs glxinfo binary.
* Wed Mar  2 2011 vuntz@opensuse.org
- Remove gnome-patch-translation support as there are no strings
  added by patches anymore:
  + remove gnome-patch-translation BuildRequires.
  + remove calls to gnome-patch-translation-prepare/update in
    %%setup.
* Thu Feb 24 2011 fcrozat@novell.com
- Update to version 2.91.90:
  + Background:
  - Remove loading of obsolete backgrounds
  - Load initial state from GSettings
  - Don't warn when trying to load a gradient
  - Make loading wallpapers seem faster
  - Show 'Adwaita' as the first in the list (bgo#637384)
  - Handle no-flags from saved config
  - Set the shading for pictures
  - Add/Remove features for panel
  - Don't show an error if no cache dir
  - Add arrows for the gradients
  + Date & Time:
  - Don't crash when g-s-d is badly installed (bgo#641232)
  - Create filenames locale-independently (bgo#641294)
  - Fix crash when TZ is an alias (bgo#641360)
  - Fix city combobox filtering
  + Display:
  - Remove support for old D-Bus interface
  - Simplify some old GNOME 2.x code
  + Info:
  - Make labels selectable
  - Add graphics info
  - Add special case for Atom(TM)
  - Add panel chooser, graphics tab (bgo#642068)
  - Add stub for default apps page
  - Clarify language in force fallback controls
  - Correctly detect the fallback session
  + Keyboard:
  - Change grouping of keys
  - Improve the layout of the bindings page
  - Clean up GConf handling
  - Add support for GSettings shortcuts
  - Pass a gettext package when loading GConf
  - Don't resize the shell horizontally
  - Don't expand tables vertically
  - Add Universal Access shortcuts (bgo#641279)
  + Network:
  - Wrap long dns lines
  - Select the first device after they are all loaded
  - Use the same border width as other panels
  - Use emblem-default-symbolic for the default printer
  - Disable NetworkManager when the airplane switch gets changed
  - Show the wired network subnet mask
  - Fix a crasher due to an uninitialized GVariant
  - Fix linking
  - Port to the rm-userset branch of NetworkManager
  - Only add the strongest AP for each SSID to the drop down box
  + Printers:
  - Right align the image
  - Use a 64px icon
  - Don't expand switch vertically
  - Fix panel width
  - Allow location and model to span cols again
  - Add unlock button (bgo#640733)
  - Sort printers by usage (bgo#641285)
  - l10n fixes for jobs count
  - Add translation context to statuses (bgo#641339)
  - Avoid unnecessary use of markup
  - Check that cups is recent enough
  - Change widget showing supply levels
  - Don't show printers separator when not needed
  - Don't try to draw empty ink level
  - Replace "Idle" state by "Ready"
  - Set Options and Show buttons sensitive
  + Region:
  - Use consistent border spacing
  - New search-based layout addition (bgo#640772)
  - Minor UI tweaks in kbd layout chooser
  - Remove annoying tooltip on a treeview
  - Easier to understand layout switching options (bgo#641021)
  - Remove code to handle print button
  - Some UI fixes for the layout chooser
  - Make layout filtering much faster
  - Fix overeager string splitting
  - Fix the modality of the Preview dialog
  + Screen:
  - Simplify GtkBuilder-using code
  - Hide the brightness slider when it cannot be set
  - Hook up screen locking (bgo#637939)
  - Set idle-delay to the same value as DPMS timeout
  - Make sure the combo box is always set
  - Fix the operation of locking
  + Shell:
  - Add shortcuts to focus search entry (bgo#409230)
  - Don't pass invalid option flags (bgo#641290)
  - Use symbolic icons in the search entry (bgo#642167)
  - Sort the icons alphabetically
  - Make sure the search entry doesn't appear when in a panel
  - Fix searching for anything hiding widgets
  + Sound:
  - Try using symbolic icons for range widgets (bgo#614213)
  + Universal Access:
  - Allow the pointer page to use less horizontal space
  - Hide options that are currently unavailable (bgo#639784)
  - Implement the zoom setting
  - Adjust for magnifier schema changes
  - Use switches instead of radio groups
  - Show the typing assistant widgets
  + User Accounts:
  - Use 0 instead of blank to clear options
  - Port to GtkStyleContext
  - Hide fingerprint dialogue by default (bgo#641990)
  + Updated translations
- Add pkgconfig(libnm-glib) BuildRequires.
* Tue Feb 22 2011 fcrozat@novell.com
- Changes from version 2.91.6:
  + Way too many changes since 2.32 to list here. Please see NEWS
    the full list. Here are the highlights:
  + Port to GTK+ 3 and migrate to GSettings.
  + New control center shell, with panels, instead of independant
    capplets.
  + Revamp most panels, with a streamlined UI.
  + Add new panels: Background, Date & Time, Media (based on what
    was in nautilus preferences), Network (replacing proxy
    capplet), Power, Printers, Sound, System Information, User
    Accounts.
  + Rename Keyboard capplet to Region panel, and add language
    selection there.
  + Rename Keybinding capplet to Keyboard panel.
  + Drop default applications capplet.
  + Add various nice features here and there (support backgrounds
    from Flickr, make it possible to configure the use of NTP,
    etc.)
- Add cups-devel BuildRequires.
- Change pkgconfig() BuildRequires:
  + add gdk-pixbuf-2.0, gsettings-desktop-schemas, iso-codes,
    libsocialweb-client, polkit-gobject-1, gstreamer-0.10,
    libgtop-2.0, libpulse, libpulse-mainloop-glib, upower-glib.
  + change gnome-desktop-2.0 to gnome-desktop-3.0, gtk+-2.0 to
    gtk+-3.0, libcanberra-gtk to libcanberra-gtk3
  + remove libebook-1.2, libmetacity-private, libslab, unique-1.0.
- Add iso-codes Requires.
- Add apg Recommends, needed for user accounts panel.
- Drop gnome-control-center-shell-common-tasks-i18n.patch and
  gnome-control-center-use-settings-menu.patch: they were only
  needed for the slab-based shell, which is gone.
- Drop gnome-control-center-bnc427745-force-dpi.patch: this was
  needed to change font settings, but it's gone.
- Drop gnome-control-center-mime-scheme-handler.patch: defining
  default apps is now handled differently.
- Drop gnome-control-center-symlinked-background.patch: the
  background panel doesn't work the same anymore, and this is not
  needed anymore.
- Use %%glib2_gsettings_schema_* macros.
- Drop libgnome-window-settings1 and libgnome-window-settings-devel
  subpackages, and instead add libgnome-control-center1. Add a
  Requires for it to gnome-control-center-devel.
- Pass --with-libsocialweb to configure because we want to use
  libsocialweb, and remove now non-existing --enable-aboutme
  option.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add call to ./autogen.sh.
  + Do not call %%suse_update_desktop_file in this case.
* Mon Feb 21 2011 vuntz@opensuse.org
- Add gnome-control-center-symlinked-background.patch: if the
  configured background is not known by the backgrourd capplet, but
  it's a symlink to another background which is known, then we only
  want to display this background once. This is useful in openSUSE,
  since the default configured background is such a symlink.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
- Remove 2.x references in summaries and descriptions.
* Thu Jan 13 2011 vuntz@opensuse.org
- Add gnome-control-center-mime-scheme-handler.patch: correctly
  handle default browser and mailer. Because of a change in how gio
  works, the way to register default mailer and browser has changed
  to use MIME types instead of gconf keys. The patch is based on
  cherry-picked changes from git to the gnome-2-32 branch.
- Drop gnome-control-center-bnc436206-add-to-default.patch:
  groupwise should be updated to declare that it supports the
  x-scheme-handler/mailto mime type to be added to the list of
  mailers.
* Fri Nov 19 2010 vuntz@opensuse.org
- Update to version 2.32.1:
  + Default applications:
  - Use 'midori' as icon name for Midori web browser
  + Mouse:
  - Enable 2-finger scrolling through emulation (bgo#625163)
  + Keyboard:
  - Link against libxklavier also
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 2.31.92.1:
  + Display:
  - Add missing include to fix build
  + Updated translations.
- Changes from version 2.31.92:
  + Display:
  - Don't silently ignore errors when pkexec(1) fails
    (bgp#627861)
  + About Me:
  - Use translations from fprintd for finger ops
  + Updated translations.
* Tue Sep  7 2010 vuntz@opensuse.org
- Remove unneeded librsvg-devel BuildRequires.
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: evolution-data-server-devel, gnome-desktop-devel,
    gnome-menus-devel, gnome-settings-daemon-devel,
    libgnomekbd-devel, libslab-devel, libunique-devel,
    libxklavier-devel, metacity-devel, xorg-x11
  + new-style: dbus-1, dbus-glib-1, gconf-2.0, glib-2.0,
    gnome-desktop-2.0, gnome-settings-daemon, gtk+-2.0,
    libcanberra-gtk, libebook-1.2, libgnomekbd, libgnomekbdui,
    libgnome-menu, libmetacity-private, libslab, libxklavier,
    libxml-2.0, unique-1.0, xcursor, xft, xi.
- This will make it easier to switch to GNOME 3 libraries.
* Mon Sep  6 2010 vuntz@opensuse.org
- Add X-SuSE-ControlCenter-Personal category instead of
  X-SuSE-ControlCenter-System and AdvancedSettings to
  default-applications.desktop to make it appear where it should
  in the menu.
- Add X-SuSE-ControlCenter-Hardware category instead of
  X-SuSE-ControlCenter-System and AdvancedSettings to
  gnome-network-properties.desktop to make it appear where it
  should in the menu.
* Wed Sep  1 2010 vuntz@opensuse.org
- Update to version 2.31.91:
  + About me:
  - Fix enrolling with Upek Eikon II fingerprint reader
    (bgo#627249)
  + Shell:
  - Update libslab from master (bgo#612417)
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Updated translations.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.6:
  + Common:
  - Replace deprecated GTK+ symbols (bgo#572325)
  + About me:
  - Don't hang when new and old password are too similar
  - Catch "password too recent" error message (bgo#620135)
  + Font viewer:
  - Create the preview pixmap after the drawing area is realized
  + Keyboard:
  - Changing Print layout to Show layout
  + Shell:
  - Don't include both Personal and Look & Feel
  + Updated translations.
- Changes from version 2.31.1:
  + Common:
  - Use only single GTK+ includes (bgo#615292)
  - Remove GTK+ deprecated symbols (bgo#572325)
  + About me:
  - Don't hang when new and old password only differ in case
  - Minor string updates (bgo#615283)
  - Use changes-prevent and changes-allow icons from the
    icon-them instead of the outdated lock-icons (bgo#408585)
  - Use accessor functions instead direct access (bgo#597888)
  + Display:
  - Add a "Make Default" button in gnome-display-properties,
    which is used to set up a systemwide default RANDR
    configuration
  - Change icon name to preferences-desktop-display (bgo#614912)
  + Keyboard:
  - Added tooltips (bgo#615521)
  - Use new libgnomekbd function for default group switcher
    (bgo#603806)
  - Proper response id for the help button (bgo#616917)
  + Shell:
  - Fix issue with g-c-c shell and YaST shell having same unique
    identifier
  + Typing break:
  - Add support for Ubuntu's app indicator
  + Updated translations.
- Drop
  gnome-control-center-bnc373197-layout-switch-keybinding.patch:
  not needed anymore, since this is now handled in libgnomekbd
  (that we patched).
- Remove libcanberra-gtk Requires: packaging of libcanberra has
  changed, and the login sound will get installed via a Supplements
  there.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Don't hang when new and old password only differ in case
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + About me:
  - Fix global variable confusion
  - Fix remembering of data between runs
  + Appearance:
  - Mark a string for translation (bgo#612015)
  - Fix GTK+ multi-threading (bgo#610003)
  + Display:
  - Don't show a tooltip while a monitor is being dragged
  + Typing break:
  - Lock all the screens (bgo#492974)
  + Updated translations.
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Updated translations.
* Fri Feb 26 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + Appearance:
  - Add 'span' as a style for backgrounds
  + Display Properties:
  - Now fits in 640x480 and has a better layout overall.
  - Just use "monitors" for wording, not a mixture of "monitor",
    "display", "screen".
  - Make the mouse cursor indicate when you can drag a monitor
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.90:
  + About-me:
  - Fix hangs when 'passwd' outputs unexpected answers
  - Fix list of passwd error strings
  - Fix fingerprint name on 2nd page
  + At-properties:
  - Add AutostartCondition to gnome-at-session.desktop
    (bgo#608138)
  + Mouse:
  - Fix mnemonics conflicts on touchpad tab (bgo#608057)
  + Updated translations.
- Fix self-obsoletion of control-center2, control-center2-devel.
* Wed Jan 27 2010 vuntz@opensuse.org
- Update to version 2.29.6:
  + About-me:
  - Add translator comments to 'Home' string (bgo#605944)
  + Appearance:
  - Use GtkInfoBar rather than a copy of GeditMessageArea
  + Common:
  - Don't leak file descriptors when checking for colour schemes
    (bgo#606155)
  + Mouse:
  - Disable tapping only for touchpads without a left mouse
    button
  + Updated translations.
* Wed Jan 20 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Dec 24 2009 vuntz@opensuse.org
- Update to version 2.29.4:
  + General:
  - Drop obsolete check for HAL (bgo#595832)
  - Use external libslab when available
  - Add gthread-2.0 to common modules for linking (bgo#600589)
  - Enable silent build rules
  + Common:
  - Fix all the keybindings showing up when using compiz
    (bgo#600021)
  - Fix leak
  - Fix warning
  + About-me:
  - Fix crash when closing the window using the window button
    (bgo#592348)
  - Add missing PNG files
  + Appearance:
  - Remove interface tab (bgo#592756)
  - Add OnlyShowIn=GNOME to the .desktop file (bgo#594709)
  - Update the background style option labels (bgo#411048)
  - Fix tooltip in the background chooser (bgo#596369)
  - Add support for per-monitor backgrounds (bgo#147808)
  + Default applications:
  - Update the exec arg when changing terminal (bgo#597185)
  - Be sure to add the gconf directories for monitoring
    (bgo#597186)
  - Return an empty string for the custom web item
  + Display:
  - Don't assert when the current output doesn't have a
    resolution set yet (bgo#593866)
  - Automatically turn on outputs which support Mirror Screens
    (bgo#590823)
  - Sensitize 'Mirror Screens' depending on whether mirror mode
    is actually supported
  - Desensitize the on/off radio buttons if we are in Mirror
    Screens mode
  - Show 'Mirror Screens' in the monitor label, not a random
    monitor's name
  + Font Viewer:
  - Use pango_language_get_sample_string for sample text
    (bgo#595107)
  - Expand the Copyright display to get rid of unnecessary
    scrollbar
  - Don't use URI notation when installing fonts (bgo#603732)
  + Keybindings:
  - Fix broken logic in keybinding tree model
  - Fix zombie bindings appearing after deleting custom shortcuts
    (bgo#596351)
  - Show shortcuts for the active window manager (bgo#600531)
  - Remove sleep key entry (bgo#170175)
  + Keyboard:
  - Major UI reorganization
  - Fix mnemonic conflict in mousekeys tab (bgo#586433)
  + Mouse:
  - Disable two-finger scrolling/tapping based on touchpad
    capabilities.
  + Network:
  - Keep proxies in sync when "use same proxy" is selected
    (bgo#589952)
  + Typing break:
  - Increase delay for activating the postpone button to 5s
    (bgo#597086)
  - Reset timer after suspend (bgo#430797)
  + Windows:
  - Don't allow Ctrl+Click as window movement modifier
    (bgo#409405)
  + Updated translations.
- Drop gnome-control-center-default-app-xterm.patch: fixed
  upstream.
- Add libslab-devel BuildRequires.
* Thu Dec 24 2009 vuntz@opensuse.org
- Add gnome-control-center-shell-common-tasks-i18n.patch to
  translate favorite capplets, as set in gconf2-branding. This
  patch needs to be kept in sync with the branding package.
- Add gnome-patch-translation BuildRequires, since we now have
  custom strings.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Sat Oct  3 2009 riggwelter@opensuse.org
- bnc#533491 - Only show Preferred Applications in System section.
* Sat Oct  3 2009 vuntz@opensuse.org
- Add gnome-control-center-default-app-xterm.patch to correctly set
  the exec arg gconf key when changing the preferred terminal. Fix
  bnc#544006.
* Mon Sep 21 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Appearance:
  - bgo#323323 - Add link buttons to get more themes/backgrounds
    online
  - bgo#592510 - Add/remove buttons should be the same size
  - bgo#591375 - Make slideshows visually distinct
  - Don't call gnome_wp_item_ensure_gnome_bg too early
  - Rename some widget ids to make GtkBuilder happy
  - Use XDG user and system data dirs to load backgrounds
  - Fix compiler warnings
  - bgo#584342 - Make the font DPI spin button work again
  - Show correct default layout
  - bgo#594718 - Update icon because the old one has been removed
    from g-i-t
  - bgo#594066 - Allow a window manager to inherit keybindings
    from another window manager
  - Force cursor slide to 100 px, in order to use it without
    changing the window width
  + Common:
  - bgo#592920 - Drop check for libgnomeui
  + Updated translations.
- Drop libgnomeui-devel BuildRequires.
* Fri Aug 28 2009 dimstar@opensuse.org
- Update to version 2.27.91:
  + Appearance:
  - bgo#592182 - Use unique widget IDs
  - bgo#584029 - Add workaround for glade-3 not working with vbox
  - bgo#592354 - Fix parentless modal dialogs in theme installer
  + Common:
  - Add schemas file
  - Fix distcheck
  + Display:
  - Fix dragging of rotate monitors
  + Font viewer:
  - bgo#592642 - Use preferences-desktop-font for the icon
  - Fix filename after GTKBuilder migration
  + Mouse:
  - bgo#592425 - Keep touchpad UI in sync with GConf
  + Network:
  - bgo#581472 - Update the ignored hosts list when the location
    changes
  + Shell:
  - Updated to latest libslab
  + Updated translations.
* Fri Aug 28 2009 vuntz@novell.com
- Remove unneeded PolicyKit-gnome-devel BuildRequires.
* Sun Aug 23 2009 dimstar@opensuse.org
- Update to version 2.27.90
  + About-me:
  - Remove old code poking directly into the pwent
  - Port to PolicyKit-1.0
  + Appearance:
  - bgo#591392 - Fix crash when iterating through the tree model
  - bgo#591656 - Attributes tag is not supported in GtkButtons
  - Make sure the underline in "Save _As..." is interpreted
  + Common:
  - Change error message reference about Bonobo to DBus
  - bgo#590933 - Remove markup from translatable string
  - Fix compiler warnings
  - Fix requires in gnome-window-settings-2.0.pc
  + Display:
  - Don't start the outputs before creating the labeler
  - Remove dead code
  - Ensure that the output labels fit inside the monitor
    rectangle
  + Shell:
  - bgo#568527 - Remove libgnomeui usage
  - Do not depend on libpanel-applet
  - Use GOption in the shell
  - Fix error message with unknown option in shell
  - Use libunique in the shell to have a single-instance shell
  - Update to latest libslab, and do not install libslab on the
    system
  + Updated translations.
- Drop gnome-control-center-libslab.patch: included upstream.
- Replace gnome-panel-devel BuildRequires by libgnomeui-devel.
* Thu Aug 13 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Default applications:
  - Don't clear the custom browser command on startup
    (bgo#590316)
  + General:
  - Remove all libglade dependencies
  - Remove markup from translatable strings in GTKBuilder files
    (bgo#599759)
  + Network:
  - Fix unparsed mnemonics (bgo#590364)
  + Shell:
  - Removed deprecated dependencies from libslab
  - Adapted shell to new libslab API
  - Remove libgnome and libgnomeui dependencies
  + Updated translations.
- Respin gnome-control-center-use-settings-menu.patch.
- Add gnome-control-center-libslab.patch, taken from git, to fix
  some mess with the internal copy of libslab.
- Remove gstreamer010-plugins-base-devel, libglade2-devel
  BuildRequires.
- Remove Recommends on gnome-audio: that's not true anymore (the
  capplet handling this has moved to gnome-media).
- Split out libraries in their own packages:
  libgnome-window-settings1, libgnome-window-settings-devel.
- Remove permissions PreReq and the call to
  run_permissions/verifyscript/verify_permissions since we don't
  ship change-passwd anymore.
- Remove libexecdir argument from configure.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.27.4.1:
  + About me:
  - EXTRA_DIST fingerprint icons
  + Common:
  - Automatically generate .gitignore files with git.mk
  + Network:
  - Remove libglade dependency from gnome-network-properties
  + Updated translations.
- Changes from version 2.27.4:
  + About me:
  - New icons for fingerprint screen
  + Appearance:
  - Migrate to GtkBuilder
  - Remove custom cell renderers
  + At-properties:
  - Remove libglade depency from at-properties capplet
  + Default applications:
  - Remove libglade dep from default-applications capplet
  + Display:
  - Remove libglade dependency from display-properties capplet
  + Keybindings:
  - Remove libglade dependency from keybindings capplet
  + Mouse:
  - Support touchpad configuration through device properties
  + Shell:
  - Fix libslab for single includes in GTK+
  + Typing break:
  - Use GtkUIManager to replace GtkItemFactory
  + Windows:
  - Strip libglade dependency from gnome-window-properties
  + Updated translations.
- Changes from version 2.27.3:
  + About me:
  - Initialize GThread subsystem (bgo#583451)
  + Appearance:
  - Search GTK+ icon theme search path for icon themes
    (bgo#575906)
  - Only delete the theme if the user pressed OK (bgo#578694)
  - Close gtkrc files after use (bgo#578835)
  - Fix theme engine detection on non-UNIX platform (bgo#581156)
  - Don't unref NULL GConf entries
  - After removing an image set the cursor to the newly selected
    wallpaper (bgo#575075)
  + Default applications:
  - Add Arora to list of browsers
  + Display:
  - Pass a transient parent ID to the ApplyConfiguration callback
    so that it can make its confirmation dialog a child of the
    parent (bgo#576006)
  - Simplify calls to dbus-glib which cannot fail
  - Ensure that there will be a backup file before committing
    (bgo#486093)
  - Make the monitor heading be explicitly black (bgo#556050)
  - Fix the layout-outputs-horizontally helper
  - Use the timestamp of the Apply button to change the RANDR
    configuration
  - Don't pop up a redundant error dialog
  + Font viewer:
  - Safely printf strings
  - Interrupt thumbnailing at 30 s instead of 30 msecs
    (bgo#584107)
  + Keybindings:
  - Make activating a section header row expand or collapse the
    section as expected instead of crashing (bgo#577474)
  - Make the custom keybinding UI smoother
  - Don't needlessly write entries back to gconf on startup
    (bgo#581986)
  + Keyboard:
  - Dependency on libxklavier 4.0, optional load/display of extra
    layouts
  + Shell:
  - Fix libslab svn:external problem
  + Updated translations.
- Move the control-center help files to the lang package.
- Disable gnome-control-center-system-proxy-configuration.patch:
  this needs rebasing.
* Mon Jun  1 2009 sreeves@novell.com
- Fix bnc#436206 - add GroupWise to the defaults
* Wed May 27 2009 vuntz@novell.com
- Remove gnome-passwd and enable gnome-about-me instead (which
  requires --enable-aboutme in configure).
- Add PolicyKit-gnome-devel BuildRequires.
- Remove gnome-patch-translation support.
- Drop control-center-art.tar.bz2 which contains old icons.
- Do not add DocPath to desktop files: it's not needed for yelp.
- Rename gnome-control-center-system-proxy-configuration.diff to
  gnome-control-center-system-proxy-configuration.patch
* Mon May 25 2009 federico@novell.com
- Updated and enabled gnome-control-center-system-proxy-configuration.patch
  so that it builds with this version of gnome-control-center.
* Tue Mar 17 2009 vuntz@novell.com
- Update to version 2.26.0:
  + About me:
  - Fix warning when selecting a finger to enroll in the combo
    box (bgo#574974)
  + Default applications:
  - Fix mnemonic conflicts
  + Display:
  - Make the strings of the rotation dialog appear translated
    (bgo#574693)
  - Fix crash when refreshing RANDR configuration (bgo#574865)
  + Font viewer:
  - Stop the font thumbnailer eating all the CPU (bgo#573795)
  + Keybindings:
  - Fix mnemonics conflict on the custom shortcut window
  + Typing break:
  - Revert string freeze breaker (bgo#572325)
  + Updated translations.
- Remove fontilus.xml: it shouldn't be needed anymore, since
  shared-mime-info contains this.
- Don't move gnome-keybindings.pc to /usr/lib/pkgconfig: it's fine
  in /usr/share/pkgconfig
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.92:
  + General:
  - remove lots of deprecated GDK/GTK+ calls (bgo#572325)
  + Appearance:
  - fix message markup appearing in post-install dialog
    (bgo#572453)
  + Display:
  - don't block the GUI while changing RANDR configuration
  - realign outputs after a resolution change
  - use black text for enabled monitors
  - change window title and menu entry to "Display"/"Display
    Preferences" (bgo#570907)
  + Keybindings:
  - fix saving custom shortcut commands (bgo#572501)
  - always show "<Unknown Action>" for shortcuts without a
    description (bgo#572808)
  + Keyboard:
  - add visual bell settings (bgo#564998)
  - fix initial layout preview (bgo#550721)
  - restore help button in layout options (bgo#556952)
  - remove non-existing icon from sound notifications button
    (bgo#570906)
  + Font Viewer:
  - initialize type system to fix hang (bgo#572189)
  + Updated translations.
- Remove -fno-strict-aliasing from CFLAGS.
- Remove AutoReqProv: it's default now.
* Thu Mar  5 2009 vuntz@novell.com
- Add libgnomeui-devel to Requires of devel package.
* Thu Feb 12 2009 vuntz@novell.com
- Call %%suse_update_desktop_file on gnome-network-properties
* Thu Feb  5 2009 mboman@suse.de
- Update to version 2.25.90:
  + General:
    + Rename gnome-network-preferences to gnome-network-properties
    (bgo#554342)
  + About me:
    + Build fixes
    + Fix email addresses being generated by g-a-m always being
    saved as type
    + "OTHER" (Jens Granseuer) (bgo#570113)
  + Appearance:
    + Fix newly installed themes appearing twice in the GTK themes
    list if the package contains themes for both GTK and
    metacity (bgo#568595)
    + Use "Desktop Background" instead "Wallpaper" as per GDP
    glossary (bgo#569382)
  + Common:
    + Add GnomeThemeElement parameter to the ThemeChangedCallback
    so that the receiver can determine what part of the theme
    changed
  + Default application:
    + Fix the https handler never being set (bgo#568408)
    + Update the web entry with the correct command for the
    selected option instead of always using the default
  + Display:
    + Build fixes
    + Add On/Off radio buttons to turn on/off a monitor
    + Don't crash if we don't have an output (bgo#569218)
  + Keybindings:
    + Build fixes
    + Print a warning when a key doesn't have a schema,
    so no description
    + Make Enter work as expected in the custom key shortcut
    edit dialogue
  + Keyboard:
    + Sort options by description
    + Hide help button in Options (bgo#556952)
    + Allow setting a repeat delay of up to 2 seconds (bgo#569612)
  + Shell:
    + Use single GTK includes in slab (bgo#551850)
    + Compile with G*_DISABLE_DEPRECATED in slab (bgo#551850)
  + Typing break:
    + Play a sound when the display is locked or unlocked
    (bgo#169473)
  + Translation updates
- Update gnome-control-center-passwd-dialog.patch
* Fri Jan 23 2009 vuntz@novell.com
- Really apply gnome-control-center-bnc427745-force-dpi.patch
- Drop gnome-control-center-desktop.patch: the only relevant
  changes to desktop files are now done via
  %%suse_update_desktop_file
- Drop gnome-control-center-docpath.patch: we don't use DocPath in
  GNOME.
- Reduce BuildRequires.
- Remove specific commands for old version of openSUSE, including
  the handling of permissions stuff that is now done another way
  (so we can drop permissions.tar.bz2 too)
- Other minor tweaks to clean up the spec file.
- Call %%suse_update_desktop_file on all desktop files. Part of
  bnc#445728.
* Sat Jan 17 2009 crrodriguez@suse.de
- remove "la" files, baby step to clean up all references
  to libavahi-*.la
* Fri Jan  9 2009 federico@novell.com
- Remove gnome-control-center-randr-gerror.diff. Fixed upstream
* Fri Jan  9 2009 federico@novell.com
- Added gnome-control-center-randr-gerror.diff.  This adds good error
  reporting when changing the multihead configuration, and fixes these
  bugs:
  bnc#381030 - Fix spacings in the display capplet's dialog, labels,
  and option grouping.
  bnc#450141 - Remove nonfunctioning Help button.
  bnc#433939 - Make it more obvious how to turn on a newly-detected
  monitor that is off.
  bgo#551566 - Fix incorrect repainting when resizing the capplet's
  dialog.
* Fri Dec 26 2008 rodrigo@novell.com
- Remove unneeded patch
- Update to version 2.25.3:
  + Removed sound capplet, moved to gnome-media
  + Add support for fingerprint readers with more than one enrollment stage
  + Display errors when any happen
  + Slight UI changes
  + When a monitor is selected, update the monitor label to have the monitor's
    name and colour so they know which one is being edited
  + Make the monitor on which the dialogue appears the default one on startup
  + Fix monitors still overlapping when turning off "Mirror screens"
  + Remove unneeded help button in display capplet
* Wed Nov 12 2008 rodrigo@novell.com
- Add libcanberra-gtk to Requires to get sound events working (bnc#439054)
* Tue Nov  4 2008 vuntz@novell.com
- Move gnome-control-center-use-preferences-menu.patch to
  gnome-control-center-use-settings-menu.patch since we now use
  settings.menu.
* Sat Oct  4 2008 mboman@suse.de
- Update to version 2.24.0.1:
  + Fix newly-introduced crash in theme tab (bgo#553541)
* Fri Sep 26 2008 vuntz@novell.com
- Merge openSUSE:Factory and GNOME:Factory...
- Add gnome-control-center-bnc427745-force-dpi.patch to force the
  DPI to 96. This fixes huge fonts on login on recent laptops.
  Fixes bnc#427745.
* Tue Sep 23 2008 rodrigo@novell.com
- Update to version 2.24.0:
  + Accessibility:
  - Improve tooltip wording
  + Appearance:
  * when a hidden theme is selected, and therefore becomes visible,
    create a thumbnail for it (bgo#547301)
  * don't fail if the destination files already exist and the user tries
    to overwrite them (bgo#552671)
  * set GtkAdjustment page size to 0 to avoid roblems due to newly enforced
    value boundaries in GTK+ 2.14 (bgo#551740)
  + Common:
  * properly initialize the callback data (bgo#550263)
  + Default applications:
  * don't advertise startup-notify. The script doesn't support it (bgo#550694)
  * use a11y icon instead of searchtool (bgo#550742)
  + Display:
  * Use "Mirror Screens" instead of "Cloned Output" in the display of monitors,
    to be consistent with the corresponding checkbox from the Glade file
  * use theme colours for the background (bgo#545117)
  + Keybindings:
  * don't use the term "accelerator" in the UI (bgo#547276)
  + Keyboard:
  * chosing first variant by default (bgo#550722)
  * using the fact that latest libxklavier returns descriptions in UTF-8,
    no need to convert in 8-bit locales
  + Sound:
  * trying to print NULL strings crashes on Solaris (bgo#548586)
  * add context to event sound names (bgo#549489)
  + Updated translations
* Fri Sep 19 2008 rodrigo@novell.com
- Added dependency on libcanberra-*
- Sound capplet is built always (bnc#427748)
* Thu Sep 18 2008 sbrabec@suse.cz
- Dropped ftp:// and news:// patches (bnc#256090).
* Thu Sep  4 2008 mboman@novell.com
- Update to version 2.23.90:
  + Appearance:
  * Use default icon for unknown themes
  * Remove help button
  + Common:
  * Make sure we have a notification theme before trying to save it
    (bgo#547448)
  * Keep track of hidden themes (bgo#547301)
  * Require gnome-desktop 2.23.90
  + Display:
  * Draw rotated outputs rotated
  * Don't leak the application or the GladeXML
  * Replace all uses of g_print with g_debug
  * Fail gracefully if we cannot get a screen
  * Add sexy labels to identify monitors
  + Shell:
  * Remove eel dependency from libslab
  + Sound:
  * Fix warning due to left-over developer code (bgo#546583)
  * HIG fixes and improved wording (bgo#545219)
  * Make the event sound preview button listen to "activate" signal so it
    becomes accessible via keyboard (bgo#547808)
  + Translation updates
- Remove gnome-control-center-monitor-labeling.diff. Fixed upstream
* Thu Aug 28 2008 ro@suse.de
- fix build: sound settings are not being built at the moment
  (configure does not find CANBERRA)
  skip the update-desktop-file if it is not being installed
- vfs-methods have been removed, remove in filelist as well
* Wed Aug 20 2008 sbrabec@suse.cz
- Require gnome-menus - gnome-control-center binary requires
  /etc/xdg/menus/preferences.menu.
* Mon Aug 18 2008 federico@novell.com
- Updated gnome-control-center-monitor-labeling.diff so that it applies cleanly.
* Fri Aug 15 2008 federico@novell.com
- Added gnome-control-center-monitor-labeling.diff to implement
  labeling of physical monitors while their properties are being set
  in the Display capplet.
* Tue Aug  5 2008 rodrigo@suse.de
- Update to version 2.23.6:
  + Various fixes and improvements
  + Add freedesktop sound theme support
  + Updated translations
  + Updated randr 1.2 code
- Removed upstreamed randr1.2 patch
* Fri Jun 20 2008 maw@suse.de
- Update to version 2.23.4:
  + Various fixes and improvements
  + Drop the gnome-vfs dependency
  + Bugs fixed: bgo#309629, bgo#532893, bgo#317835, bgo#515078,
    bgo#526944, bgo#528196, bgo#519065, bgo#500276, bgo#524401,
    bgo#524401, bgo#511065, bgo#528196, bgo#524813, bgo#521826,
    bgo#529772, bgo#515078, bgo#527418, bgo#314883, bgo#523888,
    bgo#525530, bgo#529720, bgo#134595, and bgo#329503
  + Updated translations.
* Fri Jun 13 2008 federico@novell.com
- Updated gnome-control-center-system-proxy-configuration.patch to fix
  https://bugzilla.novell.com/show_bug.cgi?id=350513 - the widgets for
  manual proxy configuration were disabled at startup, even if Manual
  mode was selected in the user's configuration.
* Thu May 29 2008 federico@novell.com
- Updated gnome-control-center-randr-1.2.diff with the latest fixes from upstream.
* Tue May 13 2008 vuntz@suse.de
- Add gnome-control-center-bnc373197-layout-switch-keybinding.patch
  to change the default keyboard layout switching to
  Shift_L+Shift_R instead of Alt_L+Alt_R, which doesn't work at the
  moment. Helps with bnc#373197 for 11.0.
* Sat May  3 2008 coolo@suse.de
- Obsoleting older version not newer
* Fri Apr 25 2008 federico@novell.com
- Added gnome-control-center-randr-1.2.diff to integrate the new
  functionality to configure RandR 1.2.
* Mon Apr 14 2008 ro@suse.de
- added also provides for old name, not just obsoletes
* Mon Apr 14 2008 rodrigo@suse.de
- Renamed to gnome-control-center, like upstream
- Removed desktop-effects patch, moved to simple-ccsm
* Thu Apr 10 2008 maw@suse.de
- Update to version 2.22.1:
  + appearance:
  * Don't resize the font samples vertically when the window is
    resized (bgo#521823)
  * Fix warning when trying to drag an unselected item
    (bgo#523347)
  * Don't try to unref URIs if the theme package is invalid
    (bgo#524567)
  + common:
  * Fix a crash when schemas are not properly installed
    (bgo#520744)
  * Fix error handling in the thumbnailer (bgo#521009)
  * Actually check the cursor size before changing it in GConf
  + keybindings:
  * Remove debugging output
  * Stop widget accelerators from activating while the user is
    entering a new shortcut (bgo#313228)
  * Fix category headers not appearing properly in the treeview
    when using a non-UTF-8 locale (bgo#513988)
  + keyboard:
  * Don't crash when called for a drag with no selected items
    (bgo#523379)
  * Don't show the typing break tab if the typing monitor is
    not available (bgo#524034)
  + sound:
  * Use new tango icon (bgo#523916)
  * Don't show modems in the device chooser (bgo#523888)
  + themus:
  * Handle failed thumbnailing attempts properly
  + typing-break:
  * New Tango-style icons (bgo#523965)
  * Replace custom stop icon with gtk-stop stock icon
  + Updated translations.
* Mon Mar 31 2008 rodrigo@suse.de
- Added control-center2-desktop-effects.patch to add compiz
  activation GUI to the appearance capplet.
- Finish tagging of patches
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + about-me:
  * Fix misspelling of "palindrome" (bgo#519398)
  + common:
  * Port to GIO
  + keyboard:
  * Fix leaks and remove unnecessary casts
  + mouse:
  * Make the mouse orientation radio button usable with both
    mouse buttons
  + Updated translations.
* Thu Mar 13 2008 sbrabec@suse.cz
- Custom look'n'feel gconf keys moved to gconf2-branding-openSUSE.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + http://ftp.acc.umu.se/pub/GNOME/sources/gnome-control-center/2.21/gnome-control-center-2.21.9[12].news.
* Mon Feb  4 2008 rodrigo@suse.de
- Added very much needed dependency for upcoming alpha on
  gnome-settings-daemon, a runtime dependency which is not being
  picked up in any pattern
* Fri Feb  1 2008 rodrigo@suse.de
- Update to version 2.21.90:
  * http://ftp.acc.umu.se/pub/GNOME/sources/gnome-control-center/2.21/gnome-control-center-2.21.90.news
- Re-enable gnome-patch*
* Wed Jan 30 2008 maw@suse.de
- Revert last change -- nautilus owns
  %%{_libdir}/nautilus/extensions-2.0 now.
* Tue Jan 29 2008 thoenig@suse.de
- Fix build:  Add %%dir %%{_libdir}/nautilus/extensions-2.0
* Tue Jan 29 2008 rodrigo@suse.de
- Updated to 2.21.5:
  * http://ftp.gnome.org/pub/GNOME/sources/gnome-control-center/2.21/gnome-control-center-2.21.5.news
- Disabled patches that need rebase
- Removed suse_update_desktop_file for no longer existing files.
- Removed gnome-settings-daemon related files
- Disable temporarily gnome-patch-translation*, since it's
  complaining about files removed upstream ??
* Wed Nov 21 2007 maw@suse.de
- Fix build.
* Tue Nov  6 2007 rodrigo@suse.de
- Added missing gtk_widget_set_sensitive call (#8785)
* Thu Nov  1 2007 sreeves@suse.de
- Fix for #298047 - remove reference to background.desktop
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Mon Sep 17 2007 maw@suse.de
- Update to version 2.20.0:
  (Bug numbers in this entry are against bugzilla.gnome.org)
  + Appearance:
  * Correct translatable property value of "Save As" (#473810)
  * Don't set a fixed width for the toolbar button color label
    (#474317)
  * Add comment for translators (#473379)
  + General:
  * Fix building with Sun's Forte compiler (#473967)
  + Updated translations.
* Mon Sep 10 2007 maw@suse.de
- Update to version 2.19.92:
  + Appearance:
  * Leaks fixed
  * Use _prepend for lists instead of _append
  + Updated translations.
* Mon Sep 10 2007 rodrigo@suse.de
- Remove workaround for upstream bug already fixed (#223798)
* Wed Sep  5 2007 maw@suse.de
- Add control-center2-default-keybindings-thoenig-01.patch
  (#297640).
* Fri Aug 31 2007 maw@suse.de
- Update to version 2.19.91:
  (Bug numbers listed here are against bugzilla.gnome.org)
  + general:
  * Hide the password in displayed URIs when transfering files
    (#339551)
  + about-me:
  * Use g_get_user_special_dir() instead of hard-coding ~/Pictures
  * Honor mail address attributes when setting up Home and Work
    addresses
  + appearance:
  * Don't generate GTK thumbnails when we want metacity or icon
    (#462724)
  * No need for an expensive parse to initialize the colors
  * Reduce metacity thumbnail size to 128x128
  * Also load the "default" cursor theme so we know the
    available sizes (#462409)
  * Create the icon theme representative before the GTK stock
    button
  * Various small tweaks and optimizations
  * Add a shortcut to the user's special Pictures folder to
    the file chooser and default to it (#461093)
  * HIG capitalization fix for a checkbutton label
  * Use thumbnail factory to store and retrieve metatheme
    thumbs (#448968)
  * Remove check for old glib version that would result in
    bogus code
  * Only add a "Default Pointer" list item if there is no such
    GnomeThemeCursorInfo
  * Toggle sensitivity of the cursor scale labels (#463442)
  * Indent category contents, and other HIG spacing fixes
  * Fix check for available symbolic colors and make buttons
    for unsupported colors insensitive (#464081)
  * Make sure the color scheme has changed before writing
    to GConf and enabling the reset button
  * Reenable theme lockdown
  * Restrict drag'n'drop installation to the theme tab
  * Fix double-free and use-after-free
  * Make sure we have a selection before trying to get the
    data (#465431)
  * Don't leak the cursor font
  * Fix double-free and make the builtins non-static to save
    relocations (#467522)
  * Properly check all installed themes if necessary (Jens Granseuer)
  * Free the metacity theme after use (#469531)
  * Correct the item width and enable line wrapping for
    long theme names (#466405)
  * If no background image set, select "no wallpaper"
  * Simply set the upper bound of the DPI spin button to
    the maximum we consider acceptable (#469580)
  * Don't mark gtk-delete stock id for translation (#470532)
  * Always generate thumbnails asynchronously (#469849)
  + default applications:
  * Don't use '==' and improve portability with empty strings
  * Add browser and mail entries Iceape) (#467472)
  * Use the new -new-tab and -new-window arguments instead
    of -remote for Firefox tab and window commands (#393204)
  + keybindings:
  * Make the arrows and tabs unbindable without a modifier
    (#463433)
  + keyboard:
  * Disable "delete" button when no layout is selected
    (#466749)
  * Make "Add label" string translatable) (#470516)
  + settings daemon:
  * Use CTRL-ALT-DEL as default keybinding for 'Log out'
  * Use a list instead of a hash table to store the settings
    modules (#449118)
  * Raise the volume when unmuting
  * Show X keyboard settings warning dialog delayed, so that
    it runs properly centered and with decorations
  * Initialize XKB config early so that callback would not
    crash (#469192)
  + window:
  * Expose missing metacity double-click actions (#416541)
  + Updated translations
- Refresh control-center2-default-config.patch
- Remove control-center2-shell-desktop.patch.
* Wed Aug 22 2007 rodrigo@suse.de
- Patched gnomecc.desktop file to have the control center entry
  show up on the traditional menu bar (#260545)
* Thu Aug 16 2007 rodrigo@suse.de
- Fixed location of gnome-passwd.glade file (#296721)
* Wed Aug  8 2007 maw@suse.de
- Split off a -lang subpackage.
* Fri Aug  3 2007 jpr@suse.de
- Cleanup patches (#256090)
* Thu Aug  2 2007 maw@suse.de
- Update to version 2.19.6:
  + about-me:
  * Add a tooltip to the image button
  + appearance:
  * Add option to add wallpapers via the command line
  * Use new GTK+ convenience API for icon view tooltips
  * Bump all tooltips code to GTK 2.11.6
  * Improve color scheme matching
  * When reading current settings from gconf, get the color scheme from the
    GTK theme if necessary to allow matching against themes retrieved via
    gnome-theme-info
  * Implement saving of the cursor theme name in metathemes and add a
    'Default pointer' option to the cursor theme list
  * Simplify tooltip descriptions
  * Really unset the gconf key when reverting colors
  * Implement drag-and-drop theme installation
  * Remove workarounds for initialization problems in early versions of the
    capplet
  * Fix cell renderer state logic to not always be on
  * Use cairo to draw the cell renderer selection
  * Show readable_name in cursor theme list instead of name
  * Fix mnemonics and customize theme window title
  * Fix theme installation
  * Update icon cache when installing icon themes
  * Prevent some memory leaks
  * Add controls for applying suggested backgrounds and/or fonts from
    metathemes
  * Only show background/font suggestions if they haven't already been
    applied
  * Cope with unset gconf keys and group gconf notifications (Jens Granseuer)
  * Only create the custom theme entry when changes are made, and delete it
    when the theme is saved
  * Add %%F to the exec line so external programs like epiphany can set the
    background
  * Default to showing the background tab if wallpapers were given on the
    command line
  * Use our custom cell renderer for metathemes too, so the previews don't
    get shaded
  + default applications:
  * Change custom command entries to be insensitive instead of
    noneditable
  * Remove spurious desktop entries
  + keyboard:
  * Improved layout and sorting
  * Implement DND in the selected layouts list
  * Eliminate up/down buttons in the layout list
  + network:
  * Also use new icon in the window title bar
  + settings daemon:
  * Don't forget the Xft callback
  + themus:
  * Update to match theme callback signature
  + general:
  * Fix crash when no cursor is specified in theme
  * General cleanup and leak-plugging
  * Don't fail configuring if gstreamer is not available, simply skip the sound
    capplet
  * Remove spurous AT desktop entries (Jens Granseuer) (#444787)
  * Add support for custom theme names saved in metathemes (Denis Washington)
  * Re-add basic support for cursor themes for X servers without the Xcursor
    extension, like the one in Solaris
  * When applying a metatheme, check wether to set/unser color scheme gconf
    key
  * Fix notification of selection changed for GtkTreeView config support
  * Prevent cursor themes from being recognized as icon themes
  * Read a cursor themes's name from its index.theme file if it has one
  * Expand check for empty metatheme color scheme to include blank color scheme
    strings
  * Add tooltip foreground and background colors to the list of recognized
    symbolic colors
  + updated translations
- Remove control-center2-dont-update-mimedb.patch
- Use %%fdupes.
* Fri Jul 27 2007 jpr@suse.de
- Disable seamonkey patch to re-enable build
* Thu Jul 26 2007 jpr@suse.de
- Update version to 2.19.5 to get fix for (#293560)
- Many upstream bug fixes
  - Now uses icon theme for icons
  - Lots of changes to improve the settings daemon
- Translation updates
* Thu Jul 19 2007 gekker@suse.de
- Make sure that the new merged appearances capplet is visible
* Mon Jul  9 2007 maw@suse.de
- Update to version 2.19.4
- The source tarball is now called gnome-control-center-$version.tar.bz2;
  however, the package's name remains the same
- Concomitant with the tarball name change, a number of directories
  packaged have been renamed from control-center to
  gnome-control-center
- Remove the following upstreamed patches:
  * control-center2-217790-sanitize-dpi.diff
  * control-center2-compiz-keybindings.patch
  * control-center2-static-libslab.patch
  * control-center-control-key-events.patch
  * control-center-no-x-suse.patch
- Bug fixes, updated translations
- s#%%run_ldconfig#/sbin/ldconfig# in the %%post and %%postun
  sections.
* Wed Jun  6 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Tue May 22 2007 sbrabec@suse.cz
- Removed X-SuSE tag from the upstream desktop file.
- Added MIME based default option for default applications FTP
  preferences (GNOME#426638#c13).
* Thu May 17 2007 rodrigo@suse.de
- Look for gnome-passwd.glade file in the correct dir (#272702)
* Mon May 14 2007 maw@suse.de
- Rename jhmfc.patch to control-center2-dont-update-mimedb.patch
* Thu Apr 12 2007 rodrigo@suse.de
- Added patch to use preferences.menu in control-center rather than
  gnomecc.menu.
* Tue Apr 10 2007 rodrigo@suse.de
- Added patch for building libslab statically.
- Patched schemas file to contain our default values.
* Thu Apr  5 2007 sbrabec@suse.cz
- Added "Use default web browser" option for default applications
  FTP preferences (#113104#c13).
* Mon Apr  2 2007 sbrabec@suse.cz
- Ported control-center-default-applications-ftp+news.patch
  (#113104#c11).
- Added seamonkey to default applications list.
* Fri Mar 30 2007 maw@suse.de
- Update to version 2.18.0
- b.g.o 344741 and 413468 (partially).
* Mon Mar 19 2007 sbrabec@suse.cz
- Fixed devel dependencies.
* Thu Mar 15 2007 maw@suse.de
- Update to version 2.17.91
- Refresh a number of patches.
- Bug fixes include bugzilla.gnome.org #402797, #358106, #380991,
  [#395383], #401004, #397905...
* Thu Mar  8 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlinks (#248676).
* Thu Mar  1 2007 sbrabec@suse.cz
- Removed obsolete pangoxft patch (#249608).
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Tue Jan  9 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Dec 22 2006 federico@novell.com
- Added control-center2-217790-sanitize-dpi.diff to fix the
  control-center2 part of
  https://bugzilla.novell.com/show_bug.cgi?id=217790.  Some X servers
  don't report the screen's physical dimensions correctly, so the DPI
  value is wrong.  This can lead to unusably huge or tiny fonts.  This
  patch constrains the X server's DPI value to something reasonable.
* Thu Nov 30 2006 sbrabec@suse.cz
- Fixed devel dependencies for older products.
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches.
- Update and reenable control-center2-po-update.patch
* Fri Oct 13 2006 dreveman@suse.de
- Update compiz keybinding patch so it works with compiz 0.2.
* Fri Oct 13 2006 aj@suse.de
- Adjust BuildRequires for gnome-doc-utils.
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.16.1
- display:
  - Never pass negative values for the rates
- keyboard:
  - Make sure 'model' is never NULL
- themus:
  - Fixed "Open" icon on button preview
  - Allow the text in the details to ellipsize and set a minimun width for
    the dialog
- translation updates
* Wed Sep 13 2006 jhargadon@suse.de
- update to versin 2.16.0
- avoid excess strduping
- avoid extra key events processing
- avoid grabbing all keyboard when the key code cannot be retrieved
- add missing maximize button
- translation updates
* Sat Sep  2 2006 gekker@suse.de
- Install dbus service file in correct location
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.92
- fix "Background dialogue resizes when shown"
- fix issues with the themes previews
- free 'resolution' string after using it, not before
- fix memory leak
- patches from "generate visible previews first"
- translation updates
* Mon Aug 21 2006 jhargadon@suse.de
- update to version 2.15.91
- require libebook-1.2 1.7.90 for the new API
- use orca screenreader when available
- fixed X-GNOME-Bugzilla fields in .desktop file
- using Unicode subscript for repeating descriptions
- set "label for" and "labelled by" properties for the capplet
- only include libhal if HAL is enabled
- added support for locking down theme
- don't attempt to load window manager theme name from an unknown window
  manager
- use GtkAboutDialog, not GtkDialog
- use GtkStatusIcon instead of libegg
- translation updates
* Fri Aug  4 2006 sreeves@suse.de
- Mark an existing string in
  control-center2-soundupdate.patch for translation (185591)
* Thu Jun 29 2006 sbrabec@suse.cz
- Added two missing upstream translations (#185584#c27).
- Fixed Norwegian translation update (#185584#c29).
- Symlink password dialog icon to proper place (#185584#c29).
* Tue Jun 20 2006 sbrabec@suse.cz
- Fixed I18N bug in password dialog title (185584#c7).
* Fri Jun 16 2006 sreeves@suse.de
- Fix for 185591 - missing localization for sound entries.
* Fri Jun 16 2006 sbrabec@suse.cz
- Fixed missing strings in password dialog (#185584).
* Fri Jun  2 2006 hpj@suse.de
- Updated the search patch to fall back to gnome-search-tool if
  Beagle can't be found.
* Mon May 29 2006 hpj@suse.de
- Add patch to invoke Beagle on "search" keybinding. Fixes Novell
  bug #132801.
* Mon May 29 2006 sbrabec@suse.cz
- Added passwd capplet to POTFILES.in (#179459).
* Sun May 28 2006 danw@suse.de
- Add toggle maximize, horiz/vert maximize, and show desktop to
  control-center2-compiz-keybindings.patch (#178220)
* Tue May  9 2006 dobey@suse.de
- Add fixes for CRITICAL warnings from background-properties
  See bug https://bugzilla.novell.com/show_bug.cgi?id=83196
* Sun May  7 2006 danw@suse.de
- Add cube unfold binding to control-center2-compiz-keybindings.patch
* Tue May  2 2006 sbrabec@suse.cz
- Moved proxy settings from Hardware to System (#167466).
* Thu Apr 20 2006 danw@suse.de
- Add compiz keybindings to gnome-keybinding-properties. 163208
* Wed Apr 19 2006 sreeves@suse.de
- Fix for 148037 - mangled widgetry in sound capplet
* Thu Apr 13 2006 sbrabec@suse.cz
- Call %%suse_update_desktop_file for all desktop files.
- Added gnome-ui-properties to control-center (118960#c11).
- Use new control-center Categories instead of illegal old ones.
* Mon Apr  3 2006 jpr@suse.de
-  Add gst 0.10 support for gnome-settings-daemon
* Thu Mar 23 2006 rodrigo@suse.de
- Updated control-center2-multiple-displays.patch to use the correct
  DISPLAY for bonobo-activation, and fixed ultra-quick error dialog
  (#156801).
* Thu Mar 23 2006 federico@novell.com
- Updated control-center2-system-proxy-configuration.diff to fix bug
  [#158600].  Gnome-settings-daemon will now read the HTTPS_PROXY value
  from /etc/sysconfi/proxy and set it in the appropriate GConf keys.
* Mon Mar  6 2006 rodrigo@suse.de
- Added patch to support multiple concurrent sessions (fixes part
  of #150623).
* Thu Mar  2 2006 rodrigo@suse.de
- Don't spawn esd daemon, already done in libesound (part of
  [#153419])
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Fri Feb 17 2006 sreeves@suse.de
- Another Update .desktop file (Name, GenericName, Comment, DocPath)
* Fri Feb 17 2006 gekker@suse.de
- Fixup .desktop files for UI team
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Wed Feb 15 2006 gekker@suse.de
- Fix font thumbnailing (b.g.o#329043)
* Mon Feb 13 2006 gekker@suse.de
- Remove dependency on e-d-s, not required since we don't ship
  the about me capplet, partial fix for (#148339)
* Wed Feb  1 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Tue Jan 31 2006 rodrigo@suse.de
- Use /etc/pam.d/common-* for PAM authentication (146699)
* Mon Jan 30 2006 sbrabec@suse.cz
- Implemented ftp:// and news:// to
  gnome-default-applications-properties (#113104).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 hpj@suse.de
- Updated the passwd-dialog patch to pass through messages from PAM.
  This is necessary for the PAM Winbind module, as it informs the
  user of password policies and more complex error situations.
* Thu Jan 12 2006 sreeves@suse.de
- Add X-Ximian-Settings to default-applications.desktop. Fix for Bug#141104
* Mon Dec 26 2005 federico@novell.com
- Added control-center2-system-proxy-configuration.diff.  This was
  included in SUSE Linux 9.3 for bug #71202.  This makes gnome-settings-daemon
  default to the YaST settings for the HTTP proxy if appropriate, propagating
  them to apps that use GConf to find these settings.
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.12.2
- Remove upstreamed patch
* Tue Nov 29 2005 gekker@suse.de
- Add default-config patch for logout shortcut (#130829).
* Wed Oct 12 2005 gekker@suse.de
- Update to version 2.12.1
* Thu Oct  6 2005 gekker@suse.de
- Remove previous change for now
- Fix DocPath in .desktop file
* Tue Oct  4 2005 gekker@suse.de
- Rename "Desktop Background" to "Display Settings"
* Wed Sep 21 2005 rodrigo@suse.de
- Fixed icon and category of desktop file for change-passwd
  capplet (fixes #117028).
* Mon Sep 19 2005 sbrabec@suse.cz
- Fixed PreReq.
- Fixed permissions in PLUS.
* Thu Sep 15 2005 clahey@suse.de
- s/Assistive Technology Support/Assistive Technology/
- Change window height to 550.
- Part of fix for #115299
* Mon Sep  5 2005 aj@suse.de
- Update to 2.12.0.
* Mon Aug 29 2005 rodrigo@suse.de
- Added control-center2-screensaver.patch (#113353)
- Enabled setuid change-passwd program (GNOME part of #104993)
* Mon Aug 22 2005 gekker@suse.de
- Update to 2.11.92
- Remove upstreamed theme-thumbnail patch
* Sun Aug 21 2005 ro@suse.de
- added pangoxft to liblist
* Thu Aug 18 2005 gekker@suse.de
- Fix theme-thumbnail
* Tue Aug 16 2005 rodrigo@suse.de
- Added gnome-passwd patch from SP2.
* Fri Aug 12 2005 sreeves@suse.de
- Update the sound capplet to match interface requested by Nat
  and Federico. Also removed patch1 after talking with Jody as
  he indicates it is not needed.
* Wed Aug 10 2005 rodrigo@suse.de
- Update to version 2.11.91
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.11.90
- Add scrollkeeper magic
* Fri Jul 29 2005 jpr@suse.de
- Depend on kereberos libs for building
* Mon Jul 25 2005 gekker@suse.de
- Update to 2.11.6
- Backout fix for (b.g.o309558) fixed bug in xorg-x11
* Mon Jul 18 2005 sbrabec@suse.cz
- Don't grab Control key events by Show pointer function.
  http://bugzilla.gnome.org/show_bug.cgi?id=125618
- Fixed devel dependencies.
- Removed unneeded static modules and .la files for modules.
* Fri Jun 17 2005 gekker@suse.de
- Update to version 2.11.4
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed Apr 13 2005 sbrabec@suse.cz
- Do not build with -Werror.
- Added required NULL-pointer argument.
* Fri Mar 18 2005 sbrabec@suse.cz
- Changed Categories for gnome-ui-properties and
  default-applications to appear only in menu (#73047).
* Wed Mar 16 2005 sbrabec@suse.cz
- Added X-Ximian-Settings to gnome-ui-properties and
  default-applications (#73047, #73547).
* Wed Mar 16 2005 clahey@suse.de
- Changed category of desktop files so they'll still be in control
  center but won't be in More Programs menu.
- Installed icons in hicolor and installed icons for proxy and for
  directories.
* Tue Mar 15 2005 sbrabec@suse.cz
- Symlink desktop icon to standard location (#72818).
* Thu Mar 10 2005 gekker@suse.de
- Add new version of the system-proxy-configuration patch (71202).
* Thu Mar 10 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Mon Feb 28 2005 sbrabec@suse.cz
- Do not package mimeinfo.cache.
* Thu Feb 24 2005 sbrabec@suse.cz
- Removed gconf makefile-uninstall-rule (#33114).
* Fri Feb 18 2005 clahey@suse.de
- Add a desktop file for change password.
* Thu Feb 17 2005 gekker@suse.de
- add federico's system-proxy-configuration patch
* Thu Feb 10 2005 gekker@suse.de
- Update to version 2.9.91
* Fri Jan 28 2005 sbrabec@suse.cz
- Fixed directory ownership (require nautilus).
- Fixed libexecdir.
* Wed Jan 26 2005 jody@suse.de
- jump to 2.9.4
- drop all the partial updates from 2.6
* Wed Dec 15 2004 hvogel@suse.de
- fix desktop file
* Fri Oct 29 2004 ro@suse.de
- merged stuff from jody:
- Additional translations
- Some minor accessibility patches that are unreleased in the 2.6.x branch
* Fri Oct 29 2004 ro@suse.de
- locale rename: no -> nb
* Mon Oct  4 2004 sbrabec@suse.cz
- Updated directory files to show properly icons and translations
  (#46621).
* Mon Oct  4 2004 sbrabec@suse.cz
- Czech translation update (#46621).
* Thu Sep 16 2004 jody@suse.de
- fix help links for accessibility technologies and window capplet
  [#61587], #61588
* Thu Sep  9 2004 dobey@suse.de
- Pull in changes for the background capplet from CVS
* Tue Sep  7 2004 sbrabec@suse.cz
- Created shared mime info.
* Mon Sep  6 2004 shprasad@suse.de
- Not applying patch6 because it is taken care by gnome-audio.
* Mon Aug 30 2004 rml@suse.de
- add control-center-keybinding-workaround.patch (fix
  Ximian bug #59654)
* Fri Aug 13 2004 shprasad@suse.de
- Fixes bug#63036 (Fix given by sdharmaveer@novell.com)
  makes gnome login/logout sounds play at login/logout events.
- Fixes bug#63038 (Fix given by sdharmaveer@novell.com)
  overrides the default gnome login/logout sounds by novell
  login/logout sounds.
* Tue Aug 10 2004 dobey@suse.de
- Include %%prefix/share/gnome-background-properties
* Tue Jul  6 2004 jody@suse.de
- Restore missing sound and mouse capplets
* Fri Jun 25 2004 jody@suse.de
- Move the shell into a tarball to improve maintainability
- Fix crash when clicking on whitespace
* Fri Jun 25 2004 jody@suse.de
- remove keyboard layout (obsolete)
- change printer capplet and fix icon
- update shell
- backport a few fixes from head
* Thu Jun  3 2004 clahey@suse.de
- gnome-applets is a more proper replacement package than control-center2.
* Mon May  3 2004 clahey@suse.de
- Upgraded to 2.6.1.
- Added patch to change desktop files to contain the Category needed
  to show up with the new gnome-vfs2.
* Fri Apr 30 2004 clahey@suse.de
- Added patch to use new control center shell.
* Tue Apr  6 2004 sbrabec@suse.cz
- Provide alternative desktop file in Utility->Desktop for non-GNOME
  sessions, to make possible configuration of GNOME applications.
- Build with -fno-strict-aliasing.
* Sat Mar 20 2004 adrian@suse.de
- do not show gnome CC menu entry in KDE
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed names of GNOME2 packages.
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Tue Oct  7 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Sat Sep 13 2003 matz@suse.de
- Fix wrong declaration that leads to segfaults.
* Thu Aug  7 2003 sbrabec@suse.cz
- Not use globbing for schemas in %%files.
- Removed duplicated screensaveer desktop file.
* Wed Aug  6 2003 hhetter@suse.de
- remove prefix clash fix patch
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Use %%find_lang.
* Sun Jun 22 2003 ro@suse.de
- package directories
* Thu May 15 2003 sbrabec@suse.cz
- Updated to version 2.2.1.
* Fri Feb 14 2003 hhetter@suse.de
- look in /opt/gnome2 for GTK Themes instead of
  the GTK prefix, to get metathemes to work
* Fri Feb  7 2003 hhetter@suse.de
- updated to version 2.2.0.1 [GNOME 2.2.0]
* Mon Feb  3 2003 ro@suse.de
- added startup-notification to neededforbuild
* Thu Jan 16 2003 sbrabec@suse.cz
- Updated to version 2.1.6.
- Added Czech description for screensaver.
- Use gnome2-devel-packages for neededforbuild.
- Updated %%files.
* Thu Nov 21 2002 schwab@suse.de
- Fix missing declarations [#21674].
* Tue Oct 22 2002 hhetter@suse.de
- updated to version 2.0.2.91
- remove wrong docdir
* Tue Oct  1 2002 sbrabec@suse.cz
- Updated to version 2.0.1.1.
- Move gnome-window-settings-2.0.pc to /usr/%%_lib/pkgconfig/.
- Updated %%files section.
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Tue Sep  3 2002 hhetter@suse.de
- provide option to start xscreensaver-demo from control-center
  ( Bug Id #18789)
* Tue Aug 20 2002 hhetter@suse.de
- added prereq: filesystem
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Thu Jun 20 2002 hhetter@suse.de
- don't install schemas while make install
* Tue Jun 18 2002 meissner@suse.de
- use libdir for lib64
* Tue Jun 18 2002 hhetter@suse.de
- updated to version 2.0.0
- added missing schema file
* Fri Jun 14 2002 hhetter@suse.de
- supply schema files
* Wed Jun 12 2002 hhetter@suse.de
- added control-center gconf schemas and
  glade xml files to filelist
* Wed Jun  5 2002 hhetter@suse.de
- updated to version 1.99.10
* Fri Apr 26 2002 ro@suse.de
- replaced gnome-core2 by gnome-desktop in neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
